OC.L10N.register(
    "news",
    {
    "Download" : "Pellgargañ",
    "Close" : "Serriñ",
    "Open website" : "Digor al lec'hienn-web",
    "Share" : "Rannan",
    "Username" : "anv implijer",
    "by" : "gant",
    "Play audio" : "Loc'hañ an audio",
    "Download video" : "Pellkargañ ar video",
    "Description" : "Diskrivadur",
    "Refresh" : "Freskaat",
    "Web address" : "Chom-lec'h web",
    "Folder" : "Teuliad",
    "No folder" : "Teuliad ebet",
    "New folder" : "Heuliad nevez",
    "Folder name" : "Anv teuliad",
    "Credentials" : "Kretaatoù",
    "Password" : "Ger-tremen",
    "New Folder" : "Teuliad nevez",
    "Create" : "Krouiñ",
    "Rename" : "Adenvel",
    "Menu" : "Roll",
    "Newest first" : "An hini nevesañ da gentañ",
    "Oldest first" : "An hini kozhoñ da gentañ",
    "Delete" : "Dilemel",
    "Dismiss" : "Arrest",
    "All articles" : "Pep pennad",
    "Settings" : "Arventennoù",
    "Import" : "Emporzhiañ ",
    "Help" : "Skoazell",
    "Documentation" : "Diellvadur",
    "Report a bug" : "Dugas ur gudenn"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
