OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Solecitare nereușită, conexiune la rețeă indisponibilă!",
    "Request unauthorized. Are you logged in?" : "Cerere neautorizată. Ești autentificat ?",
    "Token expired or app not enabled! Reload the page!" : "Token expirat sau aplicatie inactivă. Reîncarcă pagina!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Eroare server internă! Controlați fișierul data/nextcloud.log pentru mai multe informații!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Solicitare nereușită, Nexcloud este momentan în mentenanță!",
    "News feeds" : "Fluxuri de știri",
    "Unread articles" : "Articole necitite",
    "News" : "Noutăți",
    "News folders" : "Fluxuri de știri",
    "Shared with me" : "Partajat cu mine",
    "An RSS/Atom feed reader" : "Un cititor de fluxuri RSS/Atom",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 O aplicație de agregare a știrilor pentru Nextcloud\n\n- 📲 Sincronizați fluxurile dumneavoastră de știri cu multiple [aplicații] de mobil sau calculator(https://nextcloud.github.io/news/clients/)\n- 🔄 Actualizări automate pentru toate știrile dumneavoastră\n- 🆓 Liber și cu sursă deschisă folosind licența AGPLv3, fără reclame sau funcții cu plată\n\n**În acest moment Cron trebuie instalat pe server pentru ca această aplicație să funcționeze**\n\nCerințele necesare pentru instalare se pot găsi [aici](https://nextcloud.github.io/news/install/#dependencies)\n\nLista schimbărilor este disponibilă [aici](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nRaportează o [problemă] https://github.com/nextcloud/news/issues/new/choose)\n\nPropune o [îmbunătățire](https://github.com/nextcloud/news/discussions/new)\n\nRaportează o [problemă] cu fluxurile de date(https://github.com/nextcloud/news/discussions/new)",
    "Use system cron for updates" : "Folosește programul cron pentru updates",
    "Disable this if you use a custom updater." : "Dezactivează această funcție dacă folosești un program diferit de actualizări.",
    "Maximum read count per feed" : "Număr maxim de citiri pentru un flux",
    "Maximum redirects" : "Numărul maxim de redirectări",
    "How many redirects the feed fetcher should follow." : "Cât de multe redirecționări ar trebui aplicația să urmărească.",
    "Feed fetcher timeout" : "Intervalul de așteptat al programului ce adună fluxurile de date",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Numărul maxim de secunde de așteptare pentru fuxurile RSS sau Atom; dacă ține mai mult timp atunci actualizarea va fi oprită.",
    "Explore Service URL" : "Explorează serviciul URL",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Dacă este specificat URL-ul de service va fi folosit pentru a afișa fluxuri de date în secțiune de explorare a fluxurilor. Pentru a reveni la serviciul de explorare încorporat, lăsați această intrare goală. ",
    "Update interval" : "Interval de actualizări",
    "Interval in seconds in which the feeds will be updated." : "Interval actualizare a fluxurilor de date specificat în secunde.",
    "Download" : "Descarcă",
    "Close" : "Închide",
    "Subscribe to" : "Abonamează-te la",
    "No articles available" : "Niciun articol disponibil",
    "No unread articles available" : "Niciun articol necitit disponibil",
    "Open website" : "Deschide website",
    "Star article" : "Articol favorit",
    "Unstar article" : "Scoate articolul din favorite",
    "Keep article unread" : "Păstrează articolul necitit",
    "Remove keep article unread" : "Articol necitit",
    "Share" : "Partajează",
    "Share with users" : "Partajează cu utilizatori",
    "Username" : "Utilizator",
    "No users found" : "Nu au fost găsiți utilizatori",
    "Error while searching for users" : "Eroare în timpul căutării utilizatorilor",
    "Share on social media" : "Partajează pe rețelele de socializare",
    "I wanted you to see this article" : "Imi dorec ca tu să citești acest articol",
    "Check out this article" : "Hei citeste și tu acest articol",
    "by" : "de",
    "from" : "de la",
    "shared by" : "partajat de",
    "Play audio" : "Redare audio",
    "Download audio" : "Descarca audio",
    "Download video" : "Descarcă video",
    "Keyboard shortcut" : "Scurtături din tastatură",
    "Description" : "Descriere",
    "right" : "dreapta",
    "Jump to next article" : "Sari la următorul articol",
    "left" : "stânga",
    "Jump to previous article" : "Sari la următorul articol",
    "Toggle star article" : "Scoate articolul din favorite",
    "Star article and jump to next one" : "Adaugă articolul la favorite și sari la următorul articol",
    "Toggle keep current article unread" : "Marchează acest articol ca necitit",
    "Open article in new tab" : "Deschide articolul într-un tab nou",
    "Toggle expand article in compact view" : "Comutați extinderea articolului în vizualizarea compactă",
    "Refresh" : "Împrospătare",
    "Load next feed" : "Încarcă următorul flux de date",
    "Load previous feed" : "Încarcă fluxul de date precedent",
    "Load previous folder" : "Încarcă dosarul precedent",
    "Load next folder" : "Încarcă următorul dosar",
    "Scroll to active navigation entry" : "Derulează până la setările active",
    "Mark current article's feed/folder read" : "Marchează dosarul sau fluxul de date ca citite",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Modul Ajax sau webcron este activ! Fluxurile dumneavoastră nu vor fi actualizate!",
    "How to set up the operating system cron" : "Cum să setezi funcția cron a sistemului de operare",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instalează și setează un program de actualizări mai rapide ce folosește soluția de API a aplicației News",
    "Subscribe" : "Abonare",
    "Web address" : "Adresă web",
    "Feed exists already!" : "Fluxul există deja!",
    "Folder" : "Director",
    "No folder" : "Niciun director",
    "New folder" : "Director nou",
    "Folder name" : "Denumire director",
    "Go back" : "Înapoi",
    "Folder exists already!" : "Directorul există deja!",
    "Credentials" : "Detalii de autentificare",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Informațiile de autentificare HTTP trebuie să fie stocate decriptate! Toate persoanele ce au access la acest server sau bază de date vor putea accesa aceste infromații!",
    "Password" : "Parolă",
    "Auto discover Feed" : "Descoperă automat fluxurile de date",
    "New Folder" : "Director nou",
    "Create" : "Crează",
    "Explore" : "Explorează",
    "Update failed more than 50 times" : "Actualizarea a eșuat mai mult de 50 de ori",
    "Deleted feed" : "Flux șters",
    "Undo delete feed" : "Anulează ștergerea fluxului",
    "Rename" : "Redenumește",
    "Menu" : "Meniu",
    "Mark read" : "Marchează ca citit",
    "Unpin from top" : "Indepărtatați din capul listei",
    "Pin to top" : "Adăugați în capul listei",
    "Newest first" : "Cel mai nou mai întâi",
    "Oldest first" : "Cel mai vechi mai întâi",
    "Default order" : "Ordinea impicită",
    "Enable full text" : "Activează afișarea textului complet",
    "Disable full text" : "Dezactivează afișarea textului complet",
    "Unread updated" : "Articolele necitite au fost actualizate",
    "Ignore updated" : "Ignoră articolele reîmprospătate",
    "Open feed URL" : "Deschide URL-ul fluxului de date",
    "Delete" : "Șterge",
    "Dismiss" : "Înlătură",
    "Collapse" : "Restrânge",
    "Deleted folder" : "Director șters",
    "Undo delete folder" : "Anulează ștergerea directorului",
    "Starred" : "Marcat",
    "All articles" : "Toate articolele",
    "Settings" : "Setări",
    "Disable mark read through scrolling" : "Dezactivează funcția de \"citit\" prin derulare",
    "Compact view" : "Vizualizare compactă",
    "Expand articles on key navigation" : "Extindeți articolele la apăsarea unei taste",
    "Show all articles" : "Arată toate articolele",
    "Reverse ordering (oldest on top)" : "Ordonare inversă (cele mai vechi primele)",
    "Subscriptions (OPML)" : "Subscripţii (OPLM)",
    "Import" : "Importă",
    "Export" : "Exportă",
    "Error when importing: File does not contain valid OPML" : "A apărut o eroare în timpul importării: fișierul nu conține nu conține OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Eroare la importare: fișierul OPM nu conține nici fluxuri de date nici dosare",
    "Unread/Starred Articles" : "Articole necitite",
    "Error when importing: file does not contain valid JSON" : "Eroare în timpul importării : fişierul nu conţine  JSON valid",
    "Help" : "Ajutor",
    "Keyboard shortcuts" : "Scurtături din tastatură",
    "Documentation" : "Documentație",
    "Report a bug" : "Raportează un defect"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
