OC.L10N.register(
    "news",
    {
    "News" : "Мэдээ",
    "Download" : "Татах",
    "Close" : "Хаах",
    "Share" : "Түгээх",
    "Username" : "Хэрэглэгчийн нэр",
    "from" : "тэндээс",
    "Play audio" : "Аудио тоглуулах",
    "Download audio" : "Аудиог татаж авах",
    "Download video" : "Видеог татаж авах",
    "Keyboard shortcut" : "Keyboard товчлуур",
    "Description" : "Тодорхойлолт",
    "right" : "баруун",
    "Jump to next article" : "Дараагийн өгүүллийг үзээрэй",
    "left" : "зүүн",
    "Jump to previous article" : "Өмнөх нийтлэл рүү очих",
    "Toggle star article" : "Өгүүллийг соль",
    "Refresh" : "Сэргээх",
    "Load next feed" : "Дараагийн тэжээлийг ачаална уу",
    "Load previous feed" : "Өмнөх тэжээлийг ачаална уу",
    "Load previous folder" : "Өмнөх хавтсыг ачаална уу",
    "Load next folder" : "Дараагийн хавтасыг ачаална уу",
    "How to set up the operating system cron" : "Үйлдлийн системийн cron-г хэрхэн тохируулах талаар",
    "Subscribe" : "Захиалга",
    "Web address" : "Вэб хаяг",
    "Folder" : "Хавтас",
    "No folder" : "Хавтас алга",
    "New folder" : "Шинэ хавтас",
    "Folder name" : "Хавтасны нэр",
    "Go back" : "Буцах",
    "Credentials" : "Итгэмжлэл",
    "Password" : "Нууц үг",
    "New Folder" : "Шинэ хавтас",
    "Create" : "Үүсгэх",
    "Explore" : "Хайх",
    "Update failed more than 50 times" : "Шинэчлэлт 50-иас дээш удаа амжилтгүй болсон",
    "Rename" : "Нэрлэнэ үү",
    "Newest first" : "Шинийг урд нь",
    "Oldest first" : "Хуучныг урд нь",
    "Delete" : "Устгах",
    "Dismiss" : "Арилгах",
    "Settings" : "Тохиргоо",
    "Import" : "Импорт",
    "Export" : "Экспорт",
    "Help" : "Туслах"
},
"nplurals=2; plural=(n != 1);");
