OC.L10N.register(
    "news",
    {
    "Unread articles" : "مقال غير مقروء",
    "News" : "الأخبار",
    "Download" : "تنزيل",
    "Close" : "إغلاق",
    "Share" : "مشاركة",
    "Username" : "إسم المستخدم",
    "by" : "من قبل",
    "from" : "من",
    "Description" : "وصف",
    "right" : "يمين",
    "left" : "يسار",
    "Refresh" : "تحديث",
    "Web address" : "عنوان ويب",
    "Folder" : "مجلد",
    "New folder" : "مجلد جديد",
    "Folder name" : "اسم المجلد",
    "Go back" : "العودة",
    "Credentials" : "Credentials",
    "Password" : "كلمة السر",
    "New Folder" : "مجلد جديد",
    "Create" : "انشئ",
    "Rename" : "إعادة التسمية",
    "Newest first" : "الأحدث أولا",
    "Oldest first" : "الأقدم أولا",
    "Delete" : "حذف ",
    "Dismiss" : "تراجع",
    "Collapse" : "طوي",
    "Starred" : "معلّم بنجمة.",
    "All articles" : "جميع المقالات",
    "Settings" : "إعدادات",
    "Show all articles" : "أظهر جميع المواضيع",
    "Subscriptions (OPML)" : "اشتراك (OPML)",
    "Import" : "إدخال",
    "Export" : "تصدير",
    "Unread/Starred Articles" : "مقالات غير مقروءه/نجمة ",
    "Error when importing: file does not contain valid JSON" : "خطا عند الاستيراد: الملف لايحتوي على OPML صالح",
    "Help" : "المساعدة",
    "Keyboard shortcuts" : "اختصارات لوحة المفاتيح",
    "Documentation" : "التوثيق",
    "Report a bug" : "الإبلاغ عن عِلّة"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
