<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInit98dda2b31c9a21fbf48af09fbc7e0be4
{
    public static $files = array (
        '2cffec82183ee1cea088009cef9a6fc3' => __DIR__ . '/..' . '/ezyang/htmlpurifier/library/HTMLPurifier.composer.php',
    );

    public static $prefixLengthsPsr4 = array (
        'f' => 
        array (
            'fivefilters\\Readability\\' => 24,
        ),
        'R' => 
        array (
            'Riimu\\Kit\\PathJoin\\' => 19,
        ),
        'P' => 
        array (
            'Psr\\Http\\Message\\' => 17,
        ),
        'O' => 
        array (
            'OCA\\News\\' => 9,
        ),
        'M' => 
        array (
            'Masterminds\\' => 12,
        ),
        'L' => 
        array (
            'League\\Uri\\' => 11,
        ),
        'F' => 
        array (
            'FeedIo\\' => 7,
            'Favicon\\' => 8,
        ),
    );

    public static $prefixDirsPsr4 = array (
        'fivefilters\\Readability\\' => 
        array (
            0 => __DIR__ . '/..' . '/fivefilters/readability.php/src',
        ),
        'Riimu\\Kit\\PathJoin\\' => 
        array (
            0 => __DIR__ . '/..' . '/riimu/kit-pathjoin/src',
        ),
        'Psr\\Http\\Message\\' => 
        array (
            0 => __DIR__ . '/..' . '/psr/http-message/src',
        ),
        'OCA\\News\\' => 
        array (
            0 => __DIR__ . '/../..' . '/lib',
        ),
        'Masterminds\\' => 
        array (
            0 => __DIR__ . '/..' . '/masterminds/html5/src',
        ),
        'League\\Uri\\' => 
        array (
            0 => __DIR__ . '/..' . '/league/uri-interfaces/src',
            1 => __DIR__ . '/..' . '/league/uri/src',
        ),
        'FeedIo\\' => 
        array (
            0 => __DIR__ . '/..' . '/debril/feed-io/src/FeedIo',
        ),
        'Favicon\\' => 
        array (
            0 => __DIR__ . '/..' . '/arthurhoaro/favicon/src/Favicon',
        ),
    );

    public static $prefixesPsr0 = array (
        'H' => 
        array (
            'HTMLPurifier' => 
            array (
                0 => __DIR__ . '/..' . '/ezyang/htmlpurifier/library',
            ),
        ),
    );

    public static $classMap = array (
        'Composer\\InstalledVersions' => __DIR__ . '/..' . '/composer/InstalledVersions.php',
        'Net_URL2' => __DIR__ . '/..' . '/pear/net_url2/Net/URL2.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = ComposerStaticInit98dda2b31c9a21fbf48af09fbc7e0be4::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = ComposerStaticInit98dda2b31c9a21fbf48af09fbc7e0be4::$prefixDirsPsr4;
            $loader->prefixesPsr0 = ComposerStaticInit98dda2b31c9a21fbf48af09fbc7e0be4::$prefixesPsr0;
            $loader->classMap = ComposerStaticInit98dda2b31c9a21fbf48af09fbc7e0be4::$classMap;

        }, null, ClassLoader::class);
    }
}
