OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Zahteva je spodletela. Omrežna povezava trenutno ni na voljo!",
    "Request unauthorized. Are you logged in?" : "Zahteva ni ustrezno overjena. Ali ste prijavljeni?",
    "Token expired or app not enabled! Reload the page!" : "Žeton je pretekel ali pa program ni omogočen! Poskusite osvežiti stran!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Notranja napaka strežnika! Preverite datoteko data/nextcloud.log za podrobnosti!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Zahteva je spodletela! Okolje Nextcloud je trenutno v vzdrževalnem načinu!",
    "News feeds" : "Viri novic",
    "Unread articles" : "Neprebrani prispevki",
    "News" : "Novice",
    "News folders" : "Mape novic",
    "Shared with me" : "V souporabi z mano",
    "An RSS/Atom feed reader" : "Bralnik virov RSS/Atom",
    "Use system cron for updates" : "Za posodobitve uporabi sistemski program »cron«",
    "Disable this if you use a custom updater." : "Možnost onemogočite, če uporabljate posodabljalnik po meri.",
    "Maximum read count per feed" : "Največje število prikazanih virov",
    "Maximum redirects" : "Največje število preusmeritev",
    "How many redirects the feed fetcher should follow." : "Koliko preusmeritvam naj sledi bralnik virov",
    "Feed fetcher timeout" : "Pridobivanje vira je časovno poteklo",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Čas, namenjen nalaganju virov RSS in Atom. Če traja dlje je nalaganje virov prekinjeno.",
    "Explore Service URL" : "Razišči spletni naslov storitve",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Če je podan, bo prek tega naslova URL storitve potekala poizvedba za vire in njihov izbor. Za preklop v vgrajeno storitev določevanja, mora biti polje prazno.",
    "Update interval" : "Razmik posodobitev",
    "Interval in seconds in which the feeds will be updated." : "Časovni zamik v sekundah za posodabljanje spletnih virov.",
    "Download" : "Prejmi",
    "Close" : "Zapri",
    "Subscribe to" : "Naročnina na",
    "No articles available" : "Ni prispevkov",
    "No unread articles available" : "Ni neprebranih prispevkov",
    "Open website" : "Odpri spletišče",
    "Star article" : "Označi prispevek z zvezdico",
    "Unstar article" : "Odstrani zvezdico s prispevka",
    "Keep article unread" : "Obdrži kot neprebrano",
    "Remove keep article unread" : "Odstrani možnost ohranjanja prispevkov neprebranih",
    "Share" : "Souporaba",
    "Share with users" : "Souporaba z uporabniki",
    "Username" : "Uporabniško ime",
    "No users found" : "Ni najdenih uporabnikov",
    "Error while searching for users" : "Prišlo je do napake med iskanjem uporabnikov",
    "Share on social media" : "Objava na družbenem omrežju",
    "I wanted you to see this article" : "Priporočam ogled tega prispevka",
    "Check out this article" : "Preveri ta prispevek",
    "by" : "od",
    "from" : "od",
    "shared by" : "omogoča",
    "Play audio" : "Predvajaj zvok",
    "Download audio" : "Prejmi zvok",
    "Download video" : "Prejmi video",
    "Keyboard shortcut" : "Tipkovna bližnica",
    "Description" : "Opis",
    "right" : "desno",
    "Jump to next article" : "Skoči na naslednji prispevek",
    "left" : "levo",
    "Jump to previous article" : "Skoči na predhodni prispevek",
    "Toggle star article" : "Preklopi označevanje z zvezdico",
    "Star article and jump to next one" : "Označi prispevek z zvezdico in skoči na naslednjega",
    "Toggle keep current article unread" : "Preklopi ohranjanje prispevka kot neprebranega",
    "Open article in new tab" : "Odpri prispevek v novem zavihku",
    "Toggle expand article in compact view" : "Preklopi razširitev prispevka v skrčenem pogledu",
    "Refresh" : "Osveži",
    "Load next feed" : "Naloži naslednji vir",
    "Load previous feed" : "Naloži predhodni vir",
    "Load previous folder" : "Naloži predhodno mapo",
    "Load next folder" : "Naloži naslednjo mapo",
    "Scroll to active navigation entry" : "Pomakni se na predmet v žarišču",
    "Mark current article's feed/folder read" : "Označi trenutni vir kot prebran",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "V uporabi je ali način Ajax ali pa webcron, kar pomeni, da izbrani viri ne bodo posodobljeni!",
    "How to set up the operating system cron" : "Oglejte si navodila, kako nastaviti opravila cron operacijskega sistema. ↗",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Namesti je mogoče vzporedni posodabljalnik, ki uporablja vmesnik API programa News ↗.",
    "Subscribe" : "Naročilo",
    "Web address" : "Spletni naslov",
    "Feed exists already!" : "Vir že obstaja!",
    "Folder" : "Mapa",
    "No folder" : "Ni mape",
    "New folder" : "Nova mapa",
    "Folder name" : "Ime mape",
    "Go back" : "Nazaj",
    "Folder exists already!" : "Mapa že obstaja!",
    "Credentials" : "Poverila",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Osnovni overitveni podatki HTTP Auth morajo biti shranjeni nekodirani! Vsakdo z dostopom do podatkovne zbirke bo imel omogočen dostop!",
    "Password" : "Geslo",
    "Auto discover Feed" : "Samodejno odkrivanje Vira",
    "New Folder" : "Nova mapa",
    "Create" : "Ustvari",
    "Explore" : "Razišči",
    "Update failed more than 50 times" : "Posodobitev je spodletela več kot 50-krat",
    "Deleted feed" : "Izbrisan vir",
    "Undo delete feed" : "Razveljavi brisanje vira",
    "Rename" : "Preimenuj",
    "Menu" : "Meni",
    "Mark read" : "Označi kot prebrano",
    "Unpin from top" : "Odpni z vrha",
    "Pin to top" : "Pripni na vrh",
    "Newest first" : "najprej najnovejše",
    "Oldest first" : "najprej najstarejše",
    "Default order" : "Privzeta razvrstitev",
    "Enable full text" : "Omogoči polno besedilo",
    "Disable full text" : "Omogoči polno besedilo",
    "Unread updated" : "Neprebrano je posodobljeno",
    "Ignore updated" : "Prezri posodobljeno",
    "Open feed URL" : "Odpri naslov URL vira",
    "Delete" : "Izbriši",
    "Dismiss" : "Opusti",
    "Collapse" : "Skrči",
    "Deleted folder" : "Izbrisana mapa",
    "Undo delete folder" : "Razveljavi brisanje mape",
    "Starred" : "Z zvezdico",
    "All articles" : "Vsi prispevki",
    "Settings" : "Nastavitve",
    "Disable mark read through scrolling" : "Onemogoči označevanje prebranosti med drsenjem",
    "Compact view" : "Stisnjen pogled",
    "Expand articles on key navigation" : "Razširi prispevek s tipkovnim krmarjenjem",
    "Show all articles" : "Pokaži vse prispevke",
    "Reverse ordering (oldest on top)" : "Obrni razvrstitev (najstarejši na vrh)",
    "Subscriptions (OPML)" : "Naročnine (OPML)",
    "Import" : "Uvozi",
    "Export" : "Izvozi",
    "Error when importing: File does not contain valid OPML" : "Napaka med uvažanjem: datoteka ne vsebuje veljavnega zapisa OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Napaka med uvažanjem: datoteka OPML ne vsebuje niti virov niti map",
    "Unread/Starred Articles" : "Neprebrani/Označeni prispevki",
    "Error when importing: file does not contain valid JSON" : "Napaka uvoza: datoteka ne vsebuje veljavnih podatkov JSON.",
    "Help" : "Pomoč",
    "Keyboard shortcuts" : "Tipkovne bližnjice",
    "Documentation" : "Dokumentacija",
    "Report a bug" : "Pošlji poročilo o hrošču"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
