OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Non se realizou a solicitude, a conexión de rede non está dispoñíbel!",
    "Request unauthorized. Are you logged in?" : "Solicitude non autorizada. Está vostede autenticado?",
    "Token expired or app not enabled! Reload the page!" : "Ou ben caducou o testemuño ou a aplicación non está activada. Volva cargar a páxina!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Produciuse un erro interno do servidor! Verifique o ficheiro data/nextcloud.log para obter máis información!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Produciuse un fallo na solicitude, Nexcloud esta actualmente en modo mantemento!",
    "Unread articles" : "Artigos sen ler",
    "News" : "Novas",
    "Shared with me" : "Compartido comigo",
    "An RSS/Atom feed reader" : "Un lector de fontes RSS/Atom",
    "Use system cron for updates" : "Use o cron do sistema para as actualizacións",
    "Maximum read count per feed" : "Conta máxima de lidos por fonte",
    "Maximum redirects" : "Redireccionamentos máximos",
    "How many redirects the feed fetcher should follow." : "Cantos redirecionamentos debe seguir o recuperador de fontes.",
    "Feed fetcher timeout" : "Caducidade do recuperador",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Número máximo de segundos agardando por unha fonte RSS ou Atom para cargar; se lle leva máis tempo a actualización será cancelada.",
    "Explore Service URL" : "Examinar o URL de servizo",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Se é fornecido, este URL de servizo requirirase para amosar as fontes na sección de exame da fonte. Para amparar co servizo de exame propio, deixe baldeira esta entrada.",
    "Update interval" : "Intervalo de actualización",
    "Interval in seconds in which the feeds will be updated." : "Intervalo, en segundos, no que se actualizarán as fontes.",
    "Download" : "Descargar",
    "Close" : "Pechar",
    "Subscribe to" : "Subscribirse a",
    "No articles available" : "Non hai artigos dispoñíbeis",
    "No unread articles available" : "Non hai artigos sen ler dispoñíbeis",
    "Open website" : "Abrir o sitio web",
    "Star article" : "Marcar artigo",
    "Unstar article" : "Desmarcar artigo",
    "Keep article unread" : "Conservar o artigo como non lido",
    "Remove keep article unread" : "Retirar a marca de artigo sen ler",
    "Share" : "Compartir",
    "Username" : "Nome de usuario",
    "No users found" : "Non se atoparon usuarios",
    "by" : "por",
    "from" : "dende",
    "Play audio" : "Reproducir son",
    "Download audio" : "Descargar son",
    "Download video" : "Descargar video",
    "Keyboard shortcut" : "Atallo de teclado",
    "Description" : "Descrición",
    "right" : "dereita",
    "Jump to next article" : "Ir ao seguinte artigo",
    "left" : "esquerda",
    "Jump to previous article" : "Saltar ao artigo anterior",
    "Toggle star article" : "Marcar/desmarcar os artigos con estrela",
    "Star article and jump to next one" : "Destacar o artigo e ir ao seguinte",
    "Toggle keep current article unread" : "Conservar/retirar o artigo actual como non lido",
    "Open article in new tab" : "Abrir o artigo nunha nova lapela",
    "Toggle expand article in compact view" : "Expandir/contraer o artigo en vista compacta",
    "Refresh" : "Actualizar",
    "Load next feed" : "Cargar a seguinte fonte",
    "Load previous feed" : "Cargar a fonte anterior",
    "Load previous folder" : "Cargar o cartafol anterior",
    "Load next folder" : "Cargar o seguinte cartafol",
    "Scroll to active navigation entry" : "Desprazar ata a entrada de navegación activa",
    "Mark current article's feed/folder read" : "Marcar o actual artigo de fonte/cartafol como lido",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Detectouse o modo Ajax ou webcron! As súas fontes non van ser actualizadas!",
    "How to set up the operating system cron" : "Cómo configurar o cron do sistema operativo",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instala e configura un actualizador paralelo máis rápido que utiliza a API de actualización da aplicación Novas",
    "Subscribe" : "Subscribirse",
    "Web address" : "Enderezo web",
    "Feed exists already!" : "Esta fonte de novas xa existe!",
    "Folder" : "Cartafol",
    "No folder" : "Sen cartafol",
    "New folder" : "Novo cartafol",
    "Folder name" : "Nome do cartafol",
    "Go back" : "Volver",
    "Folder exists already!" : "Xa existe o cartafol!",
    "Credentials" : "Credenciais",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "As credenciais para HTTP Basic Auth deben estar gardadas sen cifrar! Calquera persoa con acceso ao servidor poderá acceder a elas!",
    "Password" : "Contrasinal",
    "New Folder" : "Novo cartafol",
    "Create" : "Crear",
    "Explore" : "Examinar",
    "Update failed more than 50 times" : "A actualización fallou máis de 50 veces.",
    "Deleted feed" : "Fonte eliminada",
    "Undo delete feed" : "Desfacer a eliminación da fonte",
    "Rename" : "Renomear",
    "Menu" : "Menú",
    "Mark read" : "Marcar como lido",
    "Unpin from top" : "Soltar de enriba",
    "Pin to top" : "Fixar enriba",
    "Newest first" : "Primeiro o máis recente",
    "Oldest first" : "Primeiro o máis antigo",
    "Default order" : "Orde predeterminado",
    "Enable full text" : "Activar o texto completo",
    "Disable full text" : "Desactivar o texto completo",
    "Unread updated" : "Actualización non lida",
    "Ignore updated" : "Ignorar actualizados",
    "Open feed URL" : "Abrir o URL da fonte",
    "Delete" : "Eliminar",
    "Dismiss" : "Rexeitar",
    "Collapse" : "Contraer",
    "Deleted folder" : "Eliminar cartafol",
    "Undo delete folder" : "Desfacer a eliminación do cartafol",
    "Starred" : "Destacado",
    "All articles" : "Todos os artigos",
    "Settings" : "Axustes",
    "Disable mark read through scrolling" : "Desactivar o marcado como lido co desprazamento",
    "Compact view" : "Vista compacta",
    "Expand articles on key navigation" : "Expandir artigos na tecla de navegación",
    "Show all articles" : "Amosar todos os artigos",
    "Reverse ordering (oldest on top)" : "Ordenado inverso (máis vellos enriba)",
    "Subscriptions (OPML)" : "Subscricións (OPML)",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Error when importing: File does not contain valid OPML" : "Erro durante a importación: O ficheiro non contén OPML correcto",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Produciuse un erro ao importar: OPML non contén fontes ou cartafoles",
    "Unread/Starred Articles" : "Artigos destacados ou sen ler",
    "Error when importing: file does not contain valid JSON" : "Produciuse un erro ao importar: o ficheiro non contén un JSON correcto",
    "Help" : "Axuda",
    "Keyboard shortcuts" : "Atallos de teclado",
    "Documentation" : "Documentación",
    "Report a bug" : "Informar dun fallo"
},
"nplurals=2; plural=(n != 1);");
