OC.L10N.register(
    "news",
    {
    "Download" : "12",
    "Close" : "Ýap",
    "Share" : "Paýlaş",
    "Username" : "Ulanyjy ady",
    "Refresh" : "Täzelemek",
    "New folder" : "Täze papka döretmek",
    "Folder name" : "Papkanyň ady",
    "Password" : "Açarsöz",
    "Create" : "Dörediň",
    "Rename" : "Adyny üýtgetmek",
    "Newest first" : "Täze ilkinji",
    "Oldest first" : "Ilki bilen iň köne",
    "Delete" : "Pozmak",
    "Dismiss" : "Ýapmak.",
    "Settings" : "Sazlamalar",
    "Help" : "Kömek"
},
"nplurals=2; plural=(n != 1);");
