OC.L10N.register(
    "news",
    {
    "Unread articles" : "អត្ថបទ​ដែល​មិន​ទាន់​អាន",
    "Download" : "ទាញយក",
    "Close" : "បិទ",
    "Share" : "ចែក​រំលែក",
    "Username" : "ឈ្មោះ​អ្នកប្រើ",
    "by" : "ដោយ",
    "from" : "ពី",
    "Description" : "ការ​អធិប្បាយ",
    "right" : "ខាង​ស្ដាំ",
    "left" : "ខាង​ឆ្វេង",
    "Folder" : "ថត",
    "New folder" : "ថត​ថ្មី",
    "Folder name" : "ឈ្មោះ​ថត",
    "Credentials" : "Credentials",
    "Password" : "ពាក្យសម្ងាត់",
    "Create" : "បង្កើត",
    "Rename" : "ប្ដូរ​ឈ្មោះ",
    "Delete" : "លុប",
    "Collapse" : "បត់បង្រួម",
    "Starred" : "បាន​ដាក់​ផ្កាយ",
    "All articles" : "អត្ថបទ​ទាំង​អស់",
    "Settings" : "ការកំណត់",
    "Subscriptions (OPML)" : "ការ​តាមដាន (OPML)",
    "Import" : "នាំយកចូល",
    "Export" : "នាំចេញ",
    "Unread/Starred Articles" : "អត្ថបទ​ដែល​មិន​បាន​អាន ឬ​បាន​ដាក់​ផ្កាយ",
    "Error when importing: file does not contain valid JSON" : "កំហុស​ពេល​នាំ​ចូល៖ ឯកសារ​មិន​មាន JSON ត្រឹម​ត្រូវ",
    "Help" : "ជំនួយ",
    "Documentation" : "កម្រង​ឯកសារ"
},
"nplurals=1; plural=0;");
