OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Forespørsel mislyktes, nettverksforbindelse utilgjengelig!",
    "Request unauthorized. Are you logged in?" : "Forespørsel uautorisert. Er du logget inn?",
    "Token expired or app not enabled! Reload the page!" : "Nøkkel utløpt eller app ikke aktivert! Last siden på nytt!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Intern feil! Sjekk dine data/nextcloud.log fil for mer informasjon.",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Forespørsel mislyktes, Nextcloud er i vedlikeholdsmodus!",
    "Unread articles" : "Uleste artikler",
    "News" : "Nyheter",
    "Shared with me" : "Delt med meg",
    "An RSS/Atom feed reader" : "En RSS/Atom-leser",
    "Use system cron for updates" : "Bruk system-cron for oppdateringer",
    "Maximum read count per feed" : "Maksimalt antall lest pr. strøm",
    "Maximum redirects" : "Maksimalt antall videresendinger",
    "Feed fetcher timeout" : "Tidsavbrudd for henting av strøm",
    "Explore Service URL" : "URL for utforskertjeneste",
    "Download" : "Last ned",
    "Close" : "Lukk",
    "No articles available" : "Ingen artikler tilgjengelig",
    "No unread articles available" : "Ingen uleste artikler tilgjengelig",
    "Open website" : "Åpne nettside",
    "Star article" : "Merk artikkelen",
    "Unstar article" : "Fjern merking av artikkelen",
    "Keep article unread" : "Behold artikkelen ulest",
    "Remove keep article unread" : "Fjern behold artikkelen ulest",
    "Share" : "Del",
    "Username" : "Brukernavn",
    "by" : "av",
    "from" : "fra",
    "Play audio" : "Spill lyd",
    "Download audio" : "Last ned lyd",
    "Download video" : "Last ned video",
    "Keyboard shortcut" : "Hurtigtast",
    "Description" : "Beskrivelse",
    "right" : "høyre",
    "Jump to next article" : "Gå til neste artikkel",
    "left" : "venstre",
    "Jump to previous article" : "Gå til forrige artikkel",
    "Toggle star article" : "Veksle stjernemerking av artikkel",
    "Star article and jump to next one" : "Stjernemerk artikkel og gå til neste",
    "Toggle keep current article unread" : "Veksle å beholde denne artikkelen ulest",
    "Open article in new tab" : "Åpne artikkel i ny fane",
    "Toggle expand article in compact view" : "Veksle ekspandering av artikkel i kompakt visning",
    "Refresh" : "Oppdater",
    "Load next feed" : "Last neste strøm",
    "Load previous feed" : "Last forrige strøm",
    "Load previous folder" : "Last forrige mappe",
    "Load next folder" : "Last neste mappe",
    "Scroll to active navigation entry" : "Bla til aktiv navigeringspost",
    "Mark current article's feed/folder read" : "Merk denne artikkelens strøm/mappe som lest",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax eller webcron-metode påvist! Strømmene dine vil ikke bli oppdaterte!",
    "How to set up the operating system cron" : "Hvordan sette opp operativsystemets Cron",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Installer og sett opp en raskere parallel oppdaterer som bruker nyhetsappens oppdaterings-API",
    "Subscribe" : "Abonner",
    "Web address" : "Internettadresse",
    "Feed exists already!" : "Strømmen finnes allerede!",
    "Folder" : "Mappe",
    "No folder" : "Ingen mappe",
    "New folder" : "Ny mappe",
    "Folder name" : "Mappenavn",
    "Go back" : "Gå tilbake",
    "Folder exists already!" : "Mappe finnes allerede!",
    "Credentials" : "Påloggingsdetaljer",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Detaljer for HTTP Basic Auth må lagres ukryptert! Alle med tilgang til serveren eller databasen vil være i stand til å nå dem!",
    "Password" : "Passord",
    "New Folder" : "Ny mappe",
    "Create" : "Opprett",
    "Explore" : "Utforsk",
    "Update failed more than 50 times" : "Oppdatering mislyktes mer enn 50 ganger",
    "Deleted feed" : "Slettet strøm",
    "Undo delete feed" : "Angre sletting av strøm",
    "Rename" : "Gi nytt navn",
    "Menu" : "Meny",
    "Mark read" : "Merk som lest",
    "Unpin from top" : "Fjern feste fra topp",
    "Pin to top" : "Fest til topp",
    "Newest first" : "Nyeste først",
    "Oldest first" : "Eldste først",
    "Default order" : "Forvalgt rekkefølge",
    "Enable full text" : "Skru på fulltekst",
    "Disable full text" : "Skru av fulltekst",
    "Unread updated" : "Uleste oppdatert",
    "Ignore updated" : "Ignorer oppdaterte",
    "Open feed URL" : "Åpne nyhetsnettadresse",
    "Delete" : "Slett",
    "Dismiss" : "Forkast",
    "Collapse" : "Skjul",
    "Deleted folder" : "Slettet mappe",
    "Undo delete folder" : "Angre sletting av mappe",
    "Starred" : "Merket",
    "All articles" : "Alle artikler",
    "Settings" : "Innstillinger",
    "Disable mark read through scrolling" : "Slå av merk som lest ved blading",
    "Compact view" : "Kompakt visning",
    "Expand articles on key navigation" : "Ekspander artikler ved tastaturnavigering",
    "Show all articles" : "Vis alle artikler",
    "Reverse ordering (oldest on top)" : "Omvendt sortering (elste øverst)",
    "Subscriptions (OPML)" : "Abonnement (OPML)",
    "Import" : "Importer",
    "Export" : "Eksporter",
    "Error when importing: File does not contain valid OPML" : "Feil under importering: Filen inneholder ikke gyldig OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Feil ved import: OPML inneholder hverken strømmer eller mapper",
    "Unread/Starred Articles" : "Uleste/merkede artikler",
    "Error when importing: file does not contain valid JSON" : "Feil under importering: Filen inneholder ikke gyldig JSON",
    "Help" : "Hjelp",
    "Keyboard shortcuts" : "Tastatursnarveier",
    "Documentation" : "Dokumentasjon",
    "Report a bug" : "Rapporter en feil"
},
"nplurals=2; plural=(n != 1);");
