OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "A solicitação falhou, conexão de rede indisponível!",
    "Request unauthorized. Are you logged in?" : "Solicitação não autorizada. Você está logado?",
    "Request forbidden. Are you an administrator?" : "Pedido proibido. Você é um administrador?",
    "Token expired or app not enabled! Reload the page!" : "Token expirado ou aplicativo não habilitado! Recarregue a página!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Erro interno do servidor! Verifique o arquivo data/nextcloud.log para obter informações adicionais.",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "A solicitação falhou pois o Nextcloud está em modo de manutenção!",
    "News feeds" : "Alimentador de notícias",
    "Unread articles" : "Artigos não lidos",
    "News" : "Notícias",
    "News folders" : "Pastas de notícias",
    "Shared with me" : "Compartilhado comigo",
    "An RSS/Atom feed reader" : "Um leitor de RSS/Atom",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Um aplicativo leitor de feed RSS/Atom para Nextcloud\n\n- 📲 Sincronize seus feeds com vários dispositivos móveis ou desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Atualizações automáticas de seus feeds de notícias\n- 🆓 Gratuito e de código aberto sob AGPLv3, sem anúncios ou funções premium\n\n**Atualmente, o Cron do sistema é necessário para que este aplicativo funcione**\n\nAtualmente, o Cron do sistema é necessário para que este aplicativo funcione [here](https://nextcloud.github.io/news/install/#dependencies)\n\nO Changelog está disponível [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreiar um [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCriar uma [feature request](https://github.com/nextcloud/news/discussions/new)\n\nRelatório [feed issue](https://github.com/nextcloud/news/discussions/new)",
    "Use system cron for updates" : "Usar o sistema Cron para atualizações",
    "Disable this if you use a custom updater." : "Desative isso se você usar um atualizador personalizado. ",
    "Maximum read count per feed" : "O número máximo de leituras por feed",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Define a quantidade máxima de artigos que podem ser lidos por feed que não serão excluídos pelo trabalho de limpeza; se artigos antigos reaparecerem após serem lidos, aumente este valor; valores negativos, como -1, desativarão esse recurso.",
    "Delete unread articles automatically" : "Remover artigos não-lidos automaticamente",
    "Enable this if you also want to delete unread articles." : "Habilite se você desejar remover artigos não lidos.",
    "Maximum redirects" : "Redirecionamentos máximos",
    "How many redirects the feed fetcher should follow." : "Quantos redirecionamentos o alimentador de feed deve seguir.",
    "Feed fetcher timeout" : "Tempo limite do alimentador de feed",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "O número máximo de segundos para esperar por um feed RSS ou Atom carregar; se ele demorar muito a atualização será cancelada.",
    "Explore Service URL" : "Explorar Serviços URL",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Se fornecido, a URL deste serviço será consultada para exibir os feeds na seção explorar feed. Para voltar ao serviço de exploração integrado, deixe esta entrada vazia.",
    "Update interval" : "Intervalo de atualização",
    "Interval in seconds in which the feeds will be updated." : "Intervalo em segundos em que os feeds serão atualizados.",
    "Successfully updated news configuration" : "Configuração de notícias atualizada com sucesso",
    "Unable to update news config" : "Não foi possível atualizar a configuração de notícias",
    "Download" : "Baixar",
    "Close" : "Fechar",
    "Subscribe to" : "Inscrever-se em",
    "No articles available" : "Não há artigos disponíveis",
    "No unread articles available" : "Não há artigos disponíveis não lidos",
    "Open website" : "Abrir website",
    "Star article" : "Destacar artigo",
    "Unstar article" : "Excluir destaque do artigo",
    "Keep article unread" : "Manter artigo não lido",
    "Remove keep article unread" : "Excluir manter artigo não lido",
    "Share" : "Compartilhar",
    "Share with users" : "Compartilhar com usuários",
    "Username" : "Nome de usuário",
    "No users found" : "Nenhum usuário encontrado",
    "Error while searching for users" : "Erro ao pesquisar usuários",
    "Share on social media" : "Compartilhe nas redes sociais",
    "I wanted you to see this article" : "Eu queria que você visualizasse este artigo",
    "Check out this article" : "Confira este artigo",
    "by" : "por",
    "from" : "de",
    "shared by" : "compartilhado por",
    "Play audio" : "Reproduzir áudio",
    "Download audio" : "Baixar áudio",
    "Download video" : "Baixar vídeo",
    "Keyboard shortcut" : "Atalhos do teclado",
    "Description" : "Descrição",
    "right" : "direita",
    "Jump to next article" : "Avançar para o próximo artigo",
    "left" : "esquerda",
    "Jump to previous article" : "Voltar para o artigo anterior",
    "Toggle star article" : "Alternar destaque do arquivo",
    "Star article and jump to next one" : "Destacar artigo e ir para próximo",
    "Toggle keep current article unread" : "Alternar manter o presente artigo não lido",
    "Open article in new tab" : "Abrir o artigo em nova aba",
    "Toggle expand article in compact view" : "Alternar expandir artigo na visão compacta",
    "Refresh" : "Atualizar",
    "Load next feed" : "Carregar novo feed",
    "Load previous feed" : "Carregar feed anterior",
    "Load previous folder" : "Carregar pasta anterior",
    "Load next folder" : "Carregar nova pasta",
    "Scroll to active navigation entry" : "Rolar para ativar a navegação",
    "Mark current article's feed/folder read" : "Marcar o feed/pasta atual como lido",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Modo ajax ou webcron detectado! Seus feeds não serão atualizados!",
    "How to set up the operating system cron" : "Como configurar o Cron do sistema operacional",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instale e configure um atualizador rápido paralelo que usa os novos aplicativos API para atualizar",
    "Subscribe" : "Assinar",
    "Web address" : "Endereço web",
    "Feed exists already!" : "Este feed já existe!",
    "Folder" : "Pasta",
    "No folder" : "Nenhuma pasta",
    "New folder" : "Nova pasta",
    "Folder name" : "Nome da pasta",
    "Go back" : "Retornar",
    "Folder exists already!" : "Esta pasta já existe!",
    "Credentials" : "Credenciais",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Credenciais Básicas de Autenticação HTTP devem ser armazenadas sem criptografia! Todos com acesso ao servidor ou banco de dados serão capazes de acessá-los!",
    "Password" : "Senha",
    "Auto discover Feed" : "Auto descoberta de alimentador",
    "New Folder" : "Nova pasta",
    "Create" : "Criar",
    "Explore" : "Explorar",
    "Update failed more than 50 times" : "A atualização falhou mais de 50 vezes",
    "Deleted feed" : "Feed removido",
    "Undo delete feed" : "Desfazer exclusão de feed",
    "Rename" : "Renomear",
    "Menu" : "Menu",
    "Mark read" : "Marcar como lido",
    "Unpin from top" : "Tirar  destacados no topo",
    "Pin to top" : "Destacados no topo",
    "Newest first" : "Mais recentes primeiro",
    "Oldest first" : "Mais antigos primeiro",
    "Default order" : "Ordem padrão",
    "Enable full text" : "Habilita texto completo",
    "Disable full text" : "Desabilitar texto completo",
    "Unread updated" : "Não lidos atualizados",
    "Ignore updated" : "Ignorar atualizado",
    "Open feed URL" : "Abrir URL do feed",
    "Delete" : "Excluir",
    "Dismiss" : "Rejeitar",
    "Collapse" : "Esconder",
    "Deleted folder" : "Pasta excluída",
    "Undo delete folder" : "Desfazer a exclusão de pasta",
    "Starred" : "Destacado",
    "All articles" : "Todos os artigos",
    "Settings" : "Configurações",
    "Disable mark read through scrolling" : "Desativar a marca de lido durante a rolagem",
    "Compact view" : "Versão reduzida",
    "Expand articles on key navigation" : "Expandir artigos sobre tecla de navegação",
    "Show all articles" : "Exibir todos os artigos",
    "Reverse ordering (oldest on top)" : "Ordem inversa (mais antigo no topo)",
    "Subscriptions (OPML)" : "Assinaturas (OPML) ",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Error when importing: File does not contain valid OPML" : "Erro ao importar: Arquivo não contem um OPML válido",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Erro ao importar: OPML não contêm feed nem pastas",
    "Unread/Starred Articles" : "Artigos destacados/não lidos",
    "Error when importing: file does not contain valid JSON" : "Erro ao importar: arquivo não contém um JSON válido",
    "Help" : "Ajuda",
    "Keyboard shortcuts" : "Atalhos de teclado",
    "Documentation" : "Documentação",
    "Report a bug" : "Reportar um erro"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
