OC.L10N.register(
    "news",
    {
    "Unread articles" : "Oxunulmamış məqalə",
    "Download" : "Yüklə",
    "Close" : "Bağla",
    "Share" : "Paylaş",
    "Username" : "İstifadəçi adı",
    "by" : "onunla",
    "from" : "ondan",
    "Description" : "Açıqlanma",
    "right" : "Sağ",
    "left" : "Sol",
    "Refresh" : "Yenilə",
    "Folder" : "Qovluq",
    "New folder" : "Yeni qovluq",
    "Folder name" : "Qovluq adı",
    "Credentials" : "Səlahiyyətlər",
    "Password" : "Şifrə",
    "Create" : "Yarat",
    "Rename" : "Adı dəyiş",
    "Delete" : "Sil",
    "Collapse" : "Yığılma",
    "Starred" : "Ulduzlu",
    "All articles" : "Bütün məqalələr",
    "Settings" : "Quraşdırmalar",
    "Subscriptions (OPML)" : "Abunəliklər(OPML)",
    "Import" : "Əlavə et",
    "Export" : "Çıxarış",
    "Unread/Starred Articles" : "Oxunulmamış/Ulduzlanmış məqalələr",
    "Error when importing: file does not contain valid JSON" : "Yüklənmədə səhv: faylda düzgün JSON yoxdur",
    "Help" : "Kömək",
    "Documentation" : "Sənədlər"
},
"nplurals=2; plural=(n != 1);");
