OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Pedido falhou, ligação à rede indisponível!",
    "Request unauthorized. Are you logged in?" : "Pedido não autorizado. Fez o login?",
    "Token expired or app not enabled! Reload the page!" : "Token expirou ou aplicação não ativa! Recarregue a página!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Erro interno do servidor. Veja por favor o ficheiro na pasta data/nextcloud.log para mais informações!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Falha no pedido, Nextcloud está atualmente em modo de manutenção!",
    "News feeds" : "Feeds de notícias",
    "Unread articles" : "Artigos não lidos",
    "News" : "Notícias",
    "News folders" : "Novas pastas",
    "Shared with me" : "Partilhadas comigo",
    "An RSS/Atom feed reader" : "Leitor de feeds RSS/Atom",
    "Use system cron for updates" : "Use o programador do sistema para as atualizações",
    "Disable this if you use a custom updater." : "Desative isto se é um sistema de atualizações feito à medida.",
    "Maximum read count per feed" : "Número máximo de leituras por feed",
    "Maximum redirects" : "Máximo de redirecionamentos",
    "Feed fetcher timeout" : "A obtenção do feed expirou",
    "Explore Service URL" : "Explorar Serviço URL",
    "Update interval" : "Intervalo de actualização",
    "Download" : "Transferir",
    "Close" : "Fechar",
    "No articles available" : "Não há artigos disponíveis",
    "No unread articles available" : "Não há artigos por ler disponíveis",
    "Open website" : "Abrir site da web",
    "Star article" : "Destacar artigo",
    "Unstar article" : "Retirar destaque",
    "Keep article unread" : "Marcar artigo como não lido",
    "Remove keep article unread" : "Remover marcação de artigo não lido",
    "Share" : "Partilhar",
    "Username" : "Nome de utilizador",
    "No users found" : "Não foram encontrados utilizadores",
    "by" : "por",
    "from" : "de",
    "shared by" : "partilhado por",
    "Play audio" : "Reproduzir áudio",
    "Download audio" : "Transferir áudio",
    "Download video" : "Transferir vídeo",
    "Keyboard shortcut" : "Atalho de teclado",
    "Description" : "Descrição",
    "right" : "direita",
    "Jump to next article" : "Ir para o artigo seguinte",
    "left" : "esquerda",
    "Jump to previous article" : "Ir para o artigo anterior",
    "Toggle star article" : "Alternar estrela do artigo",
    "Star article and jump to next one" : "Destacar artigo e saltar para o próximo",
    "Toggle keep current article unread" : "Alternar manter o artigo atual como não lido",
    "Open article in new tab" : "Abrir artigo num separador novo",
    "Toggle expand article in compact view" : "Alternar expandir artigo na visulaização compacta",
    "Refresh" : "Atualizar",
    "Load next feed" : "Carregar feed seguinte",
    "Load previous feed" : "Carregar feed anterior",
    "Load previous folder" : "Carregar pasta anterior",
    "Load next folder" : "Carregar pasta seguinte",
    "Scroll to active navigation entry" : "Vá até a entrada de navegação ativa",
    "Mark current article's feed/folder read" : "Marcar a pasta/feed do artigo atual como lida",
    "How to set up the operating system cron" : "Como configurar o cron no sistema operativo",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instale e configure um actualizador paralelo mais rápido que use a API de actualizações da aplicação Notícias",
    "Subscribe" : "Subscrever",
    "Web address" : "Endereço da Web",
    "Feed exists already!" : "A feed já existe!",
    "Folder" : "Pasta",
    "No folder" : "Sem Pasta",
    "New folder" : "Nova Pasta",
    "Folder name" : "Nome da pasta",
    "Go back" : "Voltar",
    "Folder exists already!" : "A pasta já existe!",
    "Credentials" : "Credenciais",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "As credenciais de autenticação básica HTTP têm de ser armazenadas de forma não encriptada. Qualquer pessoa com acesso ao servidor ou base de dados poderá vê-las!",
    "Password" : "Senha",
    "New Folder" : "Nova Pasta",
    "Create" : "Criar",
    "Explore" : "Explorar",
    "Update failed more than 50 times" : "A atualização falhou mais de 50 vezes",
    "Deleted feed" : "Apagar feed",
    "Undo delete feed" : "Desfazer apagar a feed",
    "Rename" : "Renomear",
    "Menu" : "Menu",
    "Mark read" : "Marcar como lido",
    "Newest first" : "Recentes primeiro",
    "Oldest first" : "Antigos primeiro",
    "Delete" : "Apagar",
    "Dismiss" : "Rejeitar",
    "Collapse" : "Expandir",
    "Deleted folder" : "Apagar pasta",
    "Undo delete folder" : "Anular apagar pasta",
    "Starred" : "Marcado",
    "All articles" : "Todos os artigos",
    "Settings" : "Definições",
    "Disable mark read through scrolling" : "Desativar marcar ler através de movimento",
    "Compact view" : "Visualização Compacta",
    "Expand articles on key navigation" : "Expandir artigos ao navegar por tecla",
    "Show all articles" : "Mostrar todos os artigos",
    "Reverse ordering (oldest on top)" : "Ordem inversa (antigos no topo)",
    "Subscriptions (OPML)" : "Subscrições (OPML)",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Erro na importção: OPML não contém nem feeds nem pastas",
    "Unread/Starred Articles" : "Artigos Não Lidos/Classificados",
    "Error when importing: file does not contain valid JSON" : "Ocorreu um erro na importação: o ficheiro não contém JSON válido",
    "Help" : "Ajuda",
    "Keyboard shortcuts" : "Atalhos de teclado",
    "Documentation" : "Documentação",
    "Report a bug" : "Reportar um erro"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
