OC.L10N.register(
    "news",
    {
    "Download" : "ດາວໂຫລດ",
    "Close" : "ປິດ",
    "Share" : "ແບ່ງປັນ",
    "Username" : "ຊື່ຜູ້ໃຊ້",
    "Refresh" : "Refresh",
    "Folder" : "ໂຟນເດີ",
    "New folder" : "ໂຟນເດີໃຫມ່",
    "Folder name" : "ຊື່ໂຟນເດີ",
    "Credentials" : "ຂໍມູນປະຈຳຕົວ",
    "Password" : "ລະຫັດຜ່ານ",
    "Create" : "ສ້າງ",
    "Rename" : "ປ່ຽນຊື່",
    "Newest first" : "ໃໝ່ທີ່ສຸດກ່ອນ",
    "Oldest first" : "ເກົ່າທີ່ສຸດກ່ອນ",
    "Delete" : "ລຶບ",
    "Dismiss" : "ຍົກເລີກ",
    "Settings" : "ການຕັ້ງຄ່າ",
    "Help" : "ການຊ່ວຍເຫຼືອ"
},
"nplurals=1; plural=0;");
