OC.L10N.register(
    "news",
    {
    "Download" : "Sider",
    "Close" : "Mdel",
    "Share" : "Bḍu",
    "Username" : "Isem n useqdac",
    "Refresh" : "Sismeḍ",
    "New folder" : "Akaram amaynut",
    "Password" : "Awal uffir",
    "Create" : "Snulfu-d",
    "Rename" : "Beddel isem",
    "Newest first" : "Imaynuten d imezwura",
    "Oldest first" : "Iqbuṛen d imezwura",
    "Delete" : "Kkes",
    "Dismiss" : "Agi",
    "Settings" : "Iɣewwaṛen",
    "Help" : "Tallalt"
},
"nplurals=2; plural=(n != 1);");
