OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Request failed, network connection unavailable!",
    "Request unauthorized. Are you logged in?" : "Request unauthorised. Are you logged in?",
    "Request forbidden. Are you an administrator?" : "Request forbidden. Are you an administrator?",
    "Token expired or app not enabled! Reload the page!" : "Token expired or app not enabled! Reload the page!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Internal server error! Please check your data/nextcloud.log file for additional information!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Request failed, Nextcloud is in currently in maintenance mode!",
    "News feeds" : "News feeds",
    "Unread articles" : "Unread articles",
    "News" : "News",
    "News folders" : "News folders",
    "Shared with me" : "Shared with me",
    "An RSS/Atom feed reader" : "An RSS/Atom feed reader",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)",
    "Use system cron for updates" : "Use system cron for updates",
    "Disable this if you use a custom updater." : "Disable this if you use a custom updater.",
    "Maximum read count per feed" : "Maximum read count per feed",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off.",
    "Delete unread articles automatically" : "Delete unread articles automatically",
    "Enable this if you also want to delete unread articles." : "Enable this if you also want to delete unread articles.",
    "Maximum redirects" : "Maximum redirects",
    "How many redirects the feed fetcher should follow." : "How many redirects the feed fetcher should follow.",
    "Feed fetcher timeout" : "Feed fetcher timeout",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted.",
    "Explore Service URL" : "Explore Service URL",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty.",
    "Update interval" : "Update interval",
    "Interval in seconds in which the feeds will be updated." : "Interval in seconds in which the feeds will be updated.",
    "Successfully updated news configuration" : "Successfully updated news configuration",
    "Unable to update news config" : "Unable to update news config",
    "Download" : "Download",
    "Close" : "Close",
    "Subscribe to" : "Subscribe to",
    "No articles available" : "No articles available",
    "No unread articles available" : "No unread articles available",
    "Open website" : "Open website",
    "Star article" : "Star article",
    "Unstar article" : "Unstar article",
    "Keep article unread" : "Keep article unread",
    "Remove keep article unread" : "Remove keep article unread",
    "Share" : "Share",
    "Share with users" : "Share with users",
    "Username" : "Username",
    "No users found" : "No users found",
    "Error while searching for users" : "Error while searching for users",
    "Share on social media" : "Share on social media",
    "I wanted you to see this article" : "I wanted you to see this article",
    "Check out this article" : "Check out this article",
    "by" : "by",
    "from" : "from",
    "shared by" : "shared by",
    "Play audio" : "Play audio",
    "Download audio" : "Download audio",
    "Download video" : "Download video",
    "Keyboard shortcut" : "Keyboard shortcut",
    "Description" : "Description",
    "right" : "right",
    "Jump to next article" : "Jump to next article",
    "left" : "left",
    "Jump to previous article" : "Jump to previous article",
    "Toggle star article" : "Toggle star article",
    "Star article and jump to next one" : "Star article and jump to next one",
    "Toggle keep current article unread" : "Toggle keep current article unread",
    "Open article in new tab" : "Open article in new tab",
    "Toggle expand article in compact view" : "Toggle expand article in compact view",
    "Refresh" : "Refresh",
    "Load next feed" : "Load next feed",
    "Load previous feed" : "Load previous feed",
    "Load previous folder" : "Load previous folder",
    "Load next folder" : "Load next folder",
    "Scroll to active navigation entry" : "Scroll to active navigation entry",
    "Mark current article's feed/folder read" : "Mark current article's feed/folder read",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax or webcron mode detected! Your feeds will not be updated!",
    "How to set up the operating system cron" : "How to set up the operating system cron",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Install and set up a faster parallel updater that uses the News app's update API",
    "Subscribe" : "Subscribe",
    "Web address" : "Web address",
    "Feed exists already!" : "Feed exists already!",
    "Folder" : "Folder",
    "No folder" : "No folder",
    "New folder" : "New folder",
    "Folder name" : "Folder name",
    "Go back" : "Go back",
    "Folder exists already!" : "Folder exists already!",
    "Credentials" : "Credentials",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!",
    "Password" : "Password",
    "Auto discover Feed" : "Auto discover Feed",
    "New Folder" : "New Folder",
    "Create" : "Create",
    "Explore" : "Explore",
    "Update failed more than 50 times" : "Update failed more than 50 times",
    "Deleted feed" : "Deleted feed",
    "Undo delete feed" : "Undo delete feed",
    "Rename" : "Rename",
    "Menu" : "Menu",
    "Mark read" : "Mark read",
    "Unpin from top" : "Unpin from top",
    "Pin to top" : "Pin to top",
    "Newest first" : "Newest first",
    "Oldest first" : "Oldest first",
    "Default order" : "Default order",
    "Enable full text" : "Enable full text",
    "Disable full text" : "Disable full text",
    "Unread updated" : "Unread updated",
    "Ignore updated" : "Ignore updated",
    "Open feed URL" : "Open feed URL",
    "Delete" : "Delete",
    "Dismiss" : "Dismiss",
    "Collapse" : "Collapse",
    "Deleted folder" : "Deleted folder",
    "Undo delete folder" : "Undo delete folder",
    "Starred" : "Starred",
    "All articles" : "All articles",
    "Settings" : "Settings",
    "Disable mark read through scrolling" : "Disable mark read through scrolling",
    "Compact view" : "Compact view",
    "Expand articles on key navigation" : "Expand articles on key navigation",
    "Show all articles" : "Show all articles",
    "Reverse ordering (oldest on top)" : "Reverse ordering (oldest on top)",
    "Subscriptions (OPML)" : "Subscriptions (OPML)",
    "Import" : "Import",
    "Export" : "Export",
    "Error when importing: File does not contain valid OPML" : "Error when importing: File does not contain valid OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Error when importing: OPML contains neither feeds nor folders",
    "Unread/Starred Articles" : "Unread/Starred Articles",
    "Error when importing: file does not contain valid JSON" : "Error when importing: file does not contain valid JSON",
    "Help" : "Help",
    "Keyboard shortcuts" : "Keyboard shortcuts",
    "Documentation" : "Documentation",
    "Report a bug" : "Report a bug"
},
"nplurals=2; plural=(n != 1);");
