OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Échec de la requête, connexion réseau indisponible !",
    "Request unauthorized. Are you logged in?" : "Requête non autorisée. Êtes-vous bien connecté ?",
    "Request forbidden. Are you an administrator?" : "Requête interdite. Avez-vous les droits administrateurs ?",
    "Token expired or app not enabled! Reload the page!" : "Le jeton a expiré ou l'application n'est pas activée ! Veuillez recharger la page !",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Erreur interne du serveur ! Veuillez consulter votre fichier data/nextcloud.log pour plus d'informations !",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "La requête a échoué, Nextcloud est actuellement en maintenance !",
    "News feeds" : "Flux d'actualités",
    "Unread articles" : "Articles non lus",
    "News" : "News",
    "News folders" : "Dossiers d'actualités",
    "Shared with me" : "Partagé avec moi",
    "An RSS/Atom feed reader" : "Un lecteur du flux RSS/Atom",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Un lecteur de flux RSS/Atom pour Nextcloud\n\n- 📲 Synchronisez vos flux sur plusieurs [clients](https://nextcloud.github.io/news/clients/) mobiles ou de bureau\n- 🔄 Mise à jour automatique de vox flux d'actualité\n- 🆓 Libre et open-source sous licence AGPLv3, sans publicité et sans fonctionnalités premium\n\n**L'utilisation du Cron système est requise pour le fonctionnement de cette application**\n\nLa liste des pré-requis est disponible [ici](https://nextcloud.github.io/news/install/#dependencies)\n\nLa journal de versions est consultable [ici](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nSignaler un [bug](https://github.com/nextcloud/news/issues/new/choose)\n\nDemander une [fonctionnalité](https://github.com/nextcloud/news/discussions/new)\n\nSignaler un [problème avec l'application](https://github.com/nextcloud/news/discussions/new)",
    "Use system cron for updates" : "Utiliser le « cron » du système pour les mises à jour",
    "Disable this if you use a custom updater." : "Désactivez ceci si vous utilisez un outil de mise à jour personnalisé.",
    "Maximum read count per feed" : "Nombre maximum de lecture par flux",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Définit le nombre maximum d’articles pouvant être lus par flux qui ne seront pas supprimés par la tâche de nettoyage ; si d'anciens articles réapparaissent après avoir été lus, augmentez cette valeur ; les valeurs négatives telles que -1 vont désactiver cette fonctionnalité.",
    "Delete unread articles automatically" : "Supprimer automatiquement les articles non lus",
    "Enable this if you also want to delete unread articles." : "Activez ceci si vous voulez aussi supprimer les articles non lus.",
    "Maximum redirects" : "Nombre maximal de redirections",
    "How many redirects the feed fetcher should follow." : "Nombre de redirections que le récupérateur de flux doit suivre",
    "Feed fetcher timeout" : "Délai d'attente maximum du récupérateur de flux",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Nombre maximal de secondes que peut prendre un flux RSS ou Atom pour être chargé. Si le délai est dépassé, la mise à jour sera annulée",
    "Explore Service URL" : "URL du service d'exploration",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Si indiquée, l'URL de ce service sera interrogée pour afficher les flux dans la section \"Explorer\". Pour revenir au service d'exploration par défaut, laissez ce champ vide.",
    "Update interval" : "Intervalle de mise à jour",
    "Interval in seconds in which the feeds will be updated." : "Fréquence à laquelle les flux seront mis à jour (en secondes).",
    "Successfully updated news configuration" : "Mise à jour réussie de la configuration des actualités",
    "Unable to update news config" : "Impossible de mettre à jour la configuration des actualités",
    "Download" : "Télécharger",
    "Close" : "Fermer",
    "Subscribe to" : "S'abonner à ",
    "No articles available" : "Aucun article disponible",
    "No unread articles available" : "Aucun article non lu disponible",
    "Open website" : "Ouvrir le site web",
    "Star article" : "Épingler l'article",
    "Unstar article" : "Désépingler l'article",
    "Keep article unread" : "Marquer l'article comme non lu",
    "Remove keep article unread" : "Marquer l'article comme lu",
    "Share" : "Partager",
    "Share with users" : "Partager avec les utilisateurs",
    "Username" : "Nom d'utilisateur",
    "No users found" : "Aucun utilisateur trouvé",
    "Error while searching for users" : "Erreur lors de la recherche d'utilisateurs",
    "Share on social media" : "Partager sur les réseaux sociaux",
    "I wanted you to see this article" : "Je souhaitais que vous lisiez cet article",
    "Check out this article" : "Consultez cet article",
    "by" : "par",
    "from" : "de",
    "shared by" : "Partagé par",
    "Play audio" : "Ecouter",
    "Download audio" : "Télécharger le fichier audio",
    "Download video" : "Télécharger la vidéo",
    "Keyboard shortcut" : "Raccourcis clavier",
    "Description" : "Description",
    "right" : "droite",
    "Jump to next article" : "Aller au prochain article",
    "left" : "gauche",
    "Jump to previous article" : "Aller à l'article précédent",
    "Toggle star article" : "Épingler/Désépingler l'article",
    "Star article and jump to next one" : "Épingler l'article et aller au suivant",
    "Toggle keep current article unread" : "Marquer l'article comme Lu/Non lu",
    "Open article in new tab" : "Ouvrir l'article dans un nouvel onglet",
    "Toggle expand article in compact view" : "Étendre/Réduire l'article",
    "Refresh" : "Rafraîchir",
    "Load next feed" : "Charger le flux suivant",
    "Load previous feed" : "Charger le flux précédent",
    "Load previous folder" : "Charger le dossier précédent",
    "Load next folder" : "Charger le dossier suivant",
    "Scroll to active navigation entry" : "Aller à l'élément actif",
    "Mark current article's feed/folder read" : "Marquer comme lu le flux / le dossier de l'article en cours",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Mode Ajax ou Webcron détecté ! Vos flux ne seront pas mis à jour !",
    "How to set up the operating system cron" : "Comment configurer le cron du système d'exploitation",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Installe et met en place un updater qui utilise la mise à jour API de l'application News",
    "Subscribe" : "S'abonner",
    "Web address" : "Adresse web",
    "Feed exists already!" : "Le flux existe déjà !",
    "Folder" : "Dossier",
    "No folder" : "Aucun dossier",
    "New folder" : "Nouveau dossier",
    "Folder name" : "Nom du dossier",
    "Go back" : "Revenir en arrière",
    "Folder exists already!" : "Le dossier existe déjà !",
    "Credentials" : "Informations d'identification",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Les informations d'identification HTTP Basic Auth doivent être stocké en clair ! Toute personne ayant accès au serveur ou à la base de données y aura accès !",
    "Password" : "Mot de passe",
    "Auto discover Feed" : "Flux de découverte automatique",
    "New Folder" : "Nouveau dossier",
    "Create" : "Créer",
    "Explore" : "Explorer",
    "Update failed more than 50 times" : "La tentative de mise à jour a échoué plus de 50 fois",
    "Deleted feed" : "Flux supprimé",
    "Undo delete feed" : "Annuler la suppression du flux",
    "Rename" : "Renommer",
    "Menu" : "Menu",
    "Mark read" : "Marquer comme lu",
    "Unpin from top" : "Désépingler du haut",
    "Pin to top" : "Épingler en haut",
    "Newest first" : "Le plus récent en premier",
    "Oldest first" : "Le plus ancien en premier",
    "Default order" : "Ordre par défaut",
    "Enable full text" : "Activer le texte intégral",
    "Disable full text" : "Désactiver le texte intégral",
    "Unread updated" : "Mise à jour non lue",
    "Ignore updated" : "Ignorer la sélection",
    "Open feed URL" : "Ouvrir l'URL du flux",
    "Delete" : "Supprimer",
    "Dismiss" : "Ignorer",
    "Collapse" : "Replier",
    "Deleted folder" : "Dossier supprimé",
    "Undo delete folder" : "Annuler la suppression du dossier",
    "Starred" : "Épinglés",
    "All articles" : "Tous les articles",
    "Settings" : "Paramètres",
    "Disable mark read through scrolling" : "Ne pas marquer les articles comme lus lors du parcours des listes",
    "Compact view" : "Vue compacte",
    "Expand articles on key navigation" : "Etendre les articles lors de la navigation avec le clavier",
    "Show all articles" : "Afficher tous les articles",
    "Reverse ordering (oldest on top)" : "Ordre inverse (les plus anciens en haut)",
    "Subscriptions (OPML)" : "Abonnements (OPML)",
    "Import" : "Importer",
    "Export" : "Exporter",
    "Error when importing: File does not contain valid OPML" : "Erreur lors de l'import : Le fichier spécifié n'est pas un fichier OPML valide",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Erreur à l'importation : OPML ne contient ni flux ni dossiers",
    "Unread/Starred Articles" : "Articles non lus / épinglés",
    "Error when importing: file does not contain valid JSON" : "Erreur lors de l'import : le fichier spécifié n'est pas un fichier JSON valide",
    "Help" : "Aide",
    "Keyboard shortcuts" : "Raccourcis clavier",
    "Documentation" : "Documentation",
    "Report a bug" : "Signaler un bogue"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
