OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Запит не вдався, немає мережевого з'єднання!",
    "Request unauthorized. Are you logged in?" : "Запит не авторизований. Ви увійшли в систему?",
    "Request forbidden. Are you an administrator?" : "Запит заборонено. Ви адміністратор?",
    "Token expired or app not enabled! Reload the page!" : "Термін дії токена закінчився або програма не задіяна! Перезагрузіть сторінку!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Внутрішня помилка сервера! Щоб отримати додаткову інформацію, перевірте файл data/nextcloud.log!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Помилка запиту, Nextcloud зараз у режимі обслуговування!",
    "Unread articles" : "Непрочитані статті",
    "Use system cron for updates" : "Використовуйте системний cron для оновлень",
    "Maximum read count per feed" : "Максимальна кількість статей для стрічки",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Визначає максимальну кількість статей, які можна прочитати на канал, які не будуть видалені під час завдання очищення; якщо старі статті знову з’являються після прочитання, збільште це значення; від'ємні значення, такі як -1, вимкнуть цю функцію.",
    "Maximum redirects" : "Максимум перенаправлень",
    "Feed fetcher timeout" : "Час очікування для завантажувача стрічки",
    "Explore Service URL" : "URL сервісу дослідження",
    "Successfully updated news configuration" : "Конфігурацію новин успішно оновлено",
    "Download" : "Звантажити",
    "Close" : "Закрити",
    "No articles available" : "Немає доступних статей",
    "No unread articles available" : "Немає непрочитаних записів",
    "Open website" : "Відкрити веб-сайт",
    "Star article" : "Позначити статтю",
    "Unstar article" : "Зняти позначку статті",
    "Keep article unread" : "Залишити статтю непрочитаною",
    "Remove keep article unread" : "Позначити статтю як прочитану",
    "Share" : "Спільний доступ",
    "Username" : "Ім'я користувача",
    "by" : "по",
    "from" : "З",
    "Play audio" : "Відтворення аудіо",
    "Download audio" : "Звантажити аудіо",
    "Download video" : "Звантажити відео",
    "Keyboard shortcut" : "Сполучення клавіш",
    "Description" : "Опис",
    "right" : "праворуч",
    "Jump to next article" : "Наступна стаття",
    "left" : "ліворуч",
    "Jump to previous article" : "Попередня стаття",
    "Toggle star article" : "Позначити статтю",
    "Star article and jump to next one" : "Позначити статтю та перейти до наступної",
    "Toggle keep current article unread" : "Залишити статтю непрочитаною",
    "Open article in new tab" : "Відкрити статтю в новій вкладці",
    "Toggle expand article in compact view" : "Переключити статтю в компактний режим",
    "Refresh" : "Оновити",
    "Load next feed" : "Завантажити наступну стрічку",
    "Load previous feed" : "Звантажити попередню стрічку",
    "Load previous folder" : "Звантажити попередній каталог",
    "Load next folder" : "Завантажити наступний каталог",
    "Scroll to active navigation entry" : "Перехід до обраного елементу",
    "Mark current article's feed/folder read" : "Позначити поточну видачу/каталог зі статтями прочитаними",
    "How to set up the operating system cron" : "Як налаштувати cron операційної системи",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Установіть і налаштуйте швидший паралельний засіб оновлення, який використовує API оновлення програми Новини",
    "Subscribe" : "Підписатися",
    "Web address" : "Веб адреса",
    "Feed exists already!" : "Стрічка вже існує !",
    "Folder" : "Каталог",
    "No folder" : "Відсутній каталог",
    "New folder" : "Новий каталог",
    "Folder name" : "Назва каталогу",
    "Go back" : "Повернутися назад",
    "Folder exists already!" : "Каталог вже існує !",
    "Credentials" : "Облікові дані",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Облікові дані HTTP Basic Auth повинні зберігатися незашифрованими! Усі, хто має доступ до сервера або бази даних, зможуть отримати до них доступ!",
    "Password" : "Пароль",
    "New Folder" : "Новий каталог",
    "Create" : "Створити",
    "Explore" : "Дослідити",
    "Update failed more than 50 times" : "Помилка оновлення понад 50 разів",
    "Deleted feed" : "Вилучена стрічка",
    "Undo delete feed" : "Скасувати вилучення стрічки",
    "Rename" : "Перейменувати",
    "Menu" : "Меню",
    "Mark read" : "Позначити як прочитане",
    "Unpin from top" : "Зняти закріплення",
    "Pin to top" : "Закріпити нагорі",
    "Newest first" : "Новіші спочатку",
    "Oldest first" : "Старіші спочатку",
    "Enable full text" : "Увімкнути повнотекстовий",
    "Disable full text" : "Вимкнути повнотекстовий",
    "Delete" : "Вилучити",
    "Dismiss" : "Припинити",
    "Collapse" : "Згорнути",
    "Deleted folder" : "Вилучений каталог",
    "Undo delete folder" : "Скасувати вилучення каталогу",
    "Starred" : "Помічені зірочкою",
    "All articles" : "Всі статті",
    "Settings" : "Налаштування",
    "Disable mark read through scrolling" : "Вимкнути читання поміток при прокрутці",
    "Compact view" : "Компактний вигляд",
    "Expand articles on key navigation" : "Розширенні артикули під час навігації по ключах",
    "Show all articles" : "Показати всі статті",
    "Reverse ordering (oldest on top)" : "Зворотний порядок (найстаріші зверху)",
    "Subscriptions (OPML)" : "Підписки (OPML)",
    "Import" : "Імпорт",
    "Export" : "Експорт",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Помилка під час імпорту: OPML не містить ані каналів, ані папок",
    "Unread/Starred Articles" : "Непрочитані/Вибрані статті",
    "Error when importing: file does not contain valid JSON" : "Помилка при імпорті: файл не містить дійсний JSON",
    "Help" : "Допомога",
    "Keyboard shortcuts" : "Сполучення клавіш",
    "Documentation" : "Документація",
    "Report a bug" : "Повідомити про помилку"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
