/**
 * Nextcloud - News
 *
 * This file is licensed under the Affero General Public License version 3 or
 * later. See the COPYING file.
 *
 * @author Bernhard Posselt <dev@bernhard-posselt.com>
 * @copyright Bernhard Posselt 2014
 */
#app-navigation {
    overflow-y: hidden !important;
}

/* add new feed or folder */
/* button */
#app-navigation .add-new .heading {
    height: 44px;
    width: 100%;
}

#app-navigation .add-new .heading:hover {
    background-color: var(--color-background-darker);
}

#app-navigation .add-new .heading button {
    padding: 0 0 0 44px;
    line-height: 44px;
    width: 100%;
    border: 0;
    margin: 0;
    text-align: left;
    font-weight: normal;
    background-color: transparent;
    background-position: 14px center;
}


/* actual form content */
#app-navigation .add-new-popup {
    display: none;
    padding: 10px;
    width: 100%;
    border-top: 1px solid var(--color-border-dark);
    border-bottom: 1px solid var(--color-border-dark);
}


#app-navigation input.ng-invalid {
    border: 1px solid var(--color-error);
}

#app-navigation .add-new-popup input,
#app-navigation .add-new-popup select {
    width: 100%;
    height: 36px;
    padding: 5px;
    margin-right: 0;
}

#app-navigation .add-new-popup select,
#app-navigation #new-feed [name="folderName"] {
    width: calc(100% - 36px);
    border-right: 0;
    border-top-right-radius: 0;
    border-bottom-right-radius: 0;
    float: left;
}

#app-navigation .add-new-popup .add-new-folder-primary {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0;
    width: 36px;
    height: 36px;
    margin-left: 0;
    margin-right: 0;
}

#app-navigation .add-new-popup .add-new-basicauth-toggle {
    padding: 5px 0;
}

#app-navigation .add-new-popup .add-feed-basicauth {
    width: 100%;
    padding: 0 0 10px;
}

#app-navigation .add-new-popup .error {
    padding: 0 0 10px 0;
}

/* navigation */
#app-navigation ul.with-icon > li > a,
#app-navigation ul.with-icon > li > ul > li > a {
    padding-left: 44px;
}

#app-navigation .icon-starred {
    background-image: url('../img/starred.png');
}

.icon-rss {
    background-image: url('../img/rss.svg') !important;
}

.icon-rss-unread {
    background-image: url('../img/rss_unread.svg') !important;
}

.icon-add-folder {
    background-image: url('../img/add_folder.svg') !important;
}

.icon-facebook {
    background-image: url('../img/facebook.svg') !important;
}

.icon-twitter {
    background-image: url('../img/twitter.svg') !important;
}


.col-4 {
    -ms-flex: 0 0 33.333333%;
    flex: 0 0 33.333333%;
    max-width: 33.333333%;
    position: relative;
    width: 100%;
}

.row {
    display: -ms-flexbox;
    display: flex;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
}

.icon-dropdown{
    background-position: center !important;
    background-size: 24px;
    padding: 2em !important;
    min-height: 28px !important;
    min-width: 28px !important;
}

.icon-full-text-enabled {
    background-image: url('../img/fulltext.svg');
    background-size: 50%;
    opacity: .5;
}


.icon-full-text-disabled {
    background-image: url('../img/nonfulltext.svg');
    background-size: 50%;
    opacity: .5;
}

#app-navigation .unread > a {
    font-weight: bold;
}

#app-navigation p.error {
    line-height: 25px;
}

#app-navigation .folder-rename-error {
    height: auto;
}

/**
 * Error message
 */
#app-navigation .error-message {
    padding: 15px;
    background-color: var(--color-main-background);
    color: var(--color-error);
    position: relative;
    overflow-y: auto;
}

#app-navigation .ui-state-disabled {
    opacity: 1;
}

#app-navigation .error-message .title {
    font-weight: bold;
    padding-right: 30px;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
}

#app-navigation .error-message:hover .title
#app-navigation .error-message:hover .message {

}

#app-navigation .error-message button {
    top: 0;
    right: 0;
    position: absolute;
    margin: 0;
    height: 44px;
    width: 44px;
    padding: 15px;
    border: 0;
    background-size: 25px;
    background-color: transparent;
    background-image: url('../img/close.svg');
    background-repeat: no-repeat;
    background-position: right 5px top 5px;
    opacity: .9;
}

#app-navigation .error-message button:hover {
    opacity: 1;
}

#app-navigation .animate-show.ng-hide-add,
#app-navigation .animate-show.ng-hide-remove {
    /* this is required as of 1.3x to properly
       apply all styling in a show/hide animation */
    transition: 0s linear opacity;
}

#app-navigation .animate-show.ng-hide-add-active,
#app-navigation .animate-show.ng-hide-remove-active {
    transition: .2s linear opacity;
}

#app-navigation .animate-show {
    opacity: 1;
}

#app-navigation .animate-show.ng-hide {
    opacity: 0;
}

#app-navigation .feed-no-ordering {
    transform: rotate(270deg);
}

#app-navigation .feed-reverse-ordering {
    transform: rotate(180deg);
}

#app-navigation .feed-normal-ordering {
}

#app-navigation .icon-pinned {
    background-image: url('../img/pinned.svg');
}

#app-navigation .icon-unpinned {
    background-image: url('../img/unpinned.svg');
}

#app-navigation .icon-updatemode-default {
    background-image: url('../img/updatemodedefault.svg');
}

#app-navigation .icon-updatemode-unread {
    background-image: url('../img/updatemodeunread.svg');
}

#app-navigation .updateerror a {
    background-color: var(--color-warning) !important;
}
