OC.L10N.register(
    "news",
    {
    "Unread articles" : "Непрочитани статии",
    "News" : "Новости",
    "Download" : "Преземи",
    "Close" : "Затвори",
    "Open website" : "Отвори вебсајт",
    "Share" : "Сподели",
    "Username" : "Корисничко име",
    "by" : "од",
    "from" : "од",
    "Keyboard shortcut" : "Кратенка преку тастатура",
    "Description" : "Опис",
    "right" : "десно",
    "left" : "лево",
    "Refresh" : "Освежи",
    "Load next feed" : "Вчитај следен канал",
    "Subscribe" : "Претплата",
    "Feed exists already!" : "Каналот веќе постои!",
    "Folder" : "Папка",
    "New folder" : "Нова папка",
    "Folder name" : "Име на папка",
    "Go back" : "Назад",
    "Credentials" : "Акредитиви",
    "Password" : "Лозинка",
    "Create" : "Создај",
    "Deleted feed" : "Избришан канал",
    "Rename" : "Преименувај",
    "Mark read" : "Означи како прочитано",
    "Newest first" : "Новите прво",
    "Oldest first" : "Старите прво",
    "Open feed URL" : "Отвори URL на каналот",
    "Delete" : "Избриши",
    "Dismiss" : "Отфрли",
    "Collapse" : "Собери",
    "Starred" : "Со ѕвезда",
    "All articles" : "Сите статии",
    "Settings" : "Параметри",
    "Subscriptions (OPML)" : "Претплати (OPML)",
    "Import" : "Увези",
    "Export" : "Извези",
    "Unread/Starred Articles" : "Непрочитани/Означени статии",
    "Error when importing: file does not contain valid JSON" : "Грешка при импортирање: датотеката не содржи валиден JSON",
    "Help" : "Помош",
    "Keyboard shortcuts" : "Кратенки преку тастатура",
    "Documentation" : "Документација",
    "Report a bug" : "Пријави грешка"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
