OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "İstek karşılanamadı. Ağ bağlantısı kullanılamıyor!",
    "Request unauthorized. Are you logged in?" : "İstek için yeterli izin yok. Oturumunuz açık mı?",
    "Request forbidden. Are you an administrator?" : "İstek reddedildi. Bir yönetici misiniz?",
    "Token expired or app not enabled! Reload the page!" : "Kodun geçerlilik süresi dolmuş ya da uygulama etkin değil! Sayfayı yenileyin!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Sunucuda bir sorun çıktı! Lütfen ayrıntılı bilgi almak için data/nextcloud.log dosyasına bakın!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "İstek karşılanamadı. Nextcloud şu anda bakım kipinde!",
    "News feeds" : "Haber akışları",
    "Unread articles" : "Okunmamış makaleler",
    "News" : "Haberler",
    "News folders" : "Haberler klasörleri",
    "Shared with me" : "Benimle paylaşılanlar",
    "An RSS/Atom feed reader" : "Bu uygulama RSS/Atom akışlarının okunmasını sağlar",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Nextcloud için RSS/Atom akışı okuyucusu\n\n- 📲 Akışlarınızı birkaç mobil ya da masaüstü [istemci](https://nextcloud.github.io/news/clients/) ile eşitler\n- 🔄 Haber akışlarını otomatik olarak günceller\n- 🆓 Özgür ve açık kaynaklıdır, AGPLv3 lisansı koşulları altında dağıtılır, reklam ya da ücretli özellikler bulundurmaz\n\n**Bu uygulamanın çalışması için sistem zamanlanmış görevi gereklidir**\n\nGereksinimler için [buraya bakabilirsiniz](https://nextcloud.github.io/news/install/#dependencies)\n\nDeğişiklik günlüğü için [buraya bakabilirsiniz](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\n[Hata bildiriminde bulunun](https://github.com/nextcloud/news/issues/new/choose)\n\n[Özellik isteğinde bulunun](https://github.com/nextcloud/news/discussions/new)\n\n[Bir akış sorununu bildirin](https://github.com/nextcloud/news/discussions/new)",
    "Use system cron for updates" : "Güncellemeler için sistem zamanlanmış görevi kullanılsın",
    "Disable this if you use a custom updater." : "Özel bir güncelleyici çalıştırıyorsanız bu seçeneği devre dışı bırakın.",
    "Maximum read count per feed" : "Bir akış için en fazla okuma sayısı",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Temizleme görevi tarafından silinmeyecek, bir akış için okunabilecek en fazla makale sayısını belirtir. Eski makaleler okunduktan sonra yeniden görüntüleniyorsa bu değeri arttırın. -1 gibi negatif değerler bu özelliği kapatır.",
    "Delete unread articles automatically" : "Okunmamış makaleler otomatik olarak silinsin",
    "Enable this if you also want to delete unread articles." : "Okunmamış makalelerin silinmesini de istiyorsanız bu seçeneği etkinleştirin.",
    "Maximum redirects" : "En fazla yönlendirme",
    "How many redirects the feed fetcher should follow." : "Akış getiricinin izleyeceği yönlendirme sayısı.",
    "Feed fetcher timeout" : "Akış alma zaman aşımı",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Bir RSS ya da Atom akışının yüklenmesi için beklenecek en fazla süre. İşlem bu süre içinde tamamlanmaz ise güncellemeden vazgeçilir.",
    "Explore Service URL" : "Keşfetme hizmeti adresi",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Varsa, keşfetme bölümünde akışların görüntülenmesini sağlayacak hizmet adresi. İç keşfetme hizmeti için bu alanı boş bırakın.",
    "Update interval" : "Güncelleme sıklığı",
    "Interval in seconds in which the feeds will be updated." : "Saniye cinsinden, akışların güncellenme sıklığı.",
    "Successfully updated news configuration" : "Haberler yapılandırması güncellendi",
    "Unable to update news config" : "Haberler yapılandırması güncellenemedi",
    "Download" : "İndir",
    "Close" : "Kapat",
    "Subscribe to" : "Şuna abone ol",
    "No articles available" : "Henüz bir makale yok",
    "No unread articles available" : "Okunmamış bir makale yok",
    "Open website" : "Web sitesini aç",
    "Star article" : "Makaleye yıldız koy",
    "Unstar article" : "Makalenin yıldızını kaldır",
    "Keep article unread" : "Makaleyi okunmamış olarak tut",
    "Remove keep article unread" : "Makaleyi okunmamış olarak tutma",
    "Share" : "Paylaş",
    "Share with users" : "Kullanıcılarla paylaş",
    "Username" : "Kullanıcı adı",
    "No users found" : "Herhangi bir kullanıcı bulunamadı",
    "Error while searching for users" : "Kullanıcılar aranırken sorun çıktı",
    "Share on social media" : "Sosyal ağ üzerinde paylaş",
    "I wanted you to see this article" : "Bu yazıya bakmanı istiyorum",
    "Check out this article" : "Bu yazıya bir göz at",
    "by" : "yazar",
    "from" : "kaynak",
    "shared by" : "paylaşan",
    "Play audio" : "Sesi oynat",
    "Download audio" : "Sesi indir",
    "Download video" : "Görüntüyü indir",
    "Keyboard shortcut" : "Kısayol tuşu",
    "Description" : "Açıklama",
    "right" : "sağ",
    "Jump to next article" : "Sonraki makaleye geç",
    "left" : "sol",
    "Jump to previous article" : "Önceki makaleye geç",
    "Toggle star article" : "Makale yıldızını değiştir",
    "Star article and jump to next one" : "Makaleyi yıldızla ve sonrakine geç",
    "Toggle keep current article unread" : "Geçerli makalenin okunmamış olarak işaretle/kaldır",
    "Open article in new tab" : "Makaleyi yeni sekmede aç",
    "Toggle expand article in compact view" : "Sıkışık görünümde makaleyi genişlet/daralt",
    "Refresh" : "Yenile",
    "Load next feed" : "Sonraki akışı yükle",
    "Load previous feed" : "Önceki akışı yükle",
    "Load previous folder" : "Önceki klasörü yükle",
    "Load next folder" : "Sonraki klasörü yükle",
    "Scroll to active navigation entry" : "Gezinti girişini etkinleştirmek için kaydırın",
    "Mark current article's feed/folder read" : "Geçerli makale akışını/klasörünü okunmuş olarak işaretle",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax ya da Web zamanlanmış görev kipi algılandı! Akışlarınız güncellenmeyecek!",
    "How to set up the operating system cron" : "İşletim sistemi zamanlanmış görevi nasıl ayarlanır",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Haberler uygulamasının güncelleme API yazılımını kullanan daha hızlı bir paralel güncelleyici kurun ve ayarlayın",
    "Subscribe" : "Abone ol",
    "Web address" : "Web adresi",
    "Feed exists already!" : "Akış zaten var!",
    "Folder" : "Klasör",
    "No folder" : "Klasör yok",
    "New folder" : "Yeni klasör",
    "Folder name" : "Klasör adı",
    "Go back" : "Geri dön",
    "Folder exists already!" : "Klasör zaten var!",
    "Credentials" : "Kimlik doğrulama bilgileri",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth kimlik doğrulama bilgilerinin şifrelenmemiş olarak depolanması gerektiğinden, sunucu ya da veritabanına erişimi olan herkes bu bilgilere erişebilir!",
    "Password" : "Parola",
    "Auto discover Feed" : "Akışı otomatik bul",
    "New Folder" : "Yeni klasör",
    "Create" : "Ekle",
    "Explore" : "Keşfet",
    "Update failed more than 50 times" : "Güncelleme 50 defadan fazla yapılamadı",
    "Deleted feed" : "Akış silindi",
    "Undo delete feed" : "Silinmiş akışı geri al",
    "Rename" : "Yeniden adlandır",
    "Menu" : "Menü",
    "Mark read" : "Okunmuş olarak işaretle",
    "Unpin from top" : "Üstten kaldır",
    "Pin to top" : "Üste sabitle",
    "Newest first" : "Yeniden eskiye",
    "Oldest first" : "Eskiden yeniye",
    "Default order" : "Varsayılan sıralama",
    "Enable full text" : "Tam metin kullanılsın",
    "Disable full text" : "Tam metin kullanılmasın",
    "Unread updated" : "Okunmamış güncellendi",
    "Ignore updated" : "Güncellemeleri yok say",
    "Open feed URL" : "Akış adresini aç",
    "Delete" : "Sil",
    "Dismiss" : "İptal et",
    "Collapse" : "Daralt",
    "Deleted folder" : "Klasör silindi",
    "Undo delete folder" : "Klasör silmeyi geri al",
    "Starred" : "Yıldızlı",
    "All articles" : "Tüm makaleler",
    "Settings" : "Ayarlar",
    "Disable mark read through scrolling" : "Kaydırma sırasında okunmuş olarak işaretlenmesin",
    "Compact view" : "Sıkışık görünüm",
    "Expand articles on key navigation" : "Tuşla gezinme sırasında makaleler genişletilsin",
    "Show all articles" : "Tüm makaleleri görüntüle",
    "Reverse ordering (oldest on top)" : "Sıralamayı tersine çevir (eskiden yeniye)",
    "Subscriptions (OPML)" : "Abonelikler (OPML)",
    "Import" : "İçe aktar",
    "Export" : "Dışa Aktar",
    "Error when importing: File does not contain valid OPML" : "Dosya içe aktarılırken sorun çıktı: Dosyada geçerli bir OPML yok",
    "Error when importing: OPML is does neither contain feeds nor folders" : "İçe aktarma işlemi sırasında sorun çıktı: OPML içinde bir akış ya da dizin yok",
    "Unread/Starred Articles" : "Okunmamış/yıldızlı makaleler",
    "Error when importing: file does not contain valid JSON" : "İçe aktarma işlemi sırasında sorun çıktı: Dosyada geçerli JSON yok",
    "Help" : "Yardım",
    "Keyboard shortcuts" : "Kısayol tuşları",
    "Documentation" : "Belgeler",
    "Report a bug" : "Hata bildirin"
},
"nplurals=2; plural=(n > 1);");
