OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Päring ei õnnestunud, võrguühendus puudub!",
    "Request unauthorized. Are you logged in?" : "Päring pole lubatud. Oled sa sisse loginud?",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Päring ebaõnnestus, Nextcloud on hetkel hooldusrežiimis.",
    "Unread articles" : "Lugemata artiklid",
    "News" : "News",
    "Use system cron for updates" : "Kasuta süsteemi croni uuendusteks",
    "Maximum read count per feed" : "Maksimaalne lugemiste arv voo kohta",
    "Maximum redirects" : "Maksimaalsed ümbersuunamised",
    "Feed fetcher timeout" : "Voo ühenduse aegumine",
    "Explore Service URL" : "Sirvi teenuse URL-i",
    "Download" : "Lae alla",
    "Close" : "Sulge",
    "No articles available" : "Ühtegi artiklit pole saadaval",
    "No unread articles available" : "Lugemata artikleid pole saadaval",
    "Open website" : "Ava veebisait",
    "Star article" : "Märgi artikkel tähega",
    "Unstar article" : "Eemalda artiklilt täht",
    "Keep article unread" : "Hoia kui lugemata",
    "Remove keep article unread" : "Eemalda märgistus 'Hoia kui lugemata'",
    "Share" : "Jaga",
    "Username" : "Kasutajanimi",
    "by" : "lisas",
    "from" : "kohast",
    "Play audio" : "Esita heli",
    "Download audio" : "Laadi helifail alla",
    "Download video" : "Laadi video alla",
    "Keyboard shortcut" : "Klaviatuuri otsetee",
    "Description" : "Kirjeldus",
    "right" : "paremal",
    "Jump to next article" : "Hüppar järgmisele artiklile",
    "left" : "vasakul",
    "Jump to previous article" : "Hüppa eelmisele artiklile",
    "Toggle star article" : "Lülita artikli tähtekest",
    "Star article and jump to next one" : "Märgi tähekesega ning hüppa järgmisele",
    "Toggle keep current article unread" : "Lülita 'hoia olemasolev artikkel lugemata'",
    "Open article in new tab" : "Ava artikkel uuel kaardil",
    "Toggle expand article in compact view" : "Lülita 'laienda artikli kopaktne vaade'",
    "Refresh" : "Värskenda",
    "Load next feed" : "Laadi järgmine voog",
    "Load previous feed" : "Kaadi eelmine voog",
    "Load previous folder" : "Laadi eelmine kataloog",
    "Load next folder" : "Laadi järgmine kataloog",
    "Mark current article's feed/folder read" : "Märgi praegused artikli vood/kaustad loetuks",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax või webcron aktiveeritud! Su voogusid ei uuendata!",
    "How to set up the operating system cron" : "Kuidas seadistada operatsioonisüsteemi ajastatud tegevust",
    "Subscribe" : "Telli",
    "Web address" : "Veebiaadress",
    "Feed exists already!" : "Uudisvoog on juba olemas!",
    "Folder" : "Kaust",
    "No folder" : "Kausta pole",
    "New folder" : "Uus kaust",
    "Folder name" : "Kausta nimi",
    "Go back" : "Mine tagasi",
    "Folder exists already!" : "Kaust on juba olemas!",
    "Credentials" : "Kasutajatunnused",
    "Password" : "Parool",
    "New Folder" : "Uus kaust",
    "Create" : "Lisa",
    "Explore" : "Sirvi",
    "Update failed more than 50 times" : "Uuendamine on ebaõnnestunud rohkem kui 50 korda",
    "Deleted feed" : "Kustutatud uudisvoog",
    "Undo delete feed" : "Tühista uudisvoo kustutamine",
    "Rename" : "Nimeta ümber",
    "Menu" : "Menüü",
    "Mark read" : "Märgi loetuks",
    "Newest first" : "Uuemad eespool",
    "Oldest first" : "Vanemad eespool",
    "Default order" : "Vaikejärjestus",
    "Delete" : "Kustuta",
    "Dismiss" : "Jäta vahele",
    "Collapse" : "Sulge",
    "Deleted folder" : "Kustutatud kaust",
    "Undo delete folder" : "Tühista kausta kustutamine",
    "Starred" : "Tärniga märgitud",
    "All articles" : "Kõik artiklid",
    "Settings" : "Seaded",
    "Disable mark read through scrolling" : "Lülita kerimisel loetuks määramine välja",
    "Compact view" : "Kompaktne vaade",
    "Show all articles" : "Näita kõiki artikleid",
    "Reverse ordering (oldest on top)" : "Pööratud järjestus (vanemad eespool)",
    "Subscriptions (OPML)" : "Tellimused (OPML)",
    "Import" : "Impordi",
    "Export" : "Ekspordi",
    "Unread/Starred Articles" : "Lugemata/Märgitud artiklid",
    "Error when importing: file does not contain valid JSON" : "Viga importimisel: fail ei sisalda korrektset JSON-i",
    "Help" : "Abiinfo",
    "Keyboard shortcuts" : "Klaviatuuri otseteed",
    "Documentation" : "Dokumentatsioon",
    "Report a bug" : "Teata veast"
},
"nplurals=2; plural=(n != 1);");
