OC.L10N.register(
    "news",
    {
    "Download" : "چۈشۈر",
    "Close" : "ياپ",
    "Share" : "ھەمبەھىر",
    "Username" : "ئىشلەتكۈچى ئاتى",
    "by" : "سەنئەتكار",
    "Description" : "چۈشەندۈرۈش",
    "Refresh" : "يېڭىلا",
    "Web address" : "تور ئادرېسى",
    "Folder" : "قىسقۇچ",
    "New folder" : "يېڭى قىسقۇچ",
    "Folder name" : "قىسقۇچ ئاتى",
    "Credentials" : "Credentials",
    "Password" : "ئىم",
    "Create" : "قۇر",
    "Rename" : "ئات ئۆزگەرت",
    "Delete" : "ئۆچۈر",
    "Starred" : "يۇلتۇزلۇق",
    "Settings" : "تەڭشەكلەر",
    "Import" : "ئەكىر",
    "Export" : "چىقار",
    "Help" : "ياردەم",
    "Documentation" : "قوللانما"
},
"nplurals=2; plural=(n != 1);");
