OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Pyyntö epäonnistui, yhteys ei ole käytettävissä!",
    "Request unauthorized. Are you logged in?" : "Pyyntö ei ole valtutettu. Oletko sisäänkirjautuneena?",
    "Token expired or app not enabled! Reload the page!" : "Valtuutus vanheni tai sovellus ei ole käytössä! Lataa sivu uudelleen!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Sisäinen palvelinvirhe! Tarkista lisätiedot lokitiedostosta data/nextcloud.log!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Pyyntö epäonnistui, Nextcloud on parhaillaan ylläpitotilassa!",
    "News feeds" : "Syötteet",
    "Unread articles" : "Lukemattomat artikkelit",
    "News" : "Uutiset",
    "News folders" : "Syötekansiot",
    "Shared with me" : "Jaettu kanssasi",
    "An RSS/Atom feed reader" : "RSS-/Atom-syötteiden lukija",
    "Use system cron for updates" : "Käytä järjestelmän cronia päivityksille",
    "Disable this if you use a custom updater." : "Poista tämä käytöstä, jos käytät erillistä päivitintä.",
    "Maximum read count per feed" : "Syötekohtainen lukukertojen enimmäismäärä",
    "Maximum redirects" : "Uudelleenohjausten enimmäismäärä",
    "How many redirects the feed fetcher should follow." : "Kuinka montaa uudelleenohjausta syötteen noutajan tulisi seurata.",
    "Feed fetcher timeout" : "Syötteen hakemisen aikakatkaisu",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maksimiaika sekunteina, jonka aikana RSS- tai Atom-syöte odotetaan ladattavaksi. Jos lataus kestää pidempään, se perutaan.",
    "Explore Service URL" : "Syöte-ehdotusten palvelun URL",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Palvelun osoite, josta haetaan ehdotuksia syötteistä Löydä uusia-osioon. Jätä tyhjäksi, jos haluat käyttää sisäänrakennettua oletuspalvelua.",
    "Update interval" : "Päivitysväli",
    "Interval in seconds in which the feeds will be updated." : "Syötteiden päivitysväli sekunteina.",
    "Download" : "Lataa",
    "Close" : "Sulje",
    "Subscribe to" : "Tilaa",
    "No articles available" : "Artikkeleita ei ole saatavilla",
    "No unread articles available" : "Lukemattomia artikkeleita ei ole saatavilla",
    "Open website" : "Avaa verkkosivu",
    "Star article" : "Lisää artikkeli suosikkeihin",
    "Unstar article" : "Poista artikkeli suosikeista",
    "Keep article unread" : "Pidä artikkeli lukemattomana",
    "Remove keep article unread" : "Poista artikkelin pitäminen lukemattomana",
    "Share" : "Jaa",
    "Share with users" : "Jaa käyttäjien kanssa",
    "Username" : "Käyttäjätunnus",
    "No users found" : "Käyttäjiä ei löytynyt",
    "Error while searching for users" : "Virhe käyttäjien etsinnässä",
    "Share on social media" : "Jaa sosiaalisessa mediassa",
    "I wanted you to see this article" : "Halusin sinun näkevän tämän artikkelin",
    "Check out this article" : "Katso tämä artikkeli",
    "by" : "Kirjoittaja:",
    "from" : "Syöte:",
    "shared by" : "jakanut",
    "Play audio" : "Toista äänet",
    "Download audio" : "Lataa äänet",
    "Download video" : "Lataa video",
    "Keyboard shortcut" : "Näppäimistön pikanäppäin",
    "Description" : "Kuvaus",
    "right" : "oikea",
    "Jump to next article" : "Siirry seuraavaan artikkeliin",
    "left" : "vasen",
    "Jump to previous article" : "Siirry edelliseen artikkeliin",
    "Toggle star article" : "Suosikkimerkintä päälle/pois",
    "Star article and jump to next one" : "Lisää artikkeli suosikkeihin ja siirry seuraavaan",
    "Toggle keep current article unread" : "Pidä lukemattomana/aseta luetuksi",
    "Open article in new tab" : "Avaa artikkeli uudessa välilehdessä",
    "Toggle expand article in compact view" : "Laajenna artikkeli tiivissä näkymässä/supista artikkeli",
    "Refresh" : "Päivitä",
    "Load next feed" : "Lataa seuraava syöte",
    "Load previous feed" : "Lataa edellinen syöte",
    "Load previous folder" : "Lataa edellinen kansio",
    "Load next folder" : "Lataa seuraava kansio",
    "Scroll to active navigation entry" : "Vieritä syötelista aktiivisen syötteen kohdalle",
    "Mark current article's feed/folder read" : "Merkitse nykyisen artikkelin syöte/kansio luetuksi",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax tai webcron on käytössä! Syötteitä ei päivitetä!",
    "How to set up the operating system cron" : "Käyttöjärjestelmän cronin asettaminen",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Asenna ja ota käyttöön rinnakkainen päivitys käyttäen News-sovelluksen API:a",
    "Subscribe" : "Tilaa",
    "Web address" : "Verkko-osoite",
    "Feed exists already!" : "Syöte on jo olemassa!",
    "Folder" : "Kansio",
    "No folder" : "Ei kansiota",
    "New folder" : "Uusi kansio",
    "Folder name" : "Kansion nimi",
    "Go back" : "Takaisin",
    "Folder exists already!" : "Kansio on jo olemassa!",
    "Credentials" : "Tilitiedot",
    "Password" : "Salasana",
    "Auto discover Feed" : "Löydä syöte automaattisesti",
    "New Folder" : "Uusi kansio",
    "Create" : "Luo",
    "Explore" : "Löydä uusia",
    "Update failed more than 50 times" : "Päivitys epäonnistui yli 50 kertaa",
    "Deleted feed" : "Syöte poistettu",
    "Undo delete feed" : "Kumoa syötteen poistaminen",
    "Rename" : "Nimeä uudelleen",
    "Menu" : "Valikko",
    "Mark read" : "Merkitse luetuksi",
    "Unpin from top" : "Poista kiinnitys ylhäältä",
    "Pin to top" : "Kiinnitä ylös",
    "Newest first" : "Uusin ensin",
    "Oldest first" : "Vanhin ensin",
    "Default order" : "Oletusjärjestys",
    "Enable full text" : "Lataa koko teksti",
    "Disable full text" : "Älä lataa koko tekstiä",
    "Open feed URL" : "Avaa syötteen osoite",
    "Delete" : "Poista",
    "Dismiss" : "Hylkää",
    "Collapse" : "Kutista näkymää",
    "Deleted folder" : "Kansio poistettu",
    "Undo delete folder" : "Kumoa kansion poistaminen",
    "Starred" : "Suosikit",
    "All articles" : "Kaikki artikkelit",
    "Settings" : "Asetukset",
    "Disable mark read through scrolling" : "Älä merkitse luetuksi vierittäessä",
    "Compact view" : "Tiivis näkymä",
    "Expand articles on key navigation" : "Laajenna artikkelit näppäimistöllä navigoidessa",
    "Show all articles" : "Näytä kaikki artikkelit",
    "Reverse ordering (oldest on top)" : "Käänteinen järjestys (vanhimmat ensin)",
    "Subscriptions (OPML)" : "Tilaukset (OPML)",
    "Import" : "Tuo",
    "Export" : "Vie",
    "Error when importing: File does not contain valid OPML" : "Virhe tuotaessa: tiedosto ei sisällä kelvollista OPML:ää",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Virhe tuotaessa: OPML ei sisällä syötteitä tai kansioita",
    "Unread/Starred Articles" : "Suosikit ja lukemattomat artikkelit",
    "Error when importing: file does not contain valid JSON" : "Virhe tuotaessa: tiedosto ei sisällä kelvollista JSONia",
    "Help" : "Ohje",
    "Keyboard shortcuts" : "Pikanäppäimet",
    "Documentation" : "Dokumentaatio",
    "Report a bug" : "Ilmoita viasta"
},
"nplurals=2; plural=(n != 1);");
