OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Falló la solicitú, ¡conexón de rede non disponible!",
    "Request unauthorized. Are you logged in?" : "Solicitú non autorizada. ¿Aniciesti sesión?",
    "Token expired or app not enabled! Reload the page!" : "¡Token caducáu o l'aplicación nun ta activada! ¡Recarga la páxina!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "¡Fallu internu del sirvidor! Comprueba'l ficheru de rexistru en data/nextcloud.log pa más información",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "¡Falló la solicitú! Anguaño Nextcloud ta en mou de caltenimientu.",
    "Unread articles" : "Artículos ensin lleer",
    "News" : "Anuncies",
    "Maximum read count per feed" : "Númberu máximu de llectura per feed",
    "Maximum redirects" : "Redirecciones máximes",
    "Feed fetcher timeout" : "Tiempo escosao p'algamar el feed",
    "Explore Service URL" : "Esplorar URL del serviciu",
    "Download" : "Descargar",
    "Close" : "Zarrar",
    "No articles available" : "Nun hai artículos disponibles",
    "No unread articles available" : "Nun hai artículios ensin lleer disponibles",
    "Open website" : "Abrir sitiu web",
    "Star article" : "Artículu favoritu",
    "Unstar article" : "Artículu non destacáu",
    "Keep article unread" : "Caltener artículu ensín lleer",
    "Remove keep article unread" : "Desaniciar artículu ensín lleer",
    "Share" : "Share",
    "Username" : "Nome d'usuariu",
    "by" : "por",
    "from" : "Dende",
    "Play audio" : "Reproducir audiu",
    "Download audio" : "Descargar audiu",
    "Download video" : "Descargar video",
    "Keyboard shortcut" : "Atayu de tecláu",
    "Description" : "Descripción",
    "right" : "Derecha",
    "Jump to next article" : "Salta a l'artículu siguiente",
    "left" : "esquierda",
    "Jump to previous article" : "Salta a l'artículu previu",
    "Toggle star article" : "Marcar como favoritu",
    "Toggle keep current article unread" : "Marcar como non lleíu",
    "Open article in new tab" : "Abre l'artículu nuna pestaña nueva",
    "Toggle expand article in compact view" : "Espandir artículu en vista compacta",
    "Refresh" : "Anovar",
    "Load next feed" : "Carga'l siguiente feed",
    "Load previous feed" : "Carga'l feed anterior",
    "Load previous folder" : "Carga'l direutoriu anterior",
    "Load next folder" : "Carga'l siguiente direutoriu",
    "Scroll to active navigation entry" : "Movese hasta la entrada de navegación activa",
    "Mark current article's feed/folder read" : "Marcar tolos articulos actuales como lleíos",
    "How to set up the operating system cron" : "Cómo configurar el cron del sistema operativu",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instalar y configurar un actualizador más rápidu paralelu qu'utilice l'API d'actualización de l'aplicación Noticies",
    "Subscribe" : "Soscríbete",
    "Web address" : "Direición web",
    "Feed exists already!" : "¡Esti feed yá esiste!",
    "Folder" : "Carpeta",
    "No folder" : "Ensín carpeta",
    "New folder" : "Carpeta nueva",
    "Folder name" : "Nome de la carpeta",
    "Go back" : "Atrás",
    "Folder exists already!" : "¡La carpeta yá esiste!",
    "Credentials" : "Credenciales",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "¡Les credenciales d'autenticación básica d'HTTP tienen de ser almacenaos ensin encriptar! ¡Cualesquier que pueda aportar al sirvidor o base de datos va ser capaz d'aportar a ellos!",
    "Password" : "Contraseña",
    "New Folder" : "Carpeta nueva",
    "Create" : "Crear",
    "Explore" : "Esplorar",
    "Update failed more than 50 times" : "L'actualización falló más de 50 vegaes",
    "Deleted feed" : "Desaniciar feed",
    "Undo delete feed" : "Desfacer desaniciu del feed",
    "Rename" : "Renomar",
    "Menu" : "Menú",
    "Unpin from top" : "Defixar de lo cimero",
    "Newest first" : "Lo más nuevo",
    "Oldest first" : "Lo más vieyo",
    "Delete" : "Desaniciar",
    "Dismiss" : "Encaboxar",
    "Collapse" : "Contrayer",
    "Deleted folder" : "Desaniciar carpeta",
    "Undo delete folder" : "Desfacer desaniciu de la carpeta",
    "Starred" : "Favoritos",
    "All articles" : "Tolos artículos",
    "Settings" : "Axustes",
    "Disable mark read through scrolling" : "Deshabilita marcar como lleíu al desplazar",
    "Compact view" : "Vista compauta",
    "Expand articles on key navigation" : "Espandir los artículos al navegar con tecles",
    "Show all articles" : "Amosar tolos artículos",
    "Reverse ordering (oldest on top)" : "Ordenamientu inversu (el más antiguu na parte cimera)",
    "Subscriptions (OPML)" : "Soscripciones (OPML)",
    "Import" : "Importar",
    "Export" : "Esportar",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Fallu al importar: OPML nun contién nin feeds nin carpetes",
    "Unread/Starred Articles" : "Artículos Non lleíos y Favoritos",
    "Error when importing: file does not contain valid JSON" : "Fallu al importar: el ficheru nun contién JSON válidu",
    "Help" : "Ayuda",
    "Keyboard shortcuts" : "Atayos de tecláu",
    "Documentation" : "Documentación",
    "Report a bug" : "Informar un fallu"
},
"nplurals=2; plural=(n != 1);");
