OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Rechesta faddida, sa connessione a sa rete no est a disponimentu!",
    "Request unauthorized. Are you logged in?" : "Rechesta no autorizada. Intradu nche ses?",
    "Token expired or app not enabled! Reload the page!" : "Token iscàdidu o aplicatzione non ativada! Torra a carrigare sa pàgina!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Errore in intro de su serbidore! Controlla su file data/nextcloud.log pro àteras informatziones.",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Rechesta faddida, Nextcloud immoe est in mantenimentu!",
    "News feeds" : "Fontes de noas",
    "Unread articles" : "Artìculos non lèghidos",
    "News" : "Noas",
    "News folders" : "Cartellas de noas",
    "Shared with me" : "Cumpartzidos cun megus",
    "An RSS/Atom feed reader" : "Unu letore de fontes RSS/Atom",
    "Use system cron for updates" : "Imprea su cron de su sistema pro is agiornamentos",
    "Disable this if you use a custom updater." : "Disativa custu su pones in esecutzione una funtzione de agiornamentu personalizada.",
    "Maximum read count per feed" : "Nùmeru màssimu de leturas a fonte",
    "Maximum redirects" : "Nùmeru màssimu de rediretziones",
    "How many redirects the feed fetcher should follow." : "Cantas rediretziones podet sighire su trastu de recùperu de is fontes.",
    "Feed fetcher timeout" : "Ritardu màssimu de isetu pro su recùperu de sa fonte",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Nùmeru màssimu de segundos pro isetare su carrigamentu de una fonte RSS o Atom; si bi ponet tropu tempus s'agiornamentu s'at a firmare.",
    "Explore Service URL" : "URL de su servìtziu Esplora",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Si est ispetzificadu, s'at a pregontare a custu URL de su servìtziu pro visualizare is fontes in sa setzione de esploratzione. Pro torrare a su servìtziu de esploratzione integradu, lassa bòidu custu campu.",
    "Update interval" : "Tretu de agiornamentu",
    "Interval in seconds in which the feeds will be updated." : "Tretu in segundos pro agiornare is fontes.",
    "Download" : "Iscàrriga",
    "Close" : "Serra",
    "Subscribe to" : "Sutaiscrie",
    "No articles available" : "Perunu artìculu a disponimentu",
    "No unread articles available" : "Non sunt a disponimentu artìculos non lèghidos",
    "Open website" : "Aberi pàgina web",
    "Star article" : "Cumintza un artìculu",
    "Unstar article" : "Boga dae is preferidos",
    "Keep article unread" : "Mantene s'artìculu sena ddu lèghere",
    "Remove keep article unread" : "Boga su mantenimentu de s'artìculu comente non lèghidu",
    "Share" : "Cumpartzi",
    "Share with users" : "Cumpartzi cun àteros utentes",
    "Username" : "Nùmene utente",
    "No users found" : "Peruna utèntzia agatada",
    "Error while searching for users" : "Errore in sa chirca de is utentes",
    "Share on social media" : "Cumpartzi in is retes sotziales",
    "I wanted you to see this article" : "Dia chèrrere chi legas custu artìculu",
    "Check out this article" : "Gheta·ddi un'ogru a custu artìculu",
    "by" : "dae",
    "from" : "dae",
    "shared by" : "cumpartzidu cun",
    "Play audio" : "Reprodue àudiu",
    "Download audio" : "Iscàrriga àudiu",
    "Download video" : "iscàrriga vìdeu",
    "Keyboard shortcut" : "Curtziadòrgiu de tecladu",
    "Description" : "Descritzione",
    "right" : "dereta",
    "Jump to next article" : "Brinca a s'artìculu imbeniente",
    "left" : "manca",
    "Jump to previous article" : "Brinca a s'artìculu de in antis",
    "Toggle star article" : "Còmmuta s'agiunta a is preferidos de un'artìculu",
    "Star article and jump to next one" : "Agiùnghe s'artìculu a is preferidos e brinca a s'imbeniente",
    "Toggle keep current article unread" : "Còmmunta su mantenimentu de s'artìculu comente non lèghidu",
    "Open article in new tab" : "Aberi artìculu in un'ischeda noa",
    "Toggle expand article in compact view" : "Còmmuta s'ammàniu de s'artìculu in sa bista prus istrinta",
    "Refresh" : "Agiorna",
    "Load next feed" : "Càrriga sa fonte imbeniente",
    "Load previous feed" : "Càrriga sa fonte de in antis",
    "Load previous folder" : "Càrriga sa cartella de in antis",
    "Load next folder" : "Càrriga sa cartella imbeniente",
    "Scroll to active navigation entry" : "Iscurre pro ativare sa boghe de navigatzione",
    "Mark current article's feed/folder read" : "Marca sa cartella/fonte de s'artìculu comente non lèghida",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Rilevada modalidade crom Ajax o webcron! Is fontes tuas non ant a èssere agiornadas!",
    "How to set up the operating system cron" : "Comente impostare cron de su sistema operativu",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Installa e imposta una funtzione de agiornamentu parallelu prus lestra chi impreat is API de agiornamentu de s'aplicatzione News",
    "Subscribe" : "Sutaiscrie",
    "Web address" : "Indiritzu web",
    "Feed exists already!" : "Sa fonte b'est giai!",
    "Folder" : "Cartella",
    "No folder" : "Peruna cartella",
    "New folder" : "Cartella noa",
    "Folder name" : "Nùmene de sa cartella",
    "Go back" : "In segus",
    "Folder exists already!" : "Sa cartella b'est giai!",
    "Credentials" : "Credentziales",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Is credentziales HTTP Basic Auth si depent memorizare sena tzifradura! Chie si siat potzat intrare a su serbidore o a sa base de datos at a èssere a tretu de b'intrare!",
    "Password" : "Crae",
    "Auto discover Feed" : "Iscoberta automàtica fonte",
    "New Folder" : "Cartella noa",
    "Create" : "Crea",
    "Explore" : "Esplorare",
    "Update failed more than 50 times" : "S'agiornamentu no est andadu bene prus de 50 bortas",
    "Deleted feed" : "Elimina sa fonte",
    "Undo delete feed" : "Annulla s'eliminatzione de sa fonte",
    "Rename" : "Torra a numenare",
    "Menu" : "Menu",
    "Mark read" : "Marca lèghidos",
    "Unpin from top" : "Boga dae sa chima",
    "Pin to top" : "Piga nota in artu",
    "Newest first" : "In antis is prus reghentes",
    "Oldest first" : "In antis is prus betzos",
    "Default order" : "Òrdine predefinidu",
    "Enable full text" : "Ativa totu su testu",
    "Disable full text" : "Disativa totu su testu",
    "Unread updated" : "Non lèghidos agiornados",
    "Ignore updated" : "Ignora agiornados",
    "Open feed URL" : "Aberi URL de sa fonte",
    "Delete" : "Cantzella",
    "Dismiss" : "Annulla",
    "Collapse" : "Cuntrae",
    "Deleted folder" : "Elìmina sa cartella",
    "Undo delete folder" : "Annulla s'eliminatzione de sa cartella",
    "Starred" : "Preferidos",
    "All articles" : "Totu is artìculos",
    "Settings" : "Impostatziones",
    "Disable mark read through scrolling" : "Disativa su de marcare comente non lèghidu in s'iscurrimentu",
    "Compact view" : "Bista istrinta",
    "Expand articles on key navigation" : "Ammania·nche is artìculos navighende cun is butones",
    "Show all articles" : "Mustra is artìculos",
    "Reverse ordering (oldest on top)" : "Òrdine invertidu (su prus betzu in artu)",
    "Subscriptions (OPML)" : "Sutaiscritziones (OPML)",
    "Import" : "Importa",
    "Export" : "Esporta",
    "Error when importing: File does not contain valid OPML" : "Errore de importazione: s'archìviu non cuntente unu OPML bàlidu",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Errore importende: s'archìviu OPML non cuntenet nen fontes nen cartellas",
    "Unread/Starred Articles" : "Artìculos non lèghidos/preferidos",
    "Error when importing: file does not contain valid JSON" : "Errore importende: s'archìviu non cuntenet unu JSON bàlidu",
    "Help" : "Agiudu",
    "Keyboard shortcuts" : "Curtziadòrgios de tecladu",
    "Documentation" : "Documentatzione",
    "Report a bug" : "Report a bug"
},
"nplurals=2; plural=(n != 1);");
