OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "요청이 실패했습니다. 네트워크 연결을 사용할 수 없습니다.",
    "Request unauthorized. Are you logged in?" : "요청이 인증되지 않았습니다. 로그인되어 있습니까?",
    "Token expired or app not enabled! Reload the page!" : "토큰이 만료되었거나 앱이 활성화되어 있지 않습니다. 페이지를 새로 고치십시오!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "내부 서버 오류! 자세한 내용은 data/nextcloud.log 파일을 확인하십시오!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "요청이 실패했습니다. Nextcloud가 현재 관리 모드입니다!",
    "Unread articles" : "읽지 않은 글",
    "News" : "뉴스",
    "Shared with me" : "나와 공유됨",
    "An RSS/Atom feed reader" : "RSS/Atom 피드 리더",
    "Use system cron for updates" : "시스템 cron으로 업데이트",
    "Maximum read count per feed" : "피드당 최대 읽은 글 개수",
    "Maximum redirects" : "최대 넘겨주기 수",
    "Feed fetcher timeout" : "피드 가져오기 시간 제한",
    "Explore Service URL" : "탐색 서비스 URL",
    "Download" : "다운로드",
    "Close" : "닫기",
    "No articles available" : "글 없음",
    "No unread articles available" : "읽지 않은 글 없음",
    "Open website" : "웹 사이트 열기",
    "Star article" : "글에 별표 붙이기",
    "Unstar article" : "글에서 별표 떼기",
    "Keep article unread" : "읽지 않은 상태로 유지",
    "Remove keep article unread" : "읽지 않은 상태로 유지하지 않음",
    "Share" : "공유",
    "Username" : "사용자 이름",
    "by" : "작성:",
    "from" : "원본 사이트:",
    "Play audio" : "오디오 재생",
    "Download audio" : "오디오 다운로드",
    "Download video" : "동영상 다운로드",
    "Keyboard shortcut" : "키보드 단축키",
    "Description" : "설명",
    "right" : "오른쪽",
    "Jump to next article" : "다음 글로 이동",
    "left" : "왼쪽",
    "Jump to previous article" : "이전 글로 이동",
    "Toggle star article" : "글 별표 전환",
    "Star article and jump to next one" : "글에 별표를 붙이고 다음 항목으로 이동",
    "Toggle keep current article unread" : "현재 글 읽지 않은 상태로 유지 전환",
    "Open article in new tab" : "새 탭으로 글 열기",
    "Toggle expand article in compact view" : "작은 보기에서 글 확장 전환",
    "Refresh" : "새로 고침",
    "Load next feed" : "다음 피드 불러오기",
    "Load previous feed" : "이전 피드 불러오기",
    "Load previous folder" : "이전 폴더 불러오기",
    "Load next folder" : "다음 폴더 불러오기",
    "Scroll to active navigation entry" : "활성 탐색 항목으로 스크롤",
    "Mark current article's feed/folder read" : "현재 글이 속한 피드/폴더를 읽은 것으로 표시",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax 및 웹 cron 모드가 감지되었습니다! 피드를 업데이트하지 않습니다!",
    "How to set up the operating system cron" : "운영 체제 cron 설정 방법",
    "Install and set up a faster parallel updater that uses the News app's update API" : "뉴스 앱의 업데이트 API를 사용하는 빠른 병렬 업데이터 설치 및 설정",
    "Subscribe" : "구독",
    "Web address" : "웹 주소",
    "Feed exists already!" : "피드가 이미 존재합니다!",
    "Folder" : "폴더",
    "No folder" : "폴더 없음",
    "New folder" : "새 폴더",
    "Folder name" : "폴더 이름",
    "Go back" : "뒤로 가기",
    "Folder exists already!" : "폴더가 이미 존재합니다!",
    "Credentials" : "인증 정보",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP 기본 인증 정보는 암호화되지 않은 상태로 저장됩니다! 서버나 데이터베이스에 접근한 모든 사용자들이 접근할 수 있습니다!",
    "Password" : "암호",
    "New Folder" : "새 폴더",
    "Create" : "만들기",
    "Explore" : "탐색",
    "Update failed more than 50 times" : "업데이트가 50번 이상 실패함",
    "Deleted feed" : "삭제된 피드",
    "Undo delete feed" : "피드 삭제 취소",
    "Rename" : "이름 바꾸기",
    "Menu" : "메뉴",
    "Mark read" : "읽은 상태로 표시",
    "Unpin from top" : "목록에서 고정 해제",
    "Pin to top" : "목록에 고정",
    "Newest first" : "새 항목 먼저",
    "Oldest first" : "오래된 항목 먼저",
    "Default order" : "기본 순서",
    "Enable full text" : "전문 사용",
    "Disable full text" : "전문 사용 안 함",
    "Unread updated" : "업데이트된 항목 읽지 않음으로 표시",
    "Ignore updated" : "업데이트된 항목 무시",
    "Open feed URL" : "피드 URL 열기",
    "Delete" : "삭제",
    "Dismiss" : "닫기",
    "Collapse" : "접기",
    "Deleted folder" : "삭제된 폴더",
    "Undo delete folder" : "폴더 삭제 실행 취소",
    "Starred" : "별표",
    "All articles" : "모든 글",
    "Settings" : "설정",
    "Disable mark read through scrolling" : "스크롤 시 읽은 상태로 표시 비활성화",
    "Compact view" : "축소된 보기",
    "Expand articles on key navigation" : "키 탐색 시 글 확장",
    "Show all articles" : "모든 글 보기",
    "Reverse ordering (oldest on top)" : "순서 뒤집기(오래된 항목 먼저)",
    "Subscriptions (OPML)" : "구독(OPML)",
    "Import" : "가져오기",
    "Export" : "내보내기",
    "Error when importing: File does not contain valid OPML" : "가져오는 중 오류 발생: 파일에 올바른 OPML이 없음",
    "Error when importing: OPML is does neither contain feeds nor folders" : "가져오기 오류: OPML 파일에 피드나 폴더가 없음",
    "Unread/Starred Articles" : "읽지 않은/별표한 글",
    "Error when importing: file does not contain valid JSON" : "가져오기 오류: 파일이 올바른 JSON을 포함하지 않음",
    "Help" : "도움말",
    "Keyboard shortcuts" : "키보드 단축키",
    "Documentation" : "문서",
    "Report a bug" : "버그 보고"
},
"nplurals=1; plural=0;");
