OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Požadavek se nezdařil – nedostupné síťové spojení!",
    "Request unauthorized. Are you logged in?" : "Neoprávněný požadavek. Jste přihlášení?",
    "Request forbidden. Are you an administrator?" : "Požadavek odepřen. Jste správce?",
    "Token expired or app not enabled! Reload the page!" : "Platnost tokenu skončila nebo aplikace není povolena! Načtěte stránku znovu.",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Vnitřní chyba serveru! Podrobnosti naleznete v souboru data/nextcloud.log",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Požadavek se nezdařil, protože Nextcloud se právě nachází v režimu údržby!",
    "News feeds" : "Kanály novinek",
    "Unread articles" : "Nepřečtené články",
    "News" : "Novinky",
    "News folders" : "Složky novinek",
    "Shared with me" : "Sdíleno se mnou",
    "An RSS/Atom feed reader" : "Čtečka RSS/Atom kanálů",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Aplikace čtečka RSS/Atom kanálů pro Nextcloud\n\n- 📲 Synchronizujte vámi odebírané kanály s vícero mobilními nebo desktopovými [klienty](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatické aktualizace vašich kanálů s novinkami\n- 🆓 Svobodné a open source pod licencí AGPLv3, žádné reklamy nebo funkce přístupné až po zaplacení\n\n**Aby tato aplikace fungovala, je v tuto chvíli zapotřebí systémový plánovač (cron)**\n\nPožadavky na instalaci dalších součástí jsou k nalezení [zde](https://nextcloud.github.io/news/install/#dependencies)\n\nSeznam změn je k dispozici [zde](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nVytvořte [hlášení chyby](https://github.com/nextcloud/news/issues/new/choose)\n\nVytvořte [žádost o přidání funkce](https://github.com/nextcloud/news/discussions/new)\n\nNahlaste [problém s kanálem}(https://github.com/nextcloud/news/discussions/new)",
    "Use system cron for updates" : "Pro aktualizace používat službu systémového plánovače (cron)",
    "Disable this if you use a custom updater." : "Toto vypněte, pokud používáte uživatelsky určený nástroj pro aktualizace.",
    "Maximum read count per feed" : "Maximální počet načítaných novinek na kanál",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Určuje nejvyšší nastavený počet článků, které je z jednotlivých kanálů možné číst a které tím nebudou mazány při čištění. Pokud se staré už přečtené články znovu objevují, navyšte tuto hodnotu (záporné hodnoty jako např. -1 tuto funkci úplně vypnou).",
    "Delete unread articles automatically" : "Automaticky mazat i nepřečtené články",
    "Enable this if you also want to delete unread articles." : "Pokud chcete mazat také nepřečtené články, zapněte toto.",
    "Maximum redirects" : "Nejvyšší počet přesměrování",
    "How many redirects the feed fetcher should follow." : "Kolik až přesměrování může být následováno při stahování článků.",
    "Feed fetcher timeout" : "Časový limit při stahování článků",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Nejdelší přijatelné čekání (v sekundách) na načtení RSS nebo Atom kanálu. Při překročení bude pokus o aktualizaci přerušen.",
    "Explore Service URL" : "URL služby pro objevování",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Pokud zadáno, bude tato URL dotazována ohledně zobrazování kanálů v rámci sekce pro jejich objevování. Pokud se chcete vrátit k výchozí službě pro objevování, ponechte tuto kolonku prázdnou.",
    "Update interval" : "Interval aktualizace",
    "Interval in seconds in which the feeds will be updated." : "Interval (v sekundách) ve kterém budou kanály aktualizovány.",
    "Successfully updated news configuration" : "Nastavení pro Novinky úspěšně zaktualizováno",
    "Unable to update news config" : "Nedaří se aktualizovat nastavení pro Novinky",
    "Download" : "Stáhnout",
    "Close" : "Zavřít",
    "Subscribe to" : "Přihlásit se k odběru",
    "No articles available" : "Nejsou k dispozici žádné články",
    "No unread articles available" : "Nemáte žádné nepřečtené články",
    "Open website" : "Otevřít webovou stránku",
    "Star article" : "Ohodnotit článek hvězdičkou",
    "Unstar article" : "Odebrat článku hvězdičku",
    "Keep article unread" : "Ponechat stav článku jako nepřečtený",
    "Remove keep article unread" : "Odebrat článku stav nepřečteného",
    "Share" : "Sdílet",
    "Share with users" : "Sdílet s uživateli",
    "Username" : "Uživatelské jméno",
    "No users found" : "Nenalezeni žádní uživatelé",
    "Error while searching for users" : "Chyba při hledání v uživatelích",
    "Share on social media" : "Sdílet na sociální média",
    "I wanted you to see this article" : "Tento článek doporučuji k přečtení",
    "Check out this article" : "Podívej(te) se na tento článek",
    "by" : "od",
    "from" : "z",
    "shared by" : "sdílí",
    "Play audio" : "Přehrát zvuk",
    "Download audio" : "Stáhnout si zvuk",
    "Download video" : "Stáhnout si video",
    "Keyboard shortcut" : "Klávesová zkratka",
    "Description" : "Popis",
    "right" : "vpravo",
    "Jump to next article" : "Přejít na další článek",
    "left" : "vlevo",
    "Jump to previous article" : "Přejít na předchozí článek",
    "Toggle star article" : "Označit / zrušit označení článku hvězdičkou",
    "Star article and jump to next one" : "Označit článek hvězdičkou a přejít na další",
    "Toggle keep current article unread" : "Vyp/zap. ponechání stávajícího článku jako nepřečteného",
    "Open article in new tab" : "Otevřít článek v novém panelu",
    "Toggle expand article in compact view" : "Rozbal./sbalení článku v rámci kompaktního zobrazení",
    "Refresh" : "Znovu načíst",
    "Load next feed" : "Načíst další kanál",
    "Load previous feed" : "Načíst předchozí kanál",
    "Load previous folder" : "Načíst předchozí složku",
    "Load next folder" : "Načíst další složku",
    "Scroll to active navigation entry" : "Posunout na aktivní položku navigace",
    "Mark current article's feed/folder read" : "Označit kanál/složku nyní otevřeného článku jako přečtené",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Zjištěn ajax nebo web cron režim! Kanály nebudou aktualizovány!",
    "How to set up the operating system cron" : "Jak nastavit službu plánovače operačního systému (cron)",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Nainstalovat a nastavit rychlejší paralelní systém aktualizace využívající aktualizační aplikační program. rozhraní (API) aplikace Novinky",
    "Subscribe" : "Přihlásit se k odběru",
    "Web address" : "Webová adresa",
    "Feed exists already!" : "Kanál už existuje!",
    "Folder" : "Složka",
    "No folder" : "Žádná složka",
    "New folder" : "Nová složka",
    "Folder name" : "Název složky",
    "Go back" : "Jít zpět",
    "Folder exists already!" : "Složka už existuje!",
    "Credentials" : "Přihlašovací údaje",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Je třeba, aby přihlašovací údaje pro HTTP Basic Auth byly uloženy nešifrovaně! Každý s přístupem k serveru nebo databázi je ovšem bude moci přečíst!",
    "Password" : "Heslo",
    "Auto discover Feed" : "Automaticky objevit kanál",
    "New Folder" : "Nová složka",
    "Create" : "Vytvořit",
    "Explore" : "Objevit",
    "Update failed more than 50 times" : "Aktualizace se nezdařila více než 50krát",
    "Deleted feed" : "Smazaný kanál",
    "Undo delete feed" : "Vzít zpět smazání kanálu",
    "Rename" : "Přejmenovat",
    "Menu" : "Nabídka",
    "Mark read" : "Označit jako přečtené",
    "Unpin from top" : "Odepnout ze shora",
    "Pin to top" : "Připnout nahoru",
    "Newest first" : "První nejnovější",
    "Oldest first" : "První nejstarší",
    "Default order" : "Výchozí pořadí",
    "Enable full text" : "Zobrazovat celý text",
    "Disable full text" : "Nezobrazovat celý text",
    "Unread updated" : "Aktualizované články nastavit jako nepřečtené",
    "Ignore updated" : "Ignorovat aktualizované články",
    "Open feed URL" : "Otevřít URL kanálu",
    "Delete" : "Smazat",
    "Dismiss" : "Zahodit",
    "Collapse" : "Sbalit",
    "Deleted folder" : "Smazaná složka",
    "Undo delete folder" : "Vzít zpět smazání složky",
    "Starred" : "S hvězdičkou",
    "All articles" : "Všechny články",
    "Settings" : "Nastavení",
    "Disable mark read through scrolling" : "Po posunutí na jejich konec, neoznačovat automaticky články jako přečtené.",
    "Compact view" : "Kompaktní zobrazení",
    "Expand articles on key navigation" : "Rozbalit články po stisknutí kláves navigace",
    "Show all articles" : "Zobrazit všechny články",
    "Reverse ordering (oldest on top)" : "Opačné řazení (od nejstarších)",
    "Subscriptions (OPML)" : "Odběry (OPML)",
    "Import" : "Importovat",
    "Export" : "Exportovat",
    "Error when importing: File does not contain valid OPML" : "Chyba při importu: soubor neobsahuje platná OPML data",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Chyba při importu: OPML neobsahuje kanály ani složky",
    "Unread/Starred Articles" : "Články nepřečtené a s hvězdičkou",
    "Error when importing: file does not contain valid JSON" : "Chyba při importu: soubor neobsahuje platná JSON data",
    "Help" : "Nápověda",
    "Keyboard shortcuts" : "Klávesové zkratky",
    "Documentation" : "Dokumentace",
    "Report a bug" : "Nahlásit chybu"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
