OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "La petición ha fallado, ¡la conexión de red no está disponible!",
    "Request unauthorized. Are you logged in?" : "Petición no autorizada, ¿has iniciado sesión?",
    "Request forbidden. Are you an administrator?" : "Petición prohibida. ¿Eres el administrador?",
    "Token expired or app not enabled! Reload the page!" : "¡Sesión caducada o aplicación no habilitada! ¡Vuelve a cargar la página!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "¡Error interno del servidor! ¡Por favor, comprueba el archivo data/nextcloud.log para mas información!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "¡Petición fallida! Nexcloud está actualmente en modo mantenimiento.",
    "News feeds" : "Fuentes de noticias",
    "Unread articles" : "Artículos sin leer",
    "News" : "Noticias",
    "News folders" : "Carpetas nuevas",
    "Shared with me" : "Compartido conmigo",
    "An RSS/Atom feed reader" : "Un lector de feeds RSS/Atom",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 App de lectura de fuentes de noticias RSS/Atom para Nextcloud\n\n- 📲 Sincronice sus fuentes de noticias con múltiples [clientes](https://nextcloud.github.io/news/clients/) móviles o de escritorio.\n- 🔄 Actualizaciones automáticas de sus fuentes de noticias.\n- 🆓 Gratis y de código abierto bajo AGPLv3, sin anuncios o funciones premium.\n\n**Se requiere el Cron del sistema para que esta aplicación funcione**\n\nLos requisitos se pueden encontrar [aquí](https://nextcloud.github.io/news/install/#dependencies)\n\nLa lista de cambios se encuentra [aquí](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCrear un [reporte de bug](https://github.com/nextcloud/news/issues/new/choose)\nCrear una [solicitud de función](https://github.com/nextcloud/news/discussions/new)\n\nInformar de un [problema en fuente](https://github.com/nextcloud/news/discussions/new)",
    "Use system cron for updates" : "Usa el cron del sistema para las actualizaciones",
    "Disable this if you use a custom updater." : "Desactiva esto si ejecutas un actualizador personalizado.",
    "Maximum read count per feed" : "Máximo número de lecturas por fuente",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Define la cantidad de artículos máxima que se pueden leer por fuente que no se borrarán mediante el trabajo de limpieza, si reaparecen artículos viejos después de que los hayas leído, aumenta este valor, valores negativos como -1 desactivarán esta característica.",
    "Delete unread articles automatically" : "Borrar artículos no leídos de forma automática",
    "Enable this if you also want to delete unread articles." : "Habilite esta opción si además quiere borrar los artículos no leídos.",
    "Maximum redirects" : "Máximo de redirecciones",
    "How many redirects the feed fetcher should follow." : "Cuántas redirecciones debería seguir el capturador de fuentes.",
    "Feed fetcher timeout" : "Tiempo de espera agotado para la descarga de la fuente",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Número máximo de segundos que esperara a que una fuente RSS o Atom cargue; si tarda más se abortará la actualización.",
    "Explore Service URL" : "Explorar URL del Servicio",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Si se da, esta URL del servicio se usará para mostrar las fuentes en la sección de explorar fuentes. Para volver al servicio de exploración incorporado, deja este campo vacío.",
    "Update interval" : "Intervalo de actualización",
    "Interval in seconds in which the feeds will be updated." : "Intervalo en segundos en el que se actualizarán las fuentes.",
    "Successfully updated news configuration" : "Se actualizó la configuración de noticias de forma exitosa",
    "Unable to update news config" : "No se puede actualizar la configuración de las noticias",
    "Download" : "Descargar",
    "Close" : "Cerrar",
    "Subscribe to" : "Subscribirse a",
    "No articles available" : "No hay artículos disponibles",
    "No unread articles available" : "No hay artículos leídos disponibles",
    "Open website" : "Abrir página web",
    "Star article" : "Marcar artículo como favorito",
    "Unstar article" : "Quitar artículo de favoritos",
    "Keep article unread" : "Mantener el artículo como no-leído.",
    "Remove keep article unread" : "Elimina mantener el artículo como no-leído.",
    "Share" : "Compartir",
    "Share with users" : "Compartir con usuarios",
    "Username" : "Nombre de usuario",
    "No users found" : "No se han encontrado usuarios",
    "Error while searching for users" : "Error al buscar usuarios",
    "Share on social media" : "Compartir en medios sociales",
    "I wanted you to see this article" : "Quería que vieras este artículo",
    "Check out this article" : "Echa un vistazo a este artículo",
    "by" : "por",
    "from" : "de",
    "shared by" : "compartido con",
    "Play audio" : "Reproducir audio",
    "Download audio" : "Descargar audio",
    "Download video" : "Descargar vídeo",
    "Keyboard shortcut" : "Atajo de teclado",
    "Description" : "Descripción",
    "right" : "derecha",
    "Jump to next article" : "Ir al artículo siguiente",
    "left" : "izquierda",
    "Jump to previous article" : "Ir al artículo anterior",
    "Toggle star article" : "Marcar como favorito",
    "Star article and jump to next one" : "Marcar como favorito e ir al siguiente",
    "Toggle keep current article unread" : "Marcar como no leído",
    "Open article in new tab" : "Abrir artículo en una nueva pestaña",
    "Toggle expand article in compact view" : "Cambiar a vista compacta",
    "Refresh" : "Actualizar",
    "Load next feed" : "Cargar fuente siguiente",
    "Load previous feed" : "Cargar fuente anterior",
    "Load previous folder" : "Cargar carpeta anterior",
    "Load next folder" : "Cargar carpeta siguiente",
    "Scroll to active navigation entry" : "Desplácese hasta la entrada de navegación activa",
    "Mark current article's feed/folder read" : "Marcar los articulos actuales de la fuente/carpeta como leídos",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "¡Detectado modo Ajax o webcron! ¡Tus fuentes no se actualizarán!",
    "How to set up the operating system cron" : "Cómo configurar el cron del sistema operativo",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instala y configura un actualizador paralelo más rápido que utiliza la API de actualización de la app News",
    "Subscribe" : "Suscribirse",
    "Web address" : "Dirección web",
    "Feed exists already!" : "Esa fuente ya existe.",
    "Folder" : "Carpeta",
    "No folder" : "Sin carpeta",
    "New folder" : "Nueva carpeta",
    "Folder name" : "Nombre de la carpeta",
    "Go back" : "Atrás",
    "Folder exists already!" : "¡La carpeta ya existe!",
    "Credentials" : "Credenciales",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "¡Las credenciales para HTTP Basic Auth deben estar guardadas sin cifrar! ¡Pero cualquiera con acceso al servidor podría acceder a ellas!",
    "Password" : "Contraseña",
    "Auto discover Feed" : "Auto descubrir Fuentes",
    "New Folder" : "Nueva carpeta",
    "Create" : "Crear",
    "Explore" : "Explorar",
    "Update failed more than 50 times" : "La actualización ha fallado más de 50 veces",
    "Deleted feed" : "Eliminar fuente",
    "Undo delete feed" : "Deshacer eliminar fuente",
    "Rename" : "Renombrar",
    "Menu" : "Menú",
    "Mark read" : "Marcar como leído",
    "Unpin from top" : "Soltar de arriba",
    "Pin to top" : "Fijar arriba",
    "Newest first" : "Más nuevos primero",
    "Oldest first" : "Más viejos primero",
    "Default order" : "Orden por defecto",
    "Enable full text" : "Habilitar texto completo",
    "Disable full text" : "Deshabilitar texto completo",
    "Unread updated" : "Artículos sin leer actualizados",
    "Ignore updated" : "Ignorar los actualizados",
    "Open feed URL" : "Abrir URL de la fuente",
    "Delete" : "Eliminar",
    "Dismiss" : "Descartar",
    "Collapse" : "Colapsar",
    "Deleted folder" : "Carpeta eliminada",
    "Undo delete folder" : "Deshacer eliminar carpeta",
    "Starred" : "Favoritos",
    "All articles" : "Todos los artículos",
    "Settings" : "Ajustes",
    "Disable mark read through scrolling" : "Deshabilitar marca de lectura mientras se desplaza",
    "Compact view" : "Vista compacta",
    "Expand articles on key navigation" : "Expandir los artículos al navegar con teclas",
    "Show all articles" : "Mostrar todos los artículos",
    "Reverse ordering (oldest on top)" : "Ordenación inversa (la más antigua en la parte superior)",
    "Subscriptions (OPML)" : "Suscripciones (OPML)",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Error when importing: File does not contain valid OPML" : "Error al importar: el archivo no contiene un OPML válido",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Error al importar: el OPML no contiene fuentes ni carpetas",
    "Unread/Starred Articles" : "Artículos no leídos y favoritos",
    "Error when importing: file does not contain valid JSON" : "Error al importar: el archivo no contiene JSON válido",
    "Help" : "Ayuda",
    "Keyboard shortcuts" : "Atajos de teclado",
    "Documentation" : "Documentación",
    "Report a bug" : "Notificar un error"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
