<?php return array(
    'root' => array(
        'name' => '__root__',
        'pretty_version' => '20.0.0',
        'version' => '20.0.0.0',
        'reference' => 'c60d9b1f15d566e48a148adcb3fd1e4493a1c1c0',
        'type' => 'project',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        '__root__' => array(
            'pretty_version' => '20.0.0',
            'version' => '20.0.0.0',
            'reference' => 'c60d9b1f15d566e48a148adcb3fd1e4493a1c1c0',
            'type' => 'project',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'arthurhoaro/favicon' => array(
            'pretty_version' => 'v1.3.3',
            'version' => '1.3.3.0',
            'reference' => 'b1acd8b87d6b37e5251fe0559ed488a95078f5b9',
            'type' => 'library',
            'install_path' => __DIR__ . '/../arthurhoaro/favicon',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'debril/feed-io' => array(
            'pretty_version' => 'v4.9.15',
            'version' => '4.9.15.0',
            'reference' => '1c45bd07837123ec6eacf8cdd612cbb0dc27229c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../debril/feed-io',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ezyang/htmlpurifier' => array(
            'pretty_version' => 'v4.16.0',
            'version' => '4.16.0.0',
            'reference' => '523407fb06eb9e5f3d59889b3978d5bfe94299c8',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ezyang/htmlpurifier',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'fivefilters/readability.php' => array(
            'pretty_version' => 'v3.1.1',
            'version' => '3.1.1.0',
            'reference' => 'aae0ff5f9875f039180b4ade860fc2d8bf796f79',
            'type' => 'library',
            'install_path' => __DIR__ . '/../fivefilters/readability.php',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'guzzlehttp/guzzle' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '*',
            ),
        ),
        'league/uri' => array(
            'pretty_version' => '6.7.2',
            'version' => '6.7.2.0',
            'reference' => 'd3b50812dd51f3fbf176344cc2981db03d10fe06',
            'type' => 'library',
            'install_path' => __DIR__ . '/../league/uri',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'league/uri-interfaces' => array(
            'pretty_version' => '2.3.0',
            'version' => '2.3.0.0',
            'reference' => '00e7e2943f76d8cb50c7dfdc2f6dee356e15e383',
            'type' => 'library',
            'install_path' => __DIR__ . '/../league/uri-interfaces',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'masterminds/html5' => array(
            'pretty_version' => '2.7.6',
            'version' => '2.7.6.0',
            'reference' => '897eb517a343a2281f11bc5556d6548db7d93947',
            'type' => 'library',
            'install_path' => __DIR__ . '/../masterminds/html5',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/net_url2' => array(
            'pretty_version' => 'v2.2.2',
            'version' => '2.2.2.0',
            'reference' => '07fd055820dbf466ee3990abe96d0e40a8791f9d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pear/net_url2',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-message' => array(
            'pretty_version' => '1.0.1',
            'version' => '1.0.1.0',
            'reference' => 'f6561bf28d520154e4b0ec72be95418abe6d9363',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-message',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/log' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '*',
            ),
        ),
        'riimu/kit-pathjoin' => array(
            'pretty_version' => 'v1.2.0',
            'version' => '1.2.0.0',
            'reference' => '8ad2656c79527dba9f7f20e1229dcd38abfe8cee',
            'type' => 'library',
            'install_path' => __DIR__ . '/../riimu/kit-pathjoin',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/console' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '*',
            ),
        ),
    ),
);
