OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Sikertelen kérés, a hálózati kapcsolat nem érhető el.",
    "Request unauthorized. Are you logged in?" : "Jogosulatlan kérés. Be van jelentkezve?",
    "Request forbidden. Are you an administrator?" : "Tiltott kérés. Rendszergazda Ön?",
    "Token expired or app not enabled! Reload the page!" : "Lejárt a token, vagy az alkalmazás nem engedélyezett. Töltse újra az oldalt.",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Belső kiszolgálóhiba! További információkért ellenőrizze a data/nextcloud.log fájlt.",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Kérés sikértelen, a Nextcloud jelenleg karbantartási módban van.",
    "News feeds" : "Hírcsatornák",
    "Unread articles" : "Olvasatlan cikkek",
    "News" : "Hírek",
    "News folders" : "Hírek mappái",
    "Shared with me" : "Megosztva velem",
    "An RSS/Atom feed reader" : "Egy RSS/Atom-hírcsatorna olvasó",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Egy RSS/Atom hírolvasó alkalmazás a Nextcloudhoz\n\n- 📲 Hírcsatornák szinkronizálása több mobil- vagy asztali [klienssel](https://nextcloud.github.io/news/clients/)\n- 🔄 Hírcsatornák automatikus frissítése\n- 🆓 Szabad és nyílt forráskódú, AGPLv3 licenc alatt, hirdetések és prémium funkciók nélkül\n\n**Az alkalmazás működéséhez jelenleg a rendszer cron használata szükséges**\n\nA követelmények [itt találhatók](https://nextcloud.github.io/news/install/#dependencies)\n\nA változásnapló pedig [itt](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nKészítsen egy [hibajelentést](https://github.com/nextcloud/news/issues/new/choose)\n\nKészítsen egy [funkciókérést](https://github.com/nextcloud/news/discussions/new)\n\nJelentse egy [hírcsatorna problémáját](https://github.com/nextcloud/news/discussions/new)",
    "Use system cron for updates" : "A rendszer cron használata a frissítésekhez",
    "Disable this if you use a custom updater." : "Tiltsa le, ha egyéni frissítőt használ.",
    "Maximum read count per feed" : "Maximális olvasási szám hírfolyamonként",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Meghatározza a hírcsatornánként olvasható cikkek maximális mennyiségét, amelyeket a törlési feladat nem töröl; ha a régi cikkek újra megjelennek olvasás után, növelje ezt az értéket; negatív értékek, például a -1 kikapcsolja ezt a funkciót.",
    "Delete unread articles automatically" : "Az olvasatlan cikkek automatikus törlése",
    "Enable this if you also want to delete unread articles." : "Kapcsolja be, ha törölni szeretné az olvasatlan cikkeket.",
    "Maximum redirects" : "Maximum átirányítás",
    "How many redirects the feed fetcher should follow." : "Hány átirányítást kell követnie a hírcsatornának.",
    "Feed fetcher timeout" : "Hírfolyam letöltő időtúllépés",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "A maximális idő, amennyit egy RSS vagy Atom hírcsatorna olvasására vár. Ha tovább tart, akkor a frissítés meg lesz szakítva.",
    "Explore Service URL" : "Szolgáltatásfelderítési URL",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Ha meg van adva, ezt a szolgáltatási címet ellenőrzi a hírcsatorna-megjelenítő rész megnyitásakor. Az eredeti szolgáltatásfelderítő használatához hagyja üresen.",
    "Update interval" : "Frissítési időszak",
    "Interval in seconds in which the feeds will be updated." : "A hírcsatornák frissítési intervalluma másodpercekben.",
    "Successfully updated news configuration" : "A hírek beállítása sikeresen frissítve",
    "Unable to update news config" : "A hírek beállításai nem frissíthetők",
    "Download" : "Letöltés",
    "Close" : "Bezárás",
    "Subscribe to" : "Feliratkozás:",
    "No articles available" : "Nincsenek elérhető cikkek",
    "No unread articles available" : "Nincsenek elérhető olvasatlan cikkek",
    "Open website" : "Weboldal megnyitása",
    "Star article" : "Cikk csillagozása",
    "Unstar article" : "Cikk csillagozásának eltávolítása",
    "Keep article unread" : "Cikk olvasatlanul hagyása",
    "Remove keep article unread" : "Cikk olvasatlanul hagyásának eltávolítása",
    "Share" : "Megosztás",
    "Share with users" : "Megosztás felhasználókkal",
    "Username" : "Felhasználónév",
    "No users found" : "Nem találhatók felhasználók",
    "Error while searching for users" : "Hiba történt a felhasználók keresésekor",
    "Share on social media" : "Megosztás a közösségi médiában",
    "I wanted you to see this article" : "Azt akartam, hogy lássa ezt a cikket",
    "Check out this article" : "Nézze meg ezt a cikket",
    "by" : "közreadta:",
    "from" : "forrás:",
    "shared by" : "megosztotta:",
    "Play audio" : "Hang lejátszása",
    "Download audio" : "Hang letöltése",
    "Download video" : "Videó letöltése",
    "Keyboard shortcut" : "Gyorsbillentyű",
    "Description" : "Leírás",
    "right" : "jobbra",
    "Jump to next article" : "Ugrás a következő cikkre",
    "left" : "balra",
    "Jump to previous article" : "Ugrás az előző cikkre",
    "Toggle star article" : "Cikk csillagozása be/ki",
    "Star article and jump to next one" : "Cikk csillagozása, és ugrás a következőre",
    "Toggle keep current article unread" : "Cikk olvasatlanul hagyása be/ki",
    "Open article in new tab" : "Cikk megnyitása új lapon",
    "Toggle expand article in compact view" : "Cikk kibontásának kompakt nézetben be/ki",
    "Refresh" : "Frissítés",
    "Load next feed" : "Következő hírfolyam betöltése",
    "Load previous feed" : "Előző hírfolyam betöltése",
    "Load previous folder" : "Előző mappa betöltése",
    "Load next folder" : "Következő mappa betöltése",
    "Scroll to active navigation entry" : "Görgetés az aktív navigációs bejegyzéshez",
    "Mark current article's feed/folder read" : "Aktuális cikk hírcsatornájának/mappájának megjelölése olvasottként",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax vagy webcron mód észlelve. A hírcsatornái nem lesznek frissítve.",
    "How to set up the operating system cron" : "Hogyan állítsa be az operációs rendszer cron időzítőjét",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Új gyorsabb, párhuzamosított frissítő telepítése, amely a Hírek alkalmazás frissítési API-ját használja",
    "Subscribe" : "Feliratkozás",
    "Web address" : "Webcím",
    "Feed exists already!" : "A hírcsatorna már létezik.",
    "Folder" : "Mappa",
    "No folder" : "Nincs mappa",
    "New folder" : "Új mappa",
    "Folder name" : "Mappanév",
    "Go back" : "Ugrás vissza",
    "Folder exists already!" : "A mappa már létezik.",
    "Credentials" : "Hitelesítő adatok",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "A HTTP Basic hitelesítési adatokat titkosítás nélkül kell tárolni. Bárki, aki hozzáfér a kiszolgálóhoz vagy az adatbázishoz, olvashatja azt.",
    "Password" : "Jelszó",
    "Auto discover Feed" : "Hírcsatorna automatikus felderítése",
    "New Folder" : "Új mappa",
    "Create" : "Létrehozás",
    "Explore" : "Felfedezés",
    "Update failed more than 50 times" : "Sikertelen frissítés több mint 50-szer",
    "Deleted feed" : "Törölt hírcsatorna",
    "Undo delete feed" : "Hírcsatorna törlés visszavonása",
    "Rename" : "Átnevezés",
    "Menu" : "Menü",
    "Mark read" : "Olvasottnak jelölés",
    "Unpin from top" : "Rögzítés feloldása",
    "Pin to top" : "Rögzítés a tetejére",
    "Newest first" : "Legújabb először",
    "Oldest first" : "Legrégebbi először",
    "Default order" : "Alapértelmezett sorrend",
    "Enable full text" : "Teljes szöveges mód engedélyezése",
    "Disable full text" : "Teljes szöveges mód letiltása",
    "Unread updated" : "Olvasatlan cikk frissítve",
    "Ignore updated" : "Frissített cikk mellőzése",
    "Open feed URL" : "Hírcsatorna URL megnyitása",
    "Delete" : "Törlés",
    "Dismiss" : "Elutasítás",
    "Collapse" : "Összecsukás",
    "Deleted folder" : "Törölt mappa",
    "Undo delete folder" : "Mappa törlésének visszavonása",
    "Starred" : "Csillagozott",
    "All articles" : "Minden cikk",
    "Settings" : "Beállítások",
    "Disable mark read through scrolling" : "Görgetés közbeni olvasottnak jelölés kikapcsolása",
    "Compact view" : "Kompakt nézet",
    "Expand articles on key navigation" : "Cikkek kibontása billentyűs navigációkor",
    "Show all articles" : "Minden cikk megjelenítése",
    "Reverse ordering (oldest on top)" : "Fordított sorrend (régebbi felül)",
    "Subscriptions (OPML)" : "Feliratkozások (OPML)",
    "Import" : "Importálás",
    "Export" : "Exportálás",
    "Error when importing: File does not contain valid OPML" : "Hiba az importáláskor: A fájl nem tartalmaz érvényes OPML-t",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Hiba az importáláskor: az OPML nem tartalmaz sem hírcsatornákat, sem mappákat",
    "Unread/Starred Articles" : "Olvasatlan/csillagozott cikkek",
    "Error when importing: file does not contain valid JSON" : "Hiba az importáláskor: a fájl nem tartalmaz érvényes JSON adatokat",
    "Help" : "Súgó",
    "Keyboard shortcuts" : "Gyorsbillentyűk",
    "Documentation" : "Dokumentáció",
    "Report a bug" : "Hiba bejelentése"
},
"nplurals=2; plural=(n != 1);");
