OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Forespørgslen mislykkedes, netværksforbindelse er ikke tilgængelig!",
    "Request unauthorized. Are you logged in?" : "Forespørgslen var ikke autoriseret. Er du logget ind?",
    "Request forbidden. Are you an administrator?" : "Anmodning forbudt. Er du administrator?",
    "Token expired or app not enabled! Reload the page!" : "Nøglen er udløbet  eller appen er ikke aktiveret! Genindlæs siden!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Intern server fejl! Tjek din data/nextcloud.log log-fil for yderligere information.",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Forespørgslen mislykkedes, Nextcloud er i øjeblikket i vedligeholdelse tilstand!",
    "News feeds" : "Nyhedsfeeds",
    "Unread articles" : "Ulæste artikler",
    "News" : "Nyheder",
    "News folders" : "Nyhedsmapper",
    "Shared with me" : "Delt med mig",
    "An RSS/Atom feed reader" : "En RSS/Atom-feedlæser",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 En RSS/Atom Feed-læser-app til Nextcloud\n\n- 📲 Synkroniser dine feeds med flere mobile eller desktop [klienter](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatiske opdateringer af dine nyhedsfeeds\n- 🆓 Gratis og open source under AGPLv3, ingen annoncer eller premium-funktioner\n\n**System Cron er i øjeblikket påkrævet for at denne app kan fungere**\n\nKravene kan findes [her](https://nextcloud.github.io/news/install/#dependencies)\n\nÆndringsloggen er tilgængelig [her](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nOpret en [fejlrapport](https://github.com/nextcloud/news/issues/new/choose)\n\nOpret en [funktionsanmodning](https://github.com/nextcloud/news/discussions/new)\n\nRapporter et [feedproblem](https://github.com/nextcloud/news/discussions/new)",
    "Use system cron for updates" : "Benyt system cron til opdateringer",
    "Disable this if you use a custom updater." : "Deaktiver dette, hvis du bruger en brugerdefineret opdatering.",
    "Maximum read count per feed" : "Det maksimale antal læsninger per feed",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Definerer den maksimale mængde af artikler, der kan læses pr. feed, som ikke vil blive slettet af oprydningsjobbet; hvis gamle artikler dukker op igen efter at være blevet læst, skal du øge denne værdi; negative værdier såsom -1 vil slå denne funktion fra.",
    "Maximum redirects" : "Maksimum for videredirigeringer",
    "How many redirects the feed fetcher should follow." : "Hvor mange omdirigeringer feedhenteren skal følge.",
    "Feed fetcher timeout" : "Tidsudløb for feed-indhenter",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maksimalt antal sekunder at vente på, at et RSS- eller Atom-feed indlæses; hvis det tager længere tid, vil opdateringen blive afbrudt.",
    "Explore Service URL" : "Udforsk tjenestens URL",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Hvis det er givet, vil denne tjenestes URL blive forespurgt for at vise feeds i sektionen Udforsk feed. For at falde tilbage til den indbyggede udforskningstjeneste skal du lade dette input stå tomt.",
    "Update interval" : "Opdateringsinterval",
    "Interval in seconds in which the feeds will be updated." : "Interval i sekunder, hvori feeds vil blive opdateret.",
    "Successfully updated news configuration" : "Nyhedskonfigurationen blev opdateret",
    "Unable to update news config" : "Kunne ikke opdatere nyhedskonfigurationen",
    "Download" : "Download",
    "Close" : "Luk",
    "Subscribe to" : "Abonnere på",
    "No articles available" : "Ingen tilgængelige artikler",
    "No unread articles available" : "Ingen tilgængelige ulæste artikler",
    "Open website" : "Åbn websted",
    "Star article" : "Stjernemarkér artiklen",
    "Unstar article" : "Fjern stjerne fra artiklen",
    "Keep article unread" : "Bevar artikel ulæst",
    "Remove keep article unread" : "Fjern \"bevar artikel ulæst\"",
    "Share" : "Del",
    "Share with users" : "Del med brugere",
    "Username" : "Brugernavn",
    "No users found" : "Ingen brugere fundet",
    "Error while searching for users" : "Fejl under søgning efter brugere",
    "Share on social media" : "Del på sociale medier",
    "I wanted you to see this article" : "Jeg ville have dig til at se denne artikel",
    "Check out this article" : "Tjek denne artikel",
    "by" : "af",
    "from" : "fra",
    "shared by" : "delt af",
    "Play audio" : "Afspil lydfil",
    "Download audio" : "Hent lydfil",
    "Download video" : "Hent video",
    "Keyboard shortcut" : "Tastaturgenvej",
    "Description" : "Beskrivelse",
    "right" : "højre",
    "Jump to next article" : "Gå til næste artikel",
    "left" : "venstre",
    "Jump to previous article" : "Gå til forrige artikel",
    "Toggle star article" : "Slå stjerne for artikel til/fra",
    "Star article and jump to next one" : "Stjernemarkér artikel og få til den næste",
    "Toggle keep current article unread" : "Slå \"bevar nuværende artikel ulæst\" til/fra",
    "Open article in new tab" : "Åbn artikel i en ny fane",
    "Toggle expand article in compact view" : "Slå \"udvid artikel i kompakt visning\" til/fra",
    "Refresh" : "Opdatér",
    "Load next feed" : "Indlæs næste feed",
    "Load previous feed" : "Indlæs forrige feed",
    "Load previous folder" : "Indlæs forrige mappe",
    "Load next folder" : "Indlæs næste mappe",
    "Scroll to active navigation entry" : "Rul frem til aktive navigationspost",
    "Mark current article's feed/folder read" : "Markér nuværende artikels feed/mappe som læst",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax eller webcron tilstand opdaget! Dine feed vil ikke blive opdateret!",
    "How to set up the operating system cron" : "Sådan opsætter du cron i operativsystemet",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Installere og oprette en hurtigere parallel opdateringsprogram, der bruger Nyheds app's opdateringsAPI",
    "Subscribe" : "Abonner",
    "Web address" : "Web adresse",
    "Feed exists already!" : "Feedet findes allerede!",
    "Folder" : "Mappe",
    "No folder" : "Ingen Mappe",
    "New folder" : "Ny mappe",
    "Folder name" : "Mappenavn",
    "Go back" : "Gå tilbage",
    "Folder exists already!" : "Mappen findes allerede!",
    "Credentials" : "Brugeroplysninger",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Grundlæggende HTTP Autentificerings akkreditiver skal lagres ukrypteret! Alle med adgang til server eller database vil være i stand til at få adgang til dem!",
    "Password" : "Adgangskode",
    "Auto discover Feed" : "Automatisk opdage feed",
    "New Folder" : "Ny mappe",
    "Create" : "Ny",
    "Explore" : "Udforsk",
    "Update failed more than 50 times" : "Opdatering mislykkedes mere end 50 gange",
    "Deleted feed" : "Slet feed",
    "Undo delete feed" : "Fortryd sletning af feed",
    "Rename" : "Omdøb",
    "Menu" : "Menu",
    "Mark read" : "Marker som læst",
    "Unpin from top" : "Frigør fra toppen",
    "Pin to top" : "Fastgør til toppen",
    "Newest first" : "Nyeste først",
    "Oldest first" : "Ældste først",
    "Default order" : "Standard rækkefølge",
    "Enable full text" : "Slå fuld tekst til",
    "Disable full text" : "Slå fuld tekst fra",
    "Unread updated" : "Ulæste opdateret",
    "Ignore updated" : "Ignorér updaterede",
    "Open feed URL" : "Åbn feed URL",
    "Delete" : "Slet",
    "Dismiss" : "Afvis",
    "Collapse" : "Sammenfold",
    "Deleted folder" : "Slettede mappen",
    "Undo delete folder" : "Fortryd sletning af mappe",
    "Starred" : "Stjernemarkéret",
    "All articles" : "Alle artikler",
    "Settings" : "Indstillinger",
    "Disable mark read through scrolling" : "Slå markér som læst fra når der rulles",
    "Compact view" : "Kompakt visning",
    "Expand articles on key navigation" : "Udvid artikler ved tastenavigation",
    "Show all articles" : "Vis alle artikler",
    "Reverse ordering (oldest on top)" : "Vend om på rækkefølgen (ældste øverst)",
    "Subscriptions (OPML)" : "Abonnementer (OPML)",
    "Import" : "Importer",
    "Export" : "Eksportér",
    "Error when importing: File does not contain valid OPML" : "Fejl under importering: Fil indeholder ikke valid OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Fejl ved import: OPML indeholder hverken feeds eller mapper",
    "Unread/Starred Articles" : "Ulæste/stjernemarkerede artikler",
    "Error when importing: file does not contain valid JSON" : "Fejl ved import: filen indeholder ikke gyldig JSON kode",
    "Help" : "Hjælp",
    "Keyboard shortcuts" : "Tastaturgenveje",
    "Documentation" : "Dokumentation",
    "Report a bug" : "Rapporter en fejl"
},
"nplurals=2; plural=(n != 1);");
