OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Permintaan gagal, koneksi jaringan tidak tersedia!",
    "Request unauthorized. Are you logged in?" : "Permintaan tidak sah. Apakah Anda sudah masuk?",
    "Token expired or app not enabled! Reload the page!" : "Token telah kadaluarsa atau aplikasi tidak diaktifkan! Muat ulang halaman!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Kesalahan internal server! Mohon cek berkas data/nextcloud.log Anda untuk informasi lebih lanjut!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Permintaan gagal, Nextcloud sedang dalam mode pemeliharaan!",
    "Unread articles" : "Artikel belum dibaca",
    "Use system cron for updates" : "Gunakan cron sistem untuk pembaruan",
    "Maximum read count per feed" : "Jumlah baca maksimum per feed",
    "Maximum redirects" : "Pengalihan maksimum",
    "Feed fetcher timeout" : "Pengambil feed kehabisan waktu",
    "Explore Service URL" : "URL Layanan Jelajah",
    "Download" : "Unduh",
    "Close" : "Tutup",
    "No articles available" : "Tidak ada artikel yang tersedia",
    "No unread articles available" : "Tidak ada artikel yang belum dibaca",
    "Open website" : "Buka situs web",
    "Star article" : "Bintangi artikel",
    "Unstar article" : "Hapus bintang artikel",
    "Keep article unread" : "Tandai artikel belum dibaca",
    "Remove keep article unread" : "Hapus tanda artikel belum dibaca",
    "Share" : "Bagikan",
    "Username" : "Nama pengguna",
    "by" : "oleh",
    "from" : "dari",
    "Play audio" : "Putar audio",
    "Download audio" : "Unduh audio",
    "Download video" : "Unduh video",
    "Keyboard shortcut" : "Pintasan keyboard",
    "Description" : "Keterangan",
    "right" : "kanan",
    "Jump to next article" : "Lompat ke artikel berikutnya",
    "left" : "kiri",
    "Jump to previous article" : "Lompat ke artikel sebelumnya",
    "Toggle star article" : "Tombol alih bintangi artikel",
    "Star article and jump to next one" : "Bintangi artikel dan lompat ke berikutnya",
    "Toggle keep current article unread" : "Tombol alih tandai artikel saat ini belum dibaca",
    "Open article in new tab" : "Buka artikel di tab baru",
    "Toggle expand article in compact view" : "Tombol alih perluas tulisan dalam tampilan kompak",
    "Refresh" : "Segarkan",
    "Load next feed" : "Muat feed berikutnya",
    "Load previous feed" : "Muat feed sebelumnya",
    "Load previous folder" : "Muat folder sebelumnya",
    "Load next folder" : "Muat folder berikutnya",
    "Scroll to active navigation entry" : "Gulir ke entri navigasi aktif",
    "Mark current article's feed/folder read" : "Tandai feed/folder artikel saat ini telah dibaca",
    "How to set up the operating system cron" : "Bagaimana cara menyetel cron sistem operasi",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Pasang dan atur pembaruan paralel yang lebih cepat yang menggunakan API pembaruan aplikasi Berita",
    "Subscribe" : "Berlangganan",
    "Web address" : "Alamat web",
    "Feed exists already!" : "Feed sudah ada!",
    "Folder" : "Folder",
    "No folder" : "Tidak ada folder",
    "New folder" : "Folder baru",
    "Folder name" : "Nama folder",
    "Go back" : "Kembali",
    "Folder exists already!" : "Folder sudah ada!",
    "Credentials" : "Kredensial",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Kredensial HTTP Basic Auth harus disimpan tidak terenkripsi! Semua dengan akses ke server atau database akan bisa mengaksesnya!",
    "Password" : "Kata Sandi",
    "New Folder" : "Folder Baru",
    "Create" : "Buat",
    "Explore" : "Jelajah",
    "Update failed more than 50 times" : "Pembaruan gagal lebih dari 50 kali",
    "Deleted feed" : "Feed yang dihapus",
    "Undo delete feed" : "Batalkan hapus feed",
    "Rename" : "Ubah nama",
    "Menu" : "Menu",
    "Newest first" : "Terbaru",
    "Oldest first" : "Paling lama",
    "Delete" : "Hapus",
    "Dismiss" : "Buang",
    "Collapse" : "Tutup",
    "Deleted folder" : "Folder yang dihapus",
    "Undo delete folder" : "Batalkan hapus folder",
    "Starred" : "Dibintangi",
    "All articles" : "Semua artikel",
    "Settings" : "Pengaturan",
    "Disable mark read through scrolling" : "Menonaktifkan tandai baca melalui pengguliran",
    "Compact view" : "Tampilan kompak",
    "Expand articles on key navigation" : "Perluas artikel di tombol navigasi",
    "Show all articles" : "Tampilkan semua artikel",
    "Reverse ordering (oldest on top)" : "Pengurutan terbalik (yang lama diatas)",
    "Subscriptions (OPML)" : "Berlangganan (OPML)",
    "Import" : "Impor",
    "Export" : "Ekspor",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Terjadi kesalahan saat mengimpor: OPML tidak berisi feed ataupun folder",
    "Unread/Starred Articles" : "Artikel dibintangi/belum dibaca",
    "Error when importing: file does not contain valid JSON" : "Terjadi kesalahan saat mengimor: berkas tidak berisi JSON yang sah",
    "Help" : "Bantuan",
    "Keyboard shortcuts" : "Pintasan keyboard",
    "Documentation" : "Dokumentasi",
    "Report a bug" : "Laporkan kerusakan"
},
"nplurals=1; plural=0;");
