OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "คำขอล้มเหลวเชื่อมต่อเครือข่ายไม่ได้!",
    "Request unauthorized. Are you logged in?" : "คำขอไม่ได้รับอนุญาต คุณเข้าสู่ระบบ?",
    "Token expired or app not enabled! Reload the page!" : "โทเค็นหมดอายุหรือไม่เปิดใช้งานแอพพลิเคชัน! โหลดหน้าใหม่อีกครั้ง!",
    "Unread articles" : "บทความที่ยังไม่ได้อ่าน",
    "Maximum read count per feed" : "นับจำนวนอ่านสูงสุดต่อฟีด",
    "Maximum redirects" : "เปลี่ยนเส้นทางสูงสุด",
    "Feed fetcher timeout" : "ตัวเรียกฟีดหมดเวลา",
    "Explore Service URL" : "สำรวจบริการ URL",
    "Download" : "ดาวน์โหลด",
    "Close" : "ปิด",
    "No articles available" : "ไม่มีบทความที่",
    "No unread articles available" : "ไม่มีบทความที่ยังไม่ได้อ่าน",
    "Open website" : "เปิดเว็บไซต์",
    "Star article" : "บทความติดดาว",
    "Unstar article" : "ยกเลิกติดดาวบทความ",
    "Keep article unread" : "ตั้งเป็นยังไม่ได้อ่านบทความ",
    "Remove keep article unread" : "ลบการตั้งเป็นยังไม่ได้อ่านบทความ",
    "Share" : "แชร์",
    "Username" : "ชื่อผู้ใช้",
    "by" : "โดย",
    "from" : "จาก",
    "Play audio" : "เล่นเพลง",
    "Download audio" : "ดาวน์โหลดเพลง",
    "Download video" : "ดาวน์โหลดวิดีโอ",
    "Keyboard shortcut" : "แป้นพิมพ์ลัด",
    "Description" : "คำอธิบาย",
    "right" : "ขวา",
    "Jump to next article" : "ข้ามไปยังบทความถัดไป",
    "left" : "ซ้าย",
    "Jump to previous article" : "ข้ามไปยังบทความก่อนหน้านี้",
    "Toggle star article" : "สลับบทความติดดาว",
    "Star article and jump to next one" : "บทความติดดาวและกระข้ามไปอีกหน้าหนึ่ง",
    "Toggle keep current article unread" : "สลับให้บทความในปัจจุบันยังไม่ได้อ่าน",
    "Open article in new tab" : "เปิดบทความในแท็บใหม่",
    "Toggle expand article in compact view" : "สลับการขยายบทความในมุมมองที่เล็กลง",
    "Refresh" : "รีเฟรช",
    "Load next feed" : "โหลดฟีดถัดไป",
    "Load previous feed" : "โหลดฟีดก่อนหน้านี้",
    "Load previous folder" : "โหลดโฟลเดอร์ก่อนหน้า",
    "Load next folder" : "โหลดโฟลเดอร์ถัดไป",
    "Scroll to active navigation entry" : "เลื่อนเพื่อใช้งานรายการนำทาง",
    "Mark current article's feed/folder read" : "ทำเครื่องหมายอ่านบทความปัจจุบัน ฟีด/โฟลเดอร์",
    "How to set up the operating system cron" : "วิธีการตั้งค่าระบบปฏิบัติการ cron",
    "Install and set up a faster parallel updater that uses the News app's update API" : "ติดตั้งและตั้งค่าการอัพเดทขนานที่เร็วขึ้นน้้นใช้ แอพฯข่าวการอัพเดท API",
    "Subscribe" : "สมัครรับข้อมูล",
    "Web address" : "ที่อยู่เว็บ",
    "Feed exists already!" : "ฟีดมีอยู่แล้วในระบบ!",
    "Folder" : "แฟ้มเอกสาร",
    "No folder" : "ไม่มีโฟลเดอร์",
    "New folder" : "โฟลเดอร์ใหม่",
    "Folder name" : "ชื่อโฟลเดอร์",
    "Go back" : "กลับไป",
    "Folder exists already!" : "โฟลเดอร์มีอยู่แล้วในระบบ",
    "Credentials" : "ข้อมูลส่วนตัวสำหรับเข้าระบบ",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "ข้อมูลประจำตัวการตรวจสอบสิทธิ์พื้นฐานของ HTTP จะต้องเก็บไว้แบบไม่ได้เข้ารหัสลับ! ทุกคนที่มีการเข้าถึงเซิร์ฟเวอร์หรือฐานข้อมูลจะสามารถเข้าถึงมันได้!",
    "Password" : "รหัสผ่าน",
    "New Folder" : "โฟลเดอร์ใหม่",
    "Create" : "สร้าง",
    "Explore" : "สำรวจ",
    "Update failed more than 50 times" : "อัพเดทล้มเหลวมากกว่า 50 ครั้ง",
    "Deleted feed" : "ฟีดที่ถูกลบ",
    "Undo delete feed" : "ยกเลิกการลบฟีด",
    "Rename" : "เปลี่ยนชื่อ",
    "Menu" : "เมนู",
    "Delete" : "ลบ",
    "Dismiss" : "ยกเลิก",
    "Collapse" : "ย่อ",
    "Deleted folder" : "โฟลเดอร์ที่ถูกลบ",
    "Undo delete folder" : "ยกเลิกการลบโฟลเดอร์",
    "Starred" : "ติดดาวแล้ว",
    "All articles" : "บทความทั้งหมด",
    "Settings" : "ตั้งค่า",
    "Disable mark read through scrolling" : "ปิดการใช้งานเครื่องหมายอ่านอ่านแล้วผ่านการเลื่อน",
    "Compact view" : "มุมมองขนาดเล็ก",
    "Expand articles on key navigation" : "ขยายบทความเกี่ยวกับการนำทางที่สำคัญ",
    "Show all articles" : "แสดงบทความทั้งหมด",
    "Reverse ordering (oldest on top)" : "ย้อนกลับรายการ (เก่าที่สุดอยู่ด้านบน)",
    "Subscriptions (OPML)" : "สมัครเป็นสมาชิก (OPML)",
    "Import" : "นำเข้า",
    "Export" : "ส่งออก",
    "Error when importing: OPML is does neither contain feeds nor folders" : "ข้อผิดพลาดเมื่อนำเข้า: OPML ไม่มีค่าฟีดหรือโฟลเดอร์",
    "Unread/Starred Articles" : "บทความที่ ยังไม่ได้อ่าน/ติดดาว",
    "Error when importing: file does not contain valid JSON" : "ข้อผิดพลาดเมื่อนำเข้า: ไฟล์มี JSON ที่ไม่ถูกต้อง",
    "Help" : "ช่วยเหลือ",
    "Keyboard shortcuts" : "ปุ่มลัด",
    "Documentation" : "เอกสารคู่มือประกอบการใช้งาน",
    "Report a bug" : "รายงานข้อผิดพลาด"
},
"nplurals=1; plural=0;");
