OC.L10N.register(
    "news",
    {
    "Unread articles" : "Nelegitaj artikoloj",
    "News" : "Novaĵo",
    "Download" : "Elŝuti",
    "Close" : "Fermi",
    "Open website" : "Malfermi TTT-ejon",
    "Share" : "Kunhavigi",
    "Username" : "Uzantonomo",
    "by" : "de",
    "from" : "el",
    "Description" : "Priskribo",
    "right" : "dekstro",
    "left" : "maldekstro",
    "Refresh" : "Refreŝigi",
    "Subscribe" : "Aboni",
    "Web address" : "TTT-adreso",
    "Folder" : "Dosierujo",
    "No folder" : "Neniu dosierujo",
    "New folder" : "Nova dosierujo",
    "Folder name" : "Dosierujnomo",
    "Go back" : "Revenu",
    "Folder exists already!" : "Dosierujo jam ekzistas!",
    "Credentials" : "Aŭtentigiloj",
    "Password" : "Pasvorto",
    "New Folder" : "Nova dosierujo",
    "Create" : "Krei",
    "Deleted feed" : "Forigis fluon",
    "Undo delete feed" : "Malfari forigon de fluo",
    "Rename" : "Alinomigi",
    "Mark read" : "Marki kiel legita",
    "Newest first" : "Pli novaj unue",
    "Oldest first" : "Malpli novaj unue",
    "Delete" : "Forigi",
    "Dismiss" : "Forsendi",
    "Collapse" : "Maletendi",
    "Deleted folder" : "Foriĝis dosierujo",
    "Undo delete folder" : "Malfari forigon de dosierujo",
    "Starred" : "Markita",
    "All articles" : "Ĉiuj artikoloj",
    "Settings" : "Agordo",
    "Show all articles" : "Montri ĉiujn artikolojn",
    "Import" : "Enporti",
    "Export" : "Elporti",
    "Error when importing: file does not contain valid JSON" : "La enporto eraris: la dosiero ne enhavas validan JSON-on",
    "Help" : "Helpo",
    "Keyboard shortcuts" : "Fulmoklavoj",
    "Documentation" : "Dokumentaro",
    "Report a bug" : "Raporti problemon"
},
"nplurals=2; plural=(n != 1);");
