OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Request failed, network connection unavailable!",
    "Download" : "Download",
    "Close" : "Close",
    "Username" : "Username",
    "right" : "right",
    "left" : "left",
    "Refresh" : "Refresh",
    "New folder" : "New folder",
    "Folder name" : "Folder name",
    "Credentials" : "Hisob ma'lumotlari",
    "Password" : "Password",
    "Rename" : "Rename",
    "Delete" : "Delete",
    "Dismiss" : "Dismiss",
    "Settings" : "Settings",
    "Help" : "Help"
},
"nplurals=1; plural=0;");
