OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Błędne żądanie, połączenie sieciowe jest niedostępne!",
    "Request unauthorized. Are you logged in?" : "Żądanie nieautoryzowane. Jesteś zalogowany?",
    "Request forbidden. Are you an administrator?" : "Zapytanie niedozwolone. Czy jesteś administratorem?",
    "Token expired or app not enabled! Reload the page!" : "Token wygasł lub aplikacja nie jest włączona! Przeładuj stronę!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Wewnętrzny błąd serwera! Proszę sprawdzić plik data/nextcloud.log w celu uzyskania dodatkowych informacji!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Nie wykonano żądania, Nextcloud działa obecnie w trybie konserwacji!",
    "News feeds" : "Kanały wiadomości",
    "Unread articles" : "Nieprzeczytane artykuły",
    "News" : "Wiadomości",
    "News folders" : "Katalogi z wiadomościami",
    "Shared with me" : "Udostępnione dla mnie",
    "An RSS/Atom feed reader" : "Czytnik kanałów RSS/Atom",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Aplikacja do czytania kanałów RSS/Atom dla Nextcloud\n\n- 📲 Synchronizuj swoje kanały z wieloma [klientami](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatyczne aktualizacje kanałów informacyjnych\n- 🆓 Darmowe i otwarte źródło w ramach AGPLv3, bez reklam i funkcji premium\n\n**System Cron jest obecnie wymagany do działania tej aplikacji**\n\nWymagania można znaleźć [tutaj](https://nextcloud.github.io/news/install/#dependencies)\n\nDziennik zmian jest dostępna [tutaj](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nUtwórz [raport o błędzie](https://github.com/nextcloud/news/issues/new/choose)\n\nUtwórz [żądanie funkcji](https://github.com/nextcloud/news/discussions/new)\n\nZgłoś [problem z kanałem](https://github.com/nextcloud/news/discussions/new)",
    "Use system cron for updates" : "Użyj systemowego crona do aktualizacji",
    "Disable this if you use a custom updater." : "Wyłącz tę opcję, jeśli używasz niestandardowego aktualizatora.",
    "Maximum read count per feed" : "Maksymalna ilość odczytów na kanał",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Definiuje maksymalną ilość artykułów, które mogą być odczytane przez kanał, a nie będą usuwane podczas zadania czyszczenia; zwiększ wartość jeśli starsze artykuły pojawią się ponownie po przeczytaniu; ujemne wartości jak -1 wyłączą tę funkcjonalność całkowicie.",
    "Delete unread articles automatically" : "Automatycznie usuwaj nieprzeczytane artykuły",
    "Enable this if you also want to delete unread articles." : "Włącz tę opcję, jeśli chcesz również usuwać nieprzeczytane artykuły.",
    "Maximum redirects" : "Maksymalna liczba przekierowań",
    "How many redirects the feed fetcher should follow." : "Za iloma przekierowaniami ma nastąpić podążanie przy pobieraniu kanałów.",
    "Feed fetcher timeout" : "Czas braku odpowiedzi dla ściągania kanału",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maksymalna liczba sekund oczekiwania na wczytanie kanału RSS lub Atom; jeśli potrwa to zbyt długo, aktualizacja zostanie przerwana.",
    "Explore Service URL" : "Zbadaj adres URL usługi",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Jeśli zostanie podany, adres URL tej usługi zostanie zapytany o wyświetlenie kanałów w sekcji przeglądania kanałów. Aby wrócić do wbudowanej usługi przeglądania, pozostaw to pole puste.",
    "Update interval" : "Interwał aktualizacji",
    "Interval in seconds in which the feeds will be updated." : "Przedział czasu w sekundach, w którym kanały będą zaktualizowane.",
    "Successfully updated news configuration" : "Pomyślnie zaktualizowano konfigurację wiadomości",
    "Unable to update news config" : "Nie można zaktualizować konfiguracji wiadomości",
    "Download" : "Pobierz",
    "Close" : "Zamknij",
    "Subscribe to" : "Subskrybuj",
    "No articles available" : "Brak dostępnych artykułów",
    "No unread articles available" : "Brak nieprzeczytanych artykułów",
    "Open website" : "Otwórz stronę",
    "Star article" : "Oznacz gwiazdką",
    "Unstar article" : "Odznacz gwiazdkę",
    "Keep article unread" : "Oznacz jako nieprzeczytany",
    "Remove keep article unread" : "Usuń oznaczenie jako nieprzeczytany",
    "Share" : "Udostępnij",
    "Share with users" : "Udostępnij użytkownikom",
    "Username" : "Nazwa użytkownika",
    "No users found" : "Nie znaleziono użytkowników",
    "Error while searching for users" : "Błąd podczas wyszukiwania użytkowników",
    "Share on social media" : "Udostępnij w mediach społecznościowych",
    "I wanted you to see this article" : "Chciałem, żebyś zobaczył ten artykuł",
    "Check out this article" : "Przeczytaj ten artykuł",
    "by" : "przez",
    "from" : "z",
    "shared by" : "udostępnione przez",
    "Play audio" : "Odtwarzaj plik audio",
    "Download audio" : "Pobierz audio",
    "Download video" : "Pobierz film",
    "Keyboard shortcut" : "Skrót klawiaturowy",
    "Description" : "Opis",
    "right" : "prawo",
    "Jump to next article" : "Przejdź do następnego artykułu",
    "left" : "lewo",
    "Jump to previous article" : "Przejdź do poprzedniego artykułu",
    "Toggle star article" : "Oznacz artykuł gwiazdką",
    "Star article and jump to next one" : "Oznacz artykuł gwiazdką i przejdź do następnego",
    "Toggle keep current article unread" : "Przełącz oznaczenie aktualnego artykuły jako nieprzeczytany",
    "Open article in new tab" : "Otwórz artykuł w nowej karcie",
    "Toggle expand article in compact view" : "Przełącz rozwijanie artykułu w widok kompaktowy",
    "Refresh" : "Odśwież",
    "Load next feed" : "Wczytaj następny kanał",
    "Load previous feed" : "Wczytaj poprzedni kanał",
    "Load previous folder" : "Wczytaj poprzedni katalog",
    "Load next folder" : "Wczytaj następny katalog",
    "Scroll to active navigation entry" : "Przewiń do aktywnego wpisu nawigacji",
    "Mark current article's feed/folder read" : "Zaznacz obecny kanał/katalog jako przeczytany",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Wykryto ustawienie Ajax lub webcron! Twoje kanały nie będą aktualizowane!",
    "How to set up the operating system cron" : "Jak ustawić cron systemu operacyjnego",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Zainstaluj i ustaw szybszy równoległy aktualizator, który używa do aktualizacji API aplikacji News",
    "Subscribe" : "Subskrybuj",
    "Web address" : "Adres web",
    "Feed exists already!" : "Kanał już istnieje!",
    "Folder" : "Katalog",
    "No folder" : "Brak katalogu",
    "New folder" : "Nowy katalog",
    "Folder name" : "Nazwa katalogu",
    "Go back" : "Wstecz",
    "Folder exists already!" : "Katalog już istnieje!",
    "Credentials" : "Poświadczenia",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Podstawowe poświadczenia uwierzytelnienia HTTP muszą być zapisane odszyfrowane! Każdy posiadający dostęp do serwera lub bazy danych będzie mógł je odczytać!",
    "Password" : "Hasło",
    "Auto discover Feed" : "Automatyczne wykrywanie kanału",
    "New Folder" : "Nowy katalog",
    "Create" : "Utwórz",
    "Explore" : "Przeglądaj",
    "Update failed more than 50 times" : "Aktualizacja nie powiodła się więcej niż 50 razy",
    "Deleted feed" : "Usuń kanał",
    "Undo delete feed" : "Cofnij usunięcie kanału",
    "Rename" : "Zmień nazwę",
    "Menu" : "Menu",
    "Mark read" : "Oznacz jako przeczytane",
    "Unpin from top" : "Odepnij od góry",
    "Pin to top" : "Przypnij do góry",
    "Newest first" : "Najnowsze najpierw",
    "Oldest first" : "Najstarsze najpierw",
    "Default order" : "Kolejność domyślna",
    "Enable full text" : "Włącz pełny tekst",
    "Disable full text" : "Wyłącz pełny tekst",
    "Unread updated" : "Nieprzeczytane zostały zaktualizowane",
    "Ignore updated" : "Zignoruj zaktualizowane",
    "Open feed URL" : "Otwórz URL kanału",
    "Delete" : "Usuń",
    "Dismiss" : "Odrzuć",
    "Collapse" : "Zwiń",
    "Deleted folder" : "Usunięto katalog",
    "Undo delete folder" : "Cofnij usunięcie katalogu",
    "Starred" : "Oznaczone",
    "All articles" : "Wszystkie artykuły",
    "Settings" : "Ustawienia",
    "Disable mark read through scrolling" : "Zablokuj oznaczanie jako przeczytane podczas przewijania",
    "Compact view" : "Widok kompaktowy",
    "Expand articles on key navigation" : "Rozwiń artykuły podczas nawigacji",
    "Show all articles" : "Pokaż wszystkie artykuły",
    "Reverse ordering (oldest on top)" : "Odwrotna kolejność (najstarsze na górze)",
    "Subscriptions (OPML)" : "Subskrypcje (OPML)",
    "Import" : "Importuj",
    "Export" : "Eksportuj",
    "Error when importing: File does not contain valid OPML" : "Błąd podczas importowania: plik nie zawiera prawidłowego OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Błąd podczas importowania: OMPL nie zawiera kanałów lub katalogów",
    "Unread/Starred Articles" : "Nieprzeczytane/Oznaczone Artykuły",
    "Error when importing: file does not contain valid JSON" : "Błąd podczas importowania: plik nie zawiera prawidłowego JSON",
    "Help" : "Pomoc",
    "Keyboard shortcuts" : "Skróty klawiaturowe",
    "Documentation" : "Dokumentacja",
    "Report a bug" : "Zgłoś błąd"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
