OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Aanvraag mislukt, netwerkverbinding niet beschikbaar!",
    "Request unauthorized. Are you logged in?" : "Aanvraag niet toegestaan. Ben je ingelogd?",
    "Token expired or app not enabled! Reload the page!" : "Token verlopen of app niet ingeschakeld! Ververs de pagina!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Interne serverfout! Controleer je data/nextcloud.log bestand voor meer informatie!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Aanvraag mislukt, Nextcloud staat momenteel in onderhoudsmodus!",
    "News feeds" : "Nieuwsfeeds",
    "Unread articles" : "Ongelezen artikelen",
    "News" : "Nieuws",
    "News folders" : "Nieuwsmappen",
    "Shared with me" : "Gedeeld met mij",
    "An RSS/Atom feed reader" : "Een RSS/Atom kanaal lezer",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Een RSS/Atom Feed lezer App voor Nextcloud\n\n- 📲 Synchronizeer je feeds met meerdere mobiele of desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatische updates van je nieuwsfeeds\n- 🆓 Gratis en open source onder AGPLv3, geen advertenties of premium functies\n\n**Systeem Cron is momenteel vereist om deze app te laten werken**\n\nBenodigdheden kunnen [hier](https://nextcloud.github.io/news/install/#dependencies) gevonden worden\n\nHet Veranderingslogboek is [hier](https://github.com/nextcloud/news/blob/master/CHANGELOG.md) beschikbaar\n\nCreëer een [bug rapport](https://github.com/nextcloud/news/issues/new/choose)\n\nCreëer een [functie aanvraag](https://github.com/nextcloud/news/discussions/new)\n\nRapporteer een [feed probleem](https://github.com/nextcloud/news/discussions/new)",
    "Use system cron for updates" : "Gebruik system cron voor updates",
    "Disable this if you use a custom updater." : "Schakel dit uit als je een aangepaste updater gebruikt.",
    "Maximum read count per feed" : "Maximaal aantal gelezen per feed",
    "Maximum redirects" : "Maximum redirects",
    "How many redirects the feed fetcher should follow." : "Hoeveel omleidingen de feed-fetcher moet volgen.",
    "Feed fetcher timeout" : "Feed ophaler timeout",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maximaal aantal seconden om te wachten tot een RSS- of Atom-feed is geladen; als het langer duurt, wordt de update afgebroken.",
    "Explore Service URL" : "Verken service URL",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Indien gegeven, zal de URL van deze service worden opgevraagd voor het weergeven van de feeds in het verkenningsgedeelte. Laat deze invoer leeg om terug te vallen op de ingebouwde verkenningsservice.",
    "Update interval" : "Update interval",
    "Interval in seconds in which the feeds will be updated." : "Interval in seconden waarin de feeds worden bijgewerkt.",
    "Download" : "Downloaden",
    "Close" : "Sluiten",
    "Subscribe to" : "Abonneren op",
    "No articles available" : "Geen artikelen beschikbaar",
    "No unread articles available" : "Geen ongelezen artikelen beschikbaar",
    "Open website" : "Open website",
    "Star article" : "Markeer artikel",
    "Unstar article" : "Demarkeer artikel",
    "Keep article unread" : "Bewaar artikel als ongelezen",
    "Remove keep article unread" : "Verwijder ongelezen houden artikel",
    "Share" : "Delen",
    "Share with users" : "Delen met gebruikers",
    "Username" : "Gebruikersnaam",
    "No users found" : "Geen gebruikers gevonden",
    "Error while searching for users" : "Fout bij zoeken naar gebruikers",
    "Share on social media" : "Delen op social media",
    "I wanted you to see this article" : "Ik wil graag dat je dit artikel ziet",
    "Check out this article" : "Bekijk dit artikel",
    "by" : "door",
    "from" : "van",
    "shared by" : "gedeeld door",
    "Play audio" : "Geluid afspelen",
    "Download audio" : "Audio downloaden",
    "Download video" : "Downloaden video",
    "Keyboard shortcut" : "Sneltoets",
    "Description" : "Beschrijving",
    "right" : "rechts",
    "Jump to next article" : "Ga naar volgend artikel",
    "left" : "links",
    "Jump to previous article" : "Ga naar voorgaand artikel",
    "Toggle star article" : "Omswitchen artikelmarkering ",
    "Star article and jump to next one" : "Markeer artikel en ga naar volgende",
    "Toggle keep current article unread" : "Omswitchen hou huidig artikel ongelezen",
    "Open article in new tab" : "Open artikel in nieuwe tab",
    "Toggle expand article in compact view" : "Omswitchen uitgebreid artikel in compacte weergave",
    "Refresh" : "Vernieuwen",
    "Load next feed" : "Laad volgende feed",
    "Load previous feed" : "Laad voorgaande feed",
    "Load previous folder" : "Laad voorgaande map",
    "Load next folder" : "Laad volgende map",
    "Scroll to active navigation entry" : "Scrollen naar actieve navigatie regel",
    "Mark current article's feed/folder read" : "Markeer feed/map van huidige artikel als gelezen",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax of Web cron mode gedetecteerd! Je feeds worden niet bijgewerkt!",
    "How to set up the operating system cron" : "Hoe wordt de cron-service van het operating system ingesteld",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Installeer en configureer een snellere parallel updater die gebruik maakt van de update API van de Nieuws app",
    "Subscribe" : "Abonneren",
    "Web address" : "Webadres",
    "Feed exists already!" : "Feed bestaat al!",
    "Folder" : "Map",
    "No folder" : "Geen map",
    "New folder" : "Nieuwe map",
    "Folder name" : "Mapnaam",
    "Go back" : "Terug",
    "Folder exists already!" : "Map bestaat al!",
    "Credentials" : "Inloggegevens",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP basis auth gegevens moeten ongecodeerd worden opgeslagen! Iederen die toegang heeft tot de server of database kan deze benaderen! ",
    "Password" : "Wachtwoord",
    "Auto discover Feed" : "Autodiscover Feed",
    "New Folder" : "Nieuwe map",
    "Create" : "Aanmaken",
    "Explore" : "Verkennen",
    "Update failed more than 50 times" : "Update mislukte meer dan 50 keer",
    "Deleted feed" : "Verwijderde feed",
    "Undo delete feed" : "Maak verwijderen feed ongedaan",
    "Rename" : "Naam wijzigen",
    "Menu" : "Menu",
    "Mark read" : "Als gelezen markeren",
    "Unpin from top" : "Bovenaan losmaken",
    "Pin to top" : "Bovenaan vastprikken",
    "Newest first" : "Nieuwste eerst",
    "Oldest first" : "Oudste eerst",
    "Default order" : "Standaard volgorde",
    "Enable full text" : "Inschakelen volledige tekst",
    "Disable full text" : "Uitschakelen volledige tekst",
    "Unread updated" : "Ongelezen bijgewerkt",
    "Ignore updated" : "Negeer bijgewerkt",
    "Open feed URL" : "Open feed URL",
    "Delete" : "Verwijderen",
    "Dismiss" : "Terzijde leggen",
    "Collapse" : "Inklappen",
    "Deleted folder" : "Verwijderde map",
    "Undo delete folder" : "Maak verwijderen map ongedaan",
    "Starred" : "Ster gegeven",
    "All articles" : "Alle artikelen",
    "Settings" : "Instellingen",
    "Disable mark read through scrolling" : "Niet als gelezen markeren door scrollen",
    "Compact view" : "Compact overzicht",
    "Expand articles on key navigation" : "Artikelen uitbreiden bij navigatie",
    "Show all articles" : "Toon alle artikelen",
    "Reverse ordering (oldest on top)" : "Omgekeerde volgorde (oudste boven)",
    "Subscriptions (OPML)" : "Abonnementen (OPML)",
    "Import" : "Importeer",
    "Export" : "Exporteer",
    "Error when importing: File does not contain valid OPML" : "Fout bij importeren: het bestand bevat geen geldige OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Fout bij importeren: OPML bevat geen feed noch folders. ",
    "Unread/Starred Articles" : "Ongelezen/ongemarkeerde artikelen",
    "Error when importing: file does not contain valid JSON" : "Fout tijdens het importeren: bestand bevat geen geldige JSON",
    "Help" : "Help",
    "Keyboard shortcuts" : "Sneltoetsen",
    "Documentation" : "Documentatie",
    "Report a bug" : "Rapporteer een fout"
},
"nplurals=2; plural=(n != 1);");
