OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Неуспешна заявка, няма налична мрежова връзка!",
    "Request unauthorized. Are you logged in?" : "Заявката не е упълномощена. Вписан ли сте?",
    "Request forbidden. Are you an administrator?" : "Заявката е забранена. Вие администратор ли сте?",
    "Token expired or app not enabled! Reload the page!" : "Изтекла парола или приложението не е активирано! Презаредете страницата!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Вътрешно сървърна грешка! За допълнителна информация проверете файла data/nextcloud.log !",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Заявка се провали, Nextcloud в момента е в режим на поддръжка!",
    "News feeds" : "Емисии за новини",
    "Unread articles" : "Непрочетени статии",
    "News" : "Новини",
    "News folders" : "Нови папки",
    "Shared with me" : "Споделено с мен",
    "An RSS/Atom feed reader" : "Четец за RSS/Atom емисии",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Приложение за четене на RSS/Atom Feed за Nextcloud\n\n- 📲 Синхронизирайте емисиите си с множество мобилни или настолни [клиенти](https://nextcloud.github.io/news/clients/)\n- 🔄 Автоматични актуализации на вашите новинарски емисии\n- 🆓 Безплатен и отворен код под AGPLv3, без реклами или премиум функции\n\n**За да работи това приложение, в момента се изисква System Cron**\n\nИзискванията могат да бъдат намерени [тук](https://nextcloud.github.io/news/install/#dependencies)\n\nРегистърът на промените е достъпен [тук](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nСъздайте [отчет за грешка](https://github.com/nextcloud/news/issues/new/choose)\n\nСъздайте [заявка за функция](https://github.com/nextcloud/news/discussions/new)\n\nПодайте сигнал за [проблем с емисия](https://github.com/nextcloud/news/discussions/new)",
    "Use system cron for updates" : "Използване на системния cron за актуализации",
    "Disable this if you use a custom updater." : "Деактивирайте това, ако използвате персонализирана програма за актуализиране.",
    "Maximum read count per feed" : "Максимален брой прочитания на емисия",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Задава максималния брой статии, които могат да бъдат прочетени за всяка емисия, които няма да бъдат изтрити от автоматичната програма за почистване; ако стари статии се появят отново след като са били прочетени, може да увеличите стойността; отрицателни стойности, като \"-1\", изключват напълно тази функционалност.",
    "Delete unread articles automatically" : "Автоматично изтриване на непрочетени статии",
    "Enable this if you also want to delete unread articles." : "Разрешаване на опцията ако искате и да изтривате непрочетени статии.",
    "Maximum redirects" : "Максимален брой пренасочвания",
    "How many redirects the feed fetcher should follow." : "Колко пренасочвания трябва да следва инструментът за извличане на емисии.",
    "Feed fetcher timeout" : "Максимално време за изчакване",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Максималното време в секунди за изчакване зареждането на RSS или Atom емисия; ако отнема по-дълго актуализирането се прекратява",
    "Explore Service URL" : "Разгледайте URL адреса на услугата",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Ако е даден, URL адресът на тази услуга ще бъде поискан за показване на емисиите в секцията за изследване на емисия. За да се върнете към вградената услуга за изследване, оставете тези входи данни празни.",
    "Update interval" : "Интервал за актуализиране",
    "Interval in seconds in which the feeds will be updated." : "Интервал в секунди, в който емисиите ще бъдат актуализирани.",
    "Successfully updated news configuration" : "Успешно актуализирана конфигурация за новини",
    "Unable to update news config" : "Не може да се актуализира конфигурацията за новини",
    "Download" : "Изтегли",
    "Close" : "Затваряне",
    "Subscribe to" : "Абониране за",
    "No articles available" : "Няма статии",
    "No unread articles available" : "Няма непрочетени статии",
    "Open website" : "Отвори интернет станица",
    "Star article" : "Означи със звезда",
    "Unstar article" : "Премахни означаването със звезда",
    "Keep article unread" : "Постоянното означаване като непрочетена",
    "Remove keep article unread" : "Премахни постоянното означаване като непрочетена",
    "Share" : "Споделяне",
    "Share with users" : "Споделяне с потребители",
    "Username" : "Потребител",
    "No users found" : "Няма намерени потребители",
    "Error while searching for users" : "Грешка при търсене на потребители",
    "Share on social media" : "Споделяне в социалните мрежи",
    "I wanted you to see this article" : "Исках да видите тази статия",
    "Check out this article" : "Вижте тази статия",
    "by" : "от",
    "from" : "от",
    "shared by" : "споделено от",
    "Play audio" : "Стартирай аудио",
    "Download audio" : "Изтегли аудио",
    "Download video" : "Изтегли видео",
    "Keyboard shortcut" : "Клавишни комбинации",
    "Description" : "Описание",
    "right" : "дясно",
    "Jump to next article" : "Отиди на следващата статия",
    "left" : "ляво",
    "Jump to previous article" : "Отиди на предната статия",
    "Toggle star article" : "Превключи означаването със звезда",
    "Star article and jump to next one" : "Маркирай като любим и се премести на следващата статия",
    "Toggle keep current article unread" : "Промяна запазва статуса на статията като непрочетена",
    "Open article in new tab" : "Отвори статия в нов таб",
    "Toggle expand article in compact view" : "Промяна разширява статията в комапктен изглед",
    "Refresh" : "Опресняване",
    "Load next feed" : "Следваща емисия",
    "Load previous feed" : "Предишна емисия",
    "Load previous folder" : "Зареди предна папка",
    "Load next folder" : "Зареди следваща папка",
    "Scroll to active navigation entry" : "Превъртете до активен навигационен бутон",
    "Mark current article's feed/folder read" : "Означи статиите от текущият поток/папка като прочетени",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Засечен е Ajax или webcron режим! Емисиите няма да бъдат актуализирани!",
    "How to set up the operating system cron" : "Как се настройва работещия системен cron",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Инсталирайте и настройте по-бърза паралелна програма за актуализиране, която използва API за актуализиране на приложението Новини",
    "Subscribe" : "Абониране",
    "Web address" : "Уеб адрес",
    "Feed exists already!" : "Емисията вече съществува!",
    "Folder" : "Папка",
    "No folder" : "Няма папка",
    "New folder" : "Нова папка",
    "Folder name" : "Име на папката",
    "Go back" : "Назад",
    "Folder exists already!" : "Папката вече съществува!",
    "Credentials" : "Потребител и парола",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth credentials (потребителското име и паролата) ще бъдат записани в некриптиран вид! Те ще бъдат видими за всеки с достъп до сървъра!",
    "Password" : "Парола",
    "Auto discover Feed" : "Емисия за автоматично откриване",
    "New Folder" : "Нова папка",
    "Create" : "Създай",
    "Explore" : "Проучи",
    "Update failed more than 50 times" : "Неуспешна актуализация повече от 50 пъти",
    "Deleted feed" : "Изтрита емисия",
    "Undo delete feed" : "Върни изтритата емисия",
    "Rename" : "Преименувай",
    "Menu" : "Меню",
    "Mark read" : "Означи като прочетена",
    "Unpin from top" : "Откачи от най-отгоре",
    "Pin to top" : "Закачи най-отгоре",
    "Newest first" : "Най-нов",
    "Oldest first" : "Най-стар",
    "Default order" : "Стандартна подредба",
    "Enable full text" : "Показвай целия текст",
    "Disable full text" : "Не показвай целия текст",
    "Unread updated" : "Актуализираното не е прочетено",
    "Ignore updated" : "Актуализирано е игнориране",
    "Open feed URL" : "Отвори URL на емисията",
    "Delete" : "Изтрий",
    "Dismiss" : "Затвори",
    "Collapse" : "Намали",
    "Deleted folder" : "Изтрий папка",
    "Undo delete folder" : "Върни изтритата папка",
    "Starred" : "Със звезда",
    "All articles" : "Всички статии",
    "Settings" : "Настройки",
    "Disable mark read through scrolling" : "Без означаване като \"Прочетена\" след скролиране",
    "Compact view" : "Компактен изглед",
    "Expand articles on key navigation" : "Разшири статиите от ключовата навигация",
    "Show all articles" : "Показвай всички статии",
    "Reverse ordering (oldest on top)" : "Обратен ред (най-старите отгоре)",
    "Subscriptions (OPML)" : "Абонаменти (OPML)",
    "Import" : "Внасяне",
    "Export" : "Изнасяне",
    "Error when importing: File does not contain valid OPML" : "Грешка при внасяне: файлът не е валиден OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Грешка при внасяне: OPML файлът не съдържа емисии/папки",
    "Unread/Starred Articles" : "Непрочетени/Означени със звезда статии",
    "Error when importing: file does not contain valid JSON" : "Грешка при внасяне: файлът не е валиден JSON",
    "Help" : "Помощ",
    "Keyboard shortcuts" : "Клавишни комбинации",
    "Documentation" : "Документация",
    "Report a bug" : "Докладване за грешка"
},
"nplurals=2; plural=(n != 1);");
