OC.L10N.register(
    "news",
    {
    "News" : "පුවත්",
    "Update interval" : "යාවත්කාලීන කාල පරතරය",
    "Download" : "බාගන්න",
    "Close" : "වසන්න",
    "Open website" : "වියමන අඩවිය විවෘත කරන්න",
    "Share" : "බෙදාගන්න",
    "Username" : "පරිශීලක නාමය",
    "from" : "සිට",
    "Description" : "විස්තරය",
    "right" : "දකුණ",
    "left" : "වම",
    "Load previous folder" : "පෙර බහාලුම පූරණය කරන්න",
    "Load next folder" : "ඊළඟ බහාලුම පූරණය කරන්න",
    "Web address" : "වියමන ලිපිනය",
    "Folder" : "බහාලුම",
    "New folder" : "නව බහාලුම",
    "Folder name" : "බහාලුමේ නම",
    "Go back" : "ආපසු යන්න",
    "Folder exists already!" : "බහාලුම දැනටමත් පවතී!",
    "Password" : "මුර පදය",
    "New Folder" : "නව බහාලුම",
    "Create" : "සාදන්න",
    "Rename" : "නැවත නම් කරන්න",
    "Settings" : "සැකසුම්",
    "Help" : "උපකාර"
},
"nplurals=2; plural=(n != 1);");
