OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Запрос не удался, нет сетевого соединения!",
    "Request unauthorized. Are you logged in?" : "Запрос не авторизован. Вы вошли в систему?",
    "Token expired or app not enabled! Reload the page!" : "Срок действия токена истёк или приложение не включено! Перезагрузите страницу!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Внутренняя ошибка сервера! Пожалуйста, для получения дополнительной информации проверьте журнал в файле data/nextcloud.log!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Запрос не удался, в настоящий момент Nextcloud включен в режиме обслуживания!",
    "News feeds" : "Новостные ленты",
    "Unread articles" : "Непрочтённые статьи",
    "News" : "Новости",
    "News folders" : "Каталог новостей",
    "Shared with me" : "Поделились с вами",
    "An RSS/Atom feed reader" : "Читалка RSS / Atom",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Приложение для чтения RSS/Atom для Nextcloud\n\n- 📲 Синхронизация ваших лент с несколькими мобильными или настольными [клиентами] (https://nextcloud.github.io/news/clients/)\n- 🔄 Автоматическое обновление ваших новостных лент\n- 🆓 Бесплатно и с открытым исходным кодом по AGPLv3, без рекламы и премиум-функций\n\n**Для работы этого приложения требуется системный Cron**.\n\nТребования можно найти [здесь](https://nextcloud.github.io/news/install/#dependencies)\n\nСписок изменений доступен [здесь](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nСоздать [отчёт об ошибке](https://github.com/nextcloud/news/issues/new/choose)\n\nСоздать [запрос новой функции](https://github.com/nextcloud/news/discussions/new)\n\nСообщить [о проблеме](https://github.com/nextcloud/news/discussions/new)",
    "Use system cron for updates" : "Для получения обновлений используйте системный cron",
    "Disable this if you use a custom updater." : "Отключите эту функцию, если вы используете пользовательскую программу обновления.",
    "Maximum read count per feed" : "Максимальное количество статей для ленты",
    "Maximum redirects" : "Максимум перенаправлений",
    "How many redirects the feed fetcher should follow." : "Сколько перенаправлений должен обрабатывать загрузчик лент.",
    "Feed fetcher timeout" : "Время ожидания для загрузчика ленты",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Максимальное количество секунд ожидания загрузки ленты RSS или Atom; если обновление занимает больше времени, то оно будет отменено",
    "Explore Service URL" : "URL службы обзора",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Указанный URL будет опрашиваться для отображения лент в секции Обзор. Для использования встроенного сервиса, оставьте поле ввода пустым.",
    "Update interval" : "Интервал обновления",
    "Interval in seconds in which the feeds will be updated." : "Интервал обновления лент в секундах",
    "Download" : "Скачать",
    "Close" : "Закрыть",
    "Subscribe to" : "Подписаться",
    "No articles available" : "Нет доступных статей",
    "No unread articles available" : "Нет непрочтённых статей",
    "Open website" : "Открыть веб-сайт",
    "Star article" : "Добавить в избранное",
    "Unstar article" : "Убрать из избранного",
    "Keep article unread" : "Оставить статью непрочитанной",
    "Remove keep article unread" : "Удалить отметку от непрочтении",
    "Share" : "Поделиться",
    "Share with users" : "Поделиться с пользователями",
    "Username" : "Имя пользователя",
    "No users found" : "Пользователи не найдены",
    "Error while searching for users" : "Ошибка при поиске пользователей",
    "Share on social media" : "Поделиться в социальных сетях",
    "I wanted you to see this article" : "Я хотел, чтобы вы посмотрели эту статью",
    "Check out this article" : "Прочтите эту статью",
    "by" : "автор",
    "from" : "из",
    "shared by" : "поделился",
    "Play audio" : "Проиграть аудио-запись",
    "Download audio" : "Скачать аудио-запись",
    "Download video" : "Скачать видео",
    "Keyboard shortcut" : "Горячие клавиши",
    "Description" : "Описание",
    "right" : "направо",
    "Jump to next article" : "Перейти на следующую статью",
    "left" : "налево",
    "Jump to previous article" : "Перейти на предыдущую статью",
    "Toggle star article" : "Добавить/убрать из избранного",
    "Star article and jump to next one" : "Добавить статью в избранное и перейти к следующей",
    "Toggle keep current article unread" : "Переключатель пометки текущей статьи непрочитанной",
    "Open article in new tab" : "Открыть статью в новой вкладке",
    "Toggle expand article in compact view" : "Открывать статью при просмотре в компактном режиме",
    "Refresh" : "Обновить",
    "Load next feed" : "Загрузить следующую ленту",
    "Load previous feed" : "Загрузить предыдущую ленту",
    "Load previous folder" : "Загрузить предыдущую папку",
    "Load next folder" : "Загрузить следующую папку",
    "Scroll to active navigation entry" : "Прокрутить к выбранному элементу",
    "Mark current article's feed/folder read" : "Пометить папку текущей статьи как прочитанную",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Обнаружен режим планировщика задач Ajax или webcron! Ленты не будут обновляться!",
    "How to set up the operating system cron" : "Как настроить cron (планировщик задач) операционной системы",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Установить и настроить более быстрое средство параллельного обновления, которое использует собственный API обновлений приложения новостей",
    "Subscribe" : "Подписаться",
    "Web address" : "Веб адрес",
    "Feed exists already!" : "Лента уже существует!",
    "Folder" : "Папка",
    "No folder" : "Нет папки",
    "New folder" : "Новая папка",
    "Folder name" : "Имя папки",
    "Go back" : "Вернуться назад",
    "Folder exists already!" : "Папка уже существует!",
    "Credentials" : "Учётные данные",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Аутентификационные данные HTTP Basic придётся сохранить в незашифрованном виде! Каждый, у кого есть доступ внутрь сервера или в базу данных, сможет прочитать их!",
    "Password" : "Пароль",
    "Auto discover Feed" : "Автообнаружение ленты",
    "New Folder" : "Новая папка",
    "Create" : "Создать",
    "Explore" : "Обзор",
    "Update failed more than 50 times" : "Не удалось выполнить обновление более 50 раз",
    "Deleted feed" : "Удалённая лента",
    "Undo delete feed" : "Отменить удаление ленты",
    "Rename" : "Переименовать",
    "Menu" : "Меню",
    "Mark read" : "Пометить прочтённым",
    "Unpin from top" : "Открепить сверу",
    "Pin to top" : "Прикрепить вверху",
    "Newest first" : "Новые-старые",
    "Oldest first" : "Старые-новые",
    "Default order" : "Порядок по умолчанию",
    "Enable full text" : "Включить полный текст",
    "Disable full text" : "Отключить полный текст",
    "Unread updated" : "Непрочитанное обновлено",
    "Ignore updated" : "Игнорировать обновлённые",
    "Open feed URL" : "Открыть URL ленты",
    "Delete" : "Удалить",
    "Dismiss" : "Убрать",
    "Collapse" : "Свернуть",
    "Deleted folder" : "Удаленная папка",
    "Undo delete folder" : "Отменить удаление папки",
    "Starred" : "Избранное",
    "All articles" : "Все статьи",
    "Settings" : "Настройки",
    "Disable mark read through scrolling" : "Отключить установку отметок о прочтении при прокрутке",
    "Compact view" : "Компактный вид",
    "Expand articles on key navigation" : "Раскрывать статьи при навигации клавишами",
    "Show all articles" : "Показать все статьи",
    "Reverse ordering (oldest on top)" : "Обратный порядок (самые старые сверху)",
    "Subscriptions (OPML)" : "Подписки (OPML)",
    "Import" : "Импорт",
    "Export" : "Экспорт",
    "Error when importing: File does not contain valid OPML" : "Ошибка импорта: В файле не найден корректный OPML ",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Ошибка при импорте: в OPML нет ни лент, ни папок",
    "Unread/Starred Articles" : "Непрочтенные/Избранные статьи",
    "Error when importing: file does not contain valid JSON" : "Ошибка при импорте: файл не содержит правильный JSON",
    "Help" : "Помощь",
    "Keyboard shortcuts" : "Горячие клавиши",
    "Documentation" : "Документация",
    "Report a bug" : "Сообщить об ошибке"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
