OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "درخواست انجام نشد ، اتصال به شبکه در دسترس نیست!",
    "Request unauthorized. Are you logged in?" : "درخواست غیر مجاز. آیا وارد سیستم شده اید؟",
    "Token expired or app not enabled! Reload the page!" : "گفتگوی منقضی شده یا برنامه فعال نشده است! بارگیری مجدد صفحه!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "خطای سرور داخلی! لطفاً برای اطلاعات بیشتر ، پرونده / nextcloud.log خود را بررسی کنید!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "درخواست انجام نشد ، Nextcloud در حال حاضر در حالت تعمیر و نگهداری است!",
    "Unread articles" : "مطالب خوانده نشده",
    "News" : "اخبار",
    "An RSS/Atom feed reader" : "An RSS/Atom feed reader",
    "Use system cron for updates" : "برای بروزرسانی ها از سیستم cron استفاده کنید",
    "Maximum read count per feed" : "حداکثر تعداد خواندن در هر خوراک",
    "Maximum redirects" : "حداکثر تغییر مسیرها",
    "Feed fetcher timeout" : "خاتمه دادن به فست فایر",
    "Explore Service URL" : "URL سرویس را کاوش کنید",
    "Download" : "دانلود",
    "Close" : "بستن",
    "No articles available" : "هیچ مقاله‌ای موجود نیست",
    "No unread articles available" : "هیچ مقاله‌ی خوانده‌ نشده‌ای موجود نیست",
    "Open website" : "باز کردن وب‌سایت",
    "Star article" : "مقاله ستاره",
    "Unstar article" : "مقاله Unstar",
    "Keep article unread" : "مقاله را نخوانید",
    "Remove keep article unread" : "مقاله را نخوانید حذف کنید",
    "Share" : "هم‌رسانی",
    "Username" : "نام کاربری",
    "by" : "با",
    "from" : "از",
    "Play audio" : "پخش صوت",
    "Download audio" : "دانلود صوت",
    "Download video" : "دانلود ویدئو",
    "Keyboard shortcut" : "صفحه کلید",
    "Description" : "توضیحات",
    "right" : "راست",
    "Jump to next article" : "پرش به مقاله بعدی",
    "left" : "چپ",
    "Jump to previous article" : "پرش به مقاله قبلی",
    "Toggle star article" : "مقاله ستاره را تغییر دهید",
    "Star article and jump to next one" : "مقاله ستاره و پرش به مقاله بعدی",
    "Toggle keep current article unread" : "جستجوی مقاله فعلی خوانده نشده",
    "Open article in new tab" : "باز کردن مقاله در تب جدید",
    "Toggle expand article in compact view" : "گسترش مقاله در نمای جمع و جور",
    "Refresh" : "بازنمایی",
    "Load next feed" : "خوراک بعدی را بارگیری کنید",
    "Load previous feed" : "خوراک قبلی را بارگیری کنید",
    "Load previous folder" : "پوشه قبلی را بارگیری کنید",
    "Load next folder" : "پوشه بعدی را بارگیری کنید",
    "Scroll to active navigation entry" : "به ورودی ناوبری فعال بروید",
    "Mark current article's feed/folder read" : "فید / پوشه مقاله خوانده شده را علامت گذاری کنید",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "آژاکس یا حالت وبکرون شناسایی شد! فیدهای شما به روز نمی شوند!",
    "How to set up the operating system cron" : "نحوه تنظیم سیستم عامل کرن",
    "Install and set up a faster parallel updater that uses the News app's update API" : "یک بروزرسانی موازی سریعتر را که از API به روزرسانی برنامه News استفاده می کند ، نصب و تنظیم کنید",
    "Subscribe" : "اشتراک گذاری",
    "Web address" : "آدرس وب",
    "Feed exists already!" : "خوراک در حال حاضر وجود دارد!",
    "Folder" : "پوشه",
    "No folder" : "بدون پوشه",
    "New folder" : "پوشه جدید",
    "Folder name" : "نام پوشه",
    "Go back" : "برگرد",
    "Folder exists already!" : "پوشه در حال حاضر موجود است!",
    "Credentials" : "اعتبارهای",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "اعتبارنامه HTTP Basic Auth باید بدون رمزگذاری ذخیره شود! هر کس با دسترسی به سرور یا بانک اطلاعاتی قادر به دسترسی به آنها خواهد بود!",
    "Password" : "گذرواژه",
    "New Folder" : "پوشه جدید",
    "Create" : "ایجاد کردن",
    "Explore" : "کاوش",
    "Update failed more than 50 times" : "بروزرسانی بیش از 50 بار انجام نشد",
    "Deleted feed" : "خوراک حذف شد",
    "Undo delete feed" : "فید را حذف کنید",
    "Rename" : "تغییرنام",
    "Menu" : "منو",
    "Mark read" : "علامت گذاری به عنوان خوانده شده",
    "Unpin from top" : "از بالای صفحه باز کنید",
    "Pin to top" : "از این صفحه",
    "Newest first" : "تازه ترین ها اول ",
    "Oldest first" : "قدیمی ترین ها اول ",
    "Default order" : "سفارش پیش فرض",
    "Enable full text" : "متن کامل را فعال کنید",
    "Disable full text" : "متن کامل را غیرفعال کنید",
    "Unread updated" : "خوانده نشده به روز شد",
    "Ignore updated" : "نادیده گرفتن به روز شده",
    "Open feed URL" : "نشانی اینترنتی فید را باز کنید",
    "Delete" : "حذف",
    "Dismiss" : "پنهان کن",
    "Collapse" : "فروکش  کردن",
    "Deleted folder" : "پوشه‌ی حذف شده",
    "Undo delete folder" : "حذف پوشه را لغو کنید",
    "Starred" : "ستاره دار",
    "All articles" : "تمام مطالب",
    "Settings" : "تنظیمات",
    "Disable mark read through scrolling" : "غیرفعال کردن علامت خوانده شده از طریق پیمایش",
    "Compact view" : "نمایش متراکم",
    "Expand articles on key navigation" : "مقالات مربوط به پیمایش کلید را گسترش دهید",
    "Show all articles" : "نمایش تمامی مقالات",
    "Reverse ordering (oldest on top)" : "ترتیب معکوس (قدیمی ترین در بالا)",
    "Subscriptions (OPML)" : "اشتراک‌ها (OPML)",
    "Import" : "وارد کردن",
    "Export" : "گرفتن خروجی",
    "Error when importing: File does not contain valid OPML" : "خطا هنگام وارد کردن: پرونده حاوی OPML معتبر نیست",
    "Error when importing: OPML is does neither contain feeds nor folders" : "خطا هنگام وارد کردن: OPML شامل فید و پوشه نیست",
    "Unread/Starred Articles" : "مقالات خوانده نشده / ستاره دار",
    "Error when importing: file does not contain valid JSON" : "خطا هنگام وارد کردن: فایل حاوی JSON معتبر نیست.",
    "Help" : "کمک",
    "Keyboard shortcuts" : "میان بر صفحه ی کلید",
    "Documentation" : "مستندسازی",
    "Report a bug" : "گزارش یک خطا"
},
"nplurals=2; plural=(n > 1);");
