OC.L10N.register(
    "news",
    {
    "Download" : "ښکته کول",
    "Close" : "بندول",
    "Share" : "شریکول",
    "Username" : "کارن نوم",
    "New folder" : "نوی فولډر",
    "Password" : "پاسورډ",
    "Rename" : "نوم بدلول",
    "Delete" : "ړنګول",
    "Settings" : "سمونې",
    "Help" : "مرسته"
},
"nplurals=2; plural=(n != 1);");
