/**
 * Nextcloud - News
 *
 * This file is licensed under the Affero General Public License version 3 or
 * later. See the COPYING file.
 *
 * @author Bernhard Posselt <dev@bernhard-posselt.com>
 * @copyright Bernhard Posselt 2014
 */
#app-settings input[type=file] {
    position: absolute;
    left: -30000px;
}

#app-settings-content {
    padding-bottom: 25px;
}

#app-settings-content h3 {
    padding: 5px 0;
    font-weight: bold;
}

#app-settings-content a {
    color: #0c76ff;
    text-decoration: underline;
}


#app-settings-content p {
    padding: 2px 2px 2px 10px;
}

#app-settings-content label {
    display: block;
    padding-left: 18px;
}

#app-settings-content label input[type="checkbox"] {
    margin-left: -18px;
    max-width: 16px;
}

.button-icon-label {
    background-position: 10px center;
    background-size: 16px;
    padding-left: 25px;
}

#app-settings .import-export h3 {
    padding-top: 15px;
    padding-bottom: 5px;
}

#app-settings .import-export button,
#app-settings .import-export a {
    width: 106px;
    height: 30px;
    margin: 0;
    vertical-align: middle;
    background-position: center;
}

#app-settings .import-export a {
    display: inline-block;
}

#app-settings .disabled {
    color: var(--color-text-lighter);
}