OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "הבקשה נכשלה, חיבור רשת לא זמין!",
    "Request unauthorized. Are you logged in?" : "בקשה לא מורשת. האם הנך מחובר/ת?",
    "Token expired or app not enabled! Reload the page!" : "אישור פג תוקף או יישום לא מופעל! יש לטעון את הדף שוב!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "שגיאת שרת פנימית! נא לעיין בקובץ data/nextcloud.log שאצלך לקבלת פרטים נוספים!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "הבקשה נכשלה, מערכת Nextcloud נמצאת כרגע במצב תחזוקה!",
    "Unread articles" : "מאמרים שלא נקראו",
    "News" : "חדשות",
    "Shared with me" : "משותף אתי",
    "An RSS/Atom feed reader" : "קורא ערוצי תוכן מסוג RSS/Atom",
    "Use system cron for updates" : "שימוש ב־cron של המערכת לעדכונים",
    "Maximum read count per feed" : "מספר מקסימלי של שורות קריאה מערוץ הזנת תוכן",
    "Maximum redirects" : "מספר ניתובים מירבי",
    "Feed fetcher timeout" : "עבר זמן מרבי להזנת ערוץ התוכן",
    "Explore Service URL" : "חקירת נתיב שירות",
    "Download" : "הורדה",
    "Close" : "סגירה",
    "No articles available" : "אין מאמרים זמינים",
    "No unread articles available" : "אין מאמרים שלא נקראו זמינים",
    "Open website" : "פתיחת אתר אינטרנט",
    "Star article" : "סמן מאמר בכוכב",
    "Unstar article" : "הסרת סימון כוכב ממאמר",
    "Keep article unread" : "השארת מאמר עם סימון לא נקרא",
    "Remove keep article unread" : "ביטול השארת מאמר עם סימון לא נקרא",
    "Share" : "שתף",
    "Username" : "שם משתמש",
    "No users found" : "לא נמצאו משתמשים",
    "by" : "על ידי",
    "from" : "מאת",
    "Play audio" : "השמע קובץ שמע",
    "Download audio" : "הורדת קובץ שמע",
    "Download video" : "הורדת וידאו",
    "Keyboard shortcut" : "קיצור מקלדת",
    "Description" : "תיאור",
    "right" : "ימין",
    "Jump to next article" : "קפיצה למאמר הבא",
    "left" : "שמאל",
    "Jump to previous article" : "קפיצה למאמר הקודם",
    "Toggle star article" : "החלפת מצב סימון מאמר בכוכב",
    "Star article and jump to next one" : "סימון מאמר בכוכב וקפיצה לבא אחריו",
    "Toggle keep current article unread" : "החלפת מצב סימון מאמר כלא נקרא",
    "Open article in new tab" : "פתיחת מאמר בכרטיסייה חדשה",
    "Toggle expand article in compact view" : "מעבר למאמר מורחק בתצוגה מצומצמת",
    "Refresh" : "רענון",
    "Load next feed" : "טעינת הזנת תוכן הבאה",
    "Load previous feed" : "טעינת הזנת תוכן קודמת",
    "Load previous folder" : "טעינת תיקייה קודמת",
    "Load next folder" : "טעינת תיקייה הבאה",
    "Scroll to active navigation entry" : "גלילה לרשומת ניווט פעילה",
    "Mark current article's feed/folder read" : "סימון ערוץ מידע/תיקייה למאמר הנוכחי כנקראו",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "זוהה מצב Ajax או webcron! ערוצי התוכן שלך לא יעודכנו!",
    "How to set up the operating system cron" : "איך להגדיר את cron מערכת ההפעלה",
    "Install and set up a faster parallel updater that uses the News app's update API" : "התקנה והגדרת עדכון מקביל מהיר שמשתמש בעדכון יישום חדשות מבוסס API",
    "Subscribe" : "רישום",
    "Web address" : "כתובת אתר",
    "Feed exists already!" : "ערוץ הזנת התוכן כבר קיים!",
    "Folder" : "תיקייה",
    "No folder" : "אין תיקייה",
    "New folder" : "תיקייה חדשה",
    "Folder name" : "שם התיקייה",
    "Go back" : "חזרה",
    "Folder exists already!" : "התיקייה כבר קיימת!",
    "Credentials" : "פרטי גישה",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "אישורי אימות HTTP בסיסיים חייבים להיות מאוחסנים ללא קידוד! כל אחד עם גישה לשרת או למסד הנתונים יוכלו לגשת אליהם!",
    "Password" : "סיסמא",
    "New Folder" : "תיקייה חדשה",
    "Create" : "יצירה",
    "Explore" : "דפדוף",
    "Update failed more than 50 times" : "העדכון נכשל מעל 50 פעמים",
    "Deleted feed" : "מחיקת ערוץ תוכן",
    "Undo delete feed" : "ביטול מחיקת ערוץ תוכן",
    "Rename" : "שינוי שם",
    "Menu" : "תפריט",
    "Mark read" : "סימון כנקרא",
    "Unpin from top" : "הפרדת ההצמדה",
    "Pin to top" : "הצמדה למעלה",
    "Newest first" : "החדש ביותר ראשון",
    "Oldest first" : "הישן ביותר ראשון",
    "Default order" : "סדר בררת המחדל",
    "Enable full text" : "הפעלת טקסט מלא",
    "Disable full text" : "השבתת טקסט מלא",
    "Unread updated" : "לא נקראו עודכנו",
    "Ignore updated" : "בהתעלמות עודכנו",
    "Open feed URL" : "פתיחת כתובת ערוץ תוכן",
    "Delete" : "מחיקה",
    "Dismiss" : "שחרור",
    "Collapse" : "קיווץ",
    "Deleted folder" : "מחיקת תיקייה",
    "Undo delete folder" : "ביטול מחיקת תיקייה",
    "Starred" : "מסומן",
    "All articles" : "כל המאמרים",
    "Settings" : "הגדרות",
    "Disable mark read through scrolling" : "ניטרול סימון כנקרא בעקבות גלילה",
    "Compact view" : "תצוגה קומפקטית",
    "Expand articles on key navigation" : " תצוגת מאמר מורחב בתפריט ראשי ",
    "Show all articles" : "הצגת כל המאמרים",
    "Reverse ordering (oldest on top)" : "סידור הפוך (ישן למעלה)",
    "Subscriptions (OPML)" : "הרשמות (OPML)",
    "Import" : "יבוא",
    "Export" : "ייצוא",
    "Error when importing: File does not contain valid OPML" : "שגיאה בעת הייבוא: הקובץ לא מכיל OPML תקני",
    "Error when importing: OPML is does neither contain feeds nor folders" : "שגיאה בזמן יבוא: OPML אינו מכיל הזנות מידע או תיקיות",
    "Unread/Starred Articles" : "מאמרים שלא נקראו / סומנו ככוכב",
    "Error when importing: file does not contain valid JSON" : "שגיאה ביבוא: הקובץ אינו מכיל JSON תקין",
    "Help" : "עזרה",
    "Keyboard shortcuts" : "קיצורי מקלדת",
    "Documentation" : "תיעוד",
    "Report a bug" : "דיווח על באג"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
