OC.L10N.register(
    "news",
    {
    "Download" : "ڈاؤن لوڈ،",
    "Close" : "بند ",
    "Share" : "تقسیم",
    "Username" : "اسم صارف",
    "Description" : "تصریح",
    "Folder" : "Folder",
    "Credentials" : "Credentials",
    "Password" : "پاسورڈ",
    "Rename" : "Rename",
    "Delete" : "حذف کریں",
    "Settings" : "سیٹینگز",
    "Help" : "مدد"
},
"nplurals=2; plural=(n != 1);");
