OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Förfrågan misslyckades, nätverksanslutning otillgänglig!",
    "Request unauthorized. Are you logged in?" : "Ogiltig begäran. Är du inloggad?",
    "Token expired or app not enabled! Reload the page!" : "Polletten föråldrad eller så är applikationen inte aktiverad! Uppdatera sidan.",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Internt serverfel! Vänligen kontrollera din loggfil under data/nextcloud.log för mer information!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Förfrågan misslyckades. Nextcloud är för närvarande i underhållsläge!",
    "News feeds" : "Nyhetsflöden",
    "Unread articles" : "Olästa artiklar",
    "News" : "Nyheter",
    "News folders" : "Nyhetsmappar",
    "Shared with me" : "Delad med mig",
    "An RSS/Atom feed reader" : "En RSS/Atom feed-läsare",
    "Use system cron for updates" : "Använda \"system cron\" för uppdateringar",
    "Disable this if you use a custom updater." : "Slå av detta om du anväder en egen uppdateringsprocess.",
    "Maximum read count per feed" : "Maximalt läsantal per flöde",
    "Maximum redirects" : "Maximala omdirigeringar",
    "Feed fetcher timeout" : "Timeout för flödes-hämtare",
    "Explore Service URL" : "Utforska tjänstwebbadress",
    "Update interval" : "Uppdateringsintervall",
    "Interval in seconds in which the feeds will be updated." : "Antal sekunder mellan uppdateringar av flödena.",
    "Download" : "Hämta",
    "Close" : "Stäng",
    "Subscribe to" : "Prenumerera på",
    "No articles available" : "Inga artiklar tillgängliga",
    "No unread articles available" : "Inga olästa artiklar tillgängliga",
    "Open website" : "Öppna webbplats",
    "Star article" : "Stjärnmärk artikel",
    "Unstar article" : "Ta bort stjärnmärke på artikel",
    "Keep article unread" : "Behåll artikel oläst",
    "Remove keep article unread" : "Ta bort behåll artikel oläst",
    "Share" : "Dela",
    "Share with users" : "Dela med användare",
    "Username" : "Användarnamn",
    "No users found" : "Inga användare hittades",
    "Error while searching for users" : "Kunde inte söka bland användare",
    "Share on social media" : "Dela via sociala medier",
    "I wanted you to see this article" : "Jag vill rekommendera dig den här artikeln",
    "Check out this article" : "Spana in den här artikeln",
    "by" : "av",
    "from" : "från",
    "shared by" : "delad av",
    "Play audio" : "Spela ljud",
    "Download audio" : "Hämta ljud",
    "Download video" : "Hämta video",
    "Keyboard shortcut" : "Tangentbordsgenvägar",
    "Description" : "Beskrivning",
    "right" : "Höger",
    "Jump to next article" : "Hoppa till nästa artikel",
    "left" : "vänster",
    "Jump to previous article" : "Hoppa till föregående artikel",
    "Toggle star article" : "Växla stjärnmärkning av artiklar",
    "Star article and jump to next one" : "Stärnmärk artikel och hoppa till nästa",
    "Toggle keep current article unread" : "Aktivera för att hålla aktuell artikel oläst",
    "Open article in new tab" : "Öppna artikeln i ny flik",
    "Toggle expand article in compact view" : "Aktivera för att expandera artikeln i kompakt vy",
    "Refresh" : "Uppdatera",
    "Load next feed" : "Läs in nästkommande flöde",
    "Load previous feed" : "Läs in föregående flöde",
    "Load previous folder" : "Läs in föregående mapp",
    "Load next folder" : "Läs in nästkommande mapp",
    "Scroll to active navigation entry" : "Skrolla till aktiv navigations-post",
    "Mark current article's feed/folder read" : "Markera nuvarande artikels flöde/mapp som läst",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax- eller webcron-läge upptäckt! Dina flöden kommer inte uppdateras!",
    "How to set up the operating system cron" : "Hur man ställer in cron från operativsystemet",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Installera och konfigurera en snabbare parallell uppdaterare som använder programmet Nyheter uppdatering API",
    "Subscribe" : "Prenumerera",
    "Web address" : "Webbadress",
    "Feed exists already!" : "Flödet finns redan!",
    "Folder" : "Mapp",
    "No folder" : "Ingen mapp",
    "New folder" : "Ny mapp",
    "Folder name" : "Mappnamn",
    "Go back" : "Gå tillbaks",
    "Folder exists already!" : "Katalogen finns redan",
    "Credentials" : "Inloggningsuppgifter",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Grundläggande HTTP-autentiseringsuppgifter måste lagras okrypterade! Alla med åtkomst till servern eller databasen kommer att kunna få åtkomst till dem!",
    "Password" : "Lösenord",
    "New Folder" : "Ny mapp",
    "Create" : "Skapa",
    "Explore" : "Utforska",
    "Update failed more than 50 times" : "Uppdatering misslyckades mer än 50 gånger",
    "Deleted feed" : "Borttagna flöde",
    "Undo delete feed" : "Ångra radera flöde",
    "Rename" : "Byt namn",
    "Menu" : "Meny",
    "Mark read" : "Markera som läst",
    "Unpin from top" : "Ta bort från toppen",
    "Pin to top" : "Fäst i toppen",
    "Newest first" : "Nyaste först",
    "Oldest first" : "Äldst först",
    "Default order" : "Standardordning",
    "Enable full text" : "Aktivera fulltext",
    "Disable full text" : "Avaktivera fulltext",
    "Unread updated" : "Markera som oläst",
    "Ignore updated" : "Ignorera uppdaterad",
    "Open feed URL" : "Öppna flödeswebbadress",
    "Delete" : "Ta bort",
    "Dismiss" : "Avfärda",
    "Collapse" : "Dölj",
    "Deleted folder" : "Raderad mapp",
    "Undo delete folder" : "Ångra radera mapp",
    "Starred" : "Stjärnmärkt",
    "All articles" : "Alla artiklar",
    "Settings" : "Inställningar",
    "Disable mark read through scrolling" : "Stäng av markerad som läst vid skrollning",
    "Compact view" : "Kompakt vy",
    "Expand articles on key navigation" : "Expandera artiklar vid hantering",
    "Show all articles" : "Visa alla artiklar",
    "Reverse ordering (oldest on top)" : "Omvänd ordning (äldst överst)",
    "Subscriptions (OPML)" : "Abonnemang (OPML)",
    "Import" : "Importera",
    "Export" : "Exportera",
    "Error when importing: File does not contain valid OPML" : "Fel vid importering: Fil innehåller inte giltig OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Fel vid import: OPML innehåller varken flöden eller mappar",
    "Unread/Starred Articles" : "Olästa/Stjärnmärkta artiklar",
    "Error when importing: file does not contain valid JSON" : "Fel vid import: filen innehåller inte giltig JSON",
    "Help" : "Hjälp",
    "Keyboard shortcuts" : "Tangentbordsgenvägar",
    "Documentation" : "Dokumentation",
    "Report a bug" : "Rapportera ett problem"
},
"nplurals=2; plural=(n != 1);");
