OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Fracàs de la requèsta, connexion ret indisponibla !",
    "Request unauthorized. Are you logged in?" : "Requèsta pas autorizada. Sètz plan connectat amb vòstres identificants ?",
    "Token expired or app not enabled! Reload the page!" : "Lo geton a expirat o l'aplicacion es pas activada ! Recargatz la pagina !",
    "Unread articles" : "Articles pas legits",
    "Maximum read count per feed" : "Nombre maximum de lectura per flux",
    "Maximum redirects" : "Nombre maximal de redireccions",
    "Feed fetcher timeout" : "Relambi d'espèra maximum del recuperador de flux",
    "Explore Service URL" : "URL del servici d'exploracion",
    "Download" : "Telecargar",
    "Close" : "Tampar",
    "No articles available" : "Pas cap d'article disponible",
    "No unread articles available" : "Cap d'article pas legit de disponible",
    "Open website" : "Dobrir lo site web",
    "Star article" : "Espingolar l'article",
    "Unstar article" : "Desespingolar l'article",
    "Keep article unread" : "Marcar l'article coma pas legit",
    "Remove keep article unread" : "Marcar l'article coma legit",
    "Share" : "Partejar",
    "Username" : "Identificant",
    "by" : "per",
    "from" : "de",
    "Play audio" : "Escotar",
    "Download audio" : "Telecargar lo son",
    "Download video" : "Telecargar la vidèo",
    "Keyboard shortcut" : "Acorchis de clavièr",
    "Description" : "Descripcion",
    "right" : "droite",
    "Jump to next article" : "Anar al prochain article",
    "left" : "gauche",
    "Jump to previous article" : "Anar a l'article precedent",
    "Toggle star article" : "Espingolar / Desespingolar l'article",
    "Star article and jump to next one" : "Espingolar l'article e anar al seguent",
    "Toggle keep current article unread" : "Marcar l'article coma Legit / Non legit",
    "Open article in new tab" : "Dobrir l'article dins un nouvel onglet",
    "Toggle expand article in compact view" : "Espandir / Réduire la vista (si en vista compacte)",
    "Refresh" : "Refrescar",
    "Load next feed" : "Cargar lo flux seguent",
    "Load previous feed" : "Cargar lo flux precedent",
    "Load previous folder" : "Cargar lo dorsièr precedent",
    "Load next folder" : "Cargar lo dorsièr seguent",
    "Scroll to active navigation entry" : "Anar vers lo camp de navigacion actif",
    "Mark current article's feed/folder read" : "Marcar coma legit lo flux / lo repertòri de l'article en cours",
    "How to set up the operating system cron" : "Cossí configurar lo cron del sistèma operatiu",
    "Subscribe" : "S'abonar",
    "Web address" : "Adreça web",
    "Feed exists already!" : "Lo flux existís ja !",
    "Folder" : "Dorsièr",
    "No folder" : "Aucun dorsièr",
    "New folder" : "Novèl dorsièr",
    "Folder name" : "Nom del dorsièr",
    "Go back" : "Revenir en arrière",
    "Folder exists already!" : "Lo dorsièr existís ja !",
    "Credentials" : "Informacions d'identificacion",
    "Password" : "Senhal",
    "New Folder" : "Novèl dorsièr",
    "Create" : "Crear",
    "Explore" : "Explorar",
    "Deleted feed" : "Flux suprimit",
    "Undo delete feed" : "Anullar la supression del flux",
    "Rename" : "Renomenar",
    "Menu" : "Menú",
    "Delete" : "Suprimir",
    "Dismiss" : "Ignorar",
    "Collapse" : "Replegar",
    "Deleted folder" : "Dorsièr suprimit",
    "Undo delete folder" : "Anullar la supression del dorsièr",
    "Starred" : "Espingolats",
    "All articles" : "Totes los articles",
    "Settings" : "Paramètres",
    "Disable mark read through scrolling" : "Marcar pas los articles coma legits al moment del percors de las listas",
    "Compact view" : "Vista compacta",
    "Expand articles on key navigation" : "Espandir los articles al moment de la navigacion amb lo clavièr",
    "Show all articles" : "Afichar totes los articles",
    "Reverse ordering (oldest on top)" : "Òrdre invèrse (los mai ancians amont)",
    "Subscriptions (OPML)" : "Abonaments (OPML)",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Unread/Starred Articles" : "Articles pas legits / espingolats",
    "Error when importing: file does not contain valid JSON" : "Error al moment de l'impòrt : lo fichièr especificat es pas un fichièr JSON valid",
    "Help" : "Ajuda",
    "Keyboard shortcuts" : "Acorchis de clavièr",
    "Documentation" : "Documentacion",
    "Report a bug" : "Raportar un bug"
},
"nplurals=2; plural=(n > 1);");
