OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "リクエストに失敗しました。ネットワーク接続が利用できません！",
    "Request unauthorized. Are you logged in?" : "リクエストは認証されていません。ログインしていますか？",
    "Token expired or app not enabled! Reload the page!" : "トークンまたはアプリが無効になりました！ページを再読込してください！",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "内部サーバーエラー！追加情報については、あなたのdata/nextcloud.logファイルをチェックしてください！",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "リクエストが失敗しました。Nextcloudは現在メンテナンスモードです。",
    "News feeds" : "ニューズフィード",
    "Unread articles" : "未読の記事",
    "News" : "ニュース",
    "News folders" : "ニューズフォルダー",
    "Shared with me" : "私と共有",
    "An RSS/Atom feed reader" : "RSS/Atom フィードリーダー",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 NextcloudのためのRSS/Atomフィードリーダーアプリ\n\n- 📲 お持ちのモバイル端末またはデスクトップ間でフィードを同期 [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 ニュースフィードの自動更新\n- 🆓AGPLv3下の無料・オープンソースにより、広告や有料のプレミアム機能はありません\n\n**このアプリの動作にはシステムのCron機能が必要です**\n\nシステム要件は [here](https://nextcloud.github.io/news/install/#dependencies)\n\n変更履歴は [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\n[bug report]から不具合報告(https://github.com/nextcloud/news/issues/new/choose)\n\n[feature request]から機能をリクエスト(https://github.com/nextcloud/news/discussions/new)\n\n[feed issue]からフィードの問題を報告(https://github.com/nextcloud/news/discussions/new)",
    "Use system cron for updates" : "更新のためにOSのcronを使用",
    "Disable this if you use a custom updater." : "カスタムアップデーターをご利用中の場合はこちらを無効にしてください。",
    "Maximum read count per feed" : "フィード当たりの最大閲覧数",
    "Maximum redirects" : "最大リダイレクト数",
    "How many redirects the feed fetcher should follow." : "フィードフェッチャーに許可するリダイレクト数です。",
    "Feed fetcher timeout" : "フィードフェッチャーのタイムアウト",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "RSS / Atom フィードの読み込み待機秒数の制限;設定時間より長くかかる場合はアップデートが中止されます。",
    "Explore Service URL" : "サービスURLの探索",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "指定された場合は、このサービスのURLは探索フィードセクションでフィードを表示するために照会されます。内蔵の探索サービスへ戻すには、この項目を空欄にしてください。",
    "Update interval" : "アップデート周期",
    "Interval in seconds in which the feeds will be updated." : "フィードを更新するまでの間隔を秒数で指定してください。",
    "Download" : "ダウンロード",
    "Close" : "閉じる",
    "Subscribe to" : "次を購読:",
    "No articles available" : "記事がありません",
    "No unread articles available" : "未読記事がありません",
    "Open website" : "ウェブサイトを開く",
    "Star article" : "スター付きの記事",
    "Unstar article" : "スターなしの記事",
    "Keep article unread" : "記事を未読のままにする",
    "Remove keep article unread" : "記事の未読保持を解除",
    "Share" : "共有",
    "Share with users" : "ユーザーと共有",
    "Username" : "ユーザー名",
    "No users found" : "ユーザーが見つかりません",
    "Error while searching for users" : "ユーザーの検索中にエラーが発生しました",
    "Share on social media" : "SNSで共有",
    "I wanted you to see this article" : "この記事を読みたい",
    "Check out this article" : "この記事をチェック",
    "by" : "by",
    "from" : "開始",
    "shared by" : "共有:",
    "Play audio" : "音楽を再生",
    "Download audio" : "音楽をダウンロード",
    "Download video" : "動画をダウンロード",
    "Keyboard shortcut" : "キーボードショートカット",
    "Description" : "説明",
    "right" : "右",
    "Jump to next article" : "次の記事へジャンプ",
    "left" : "左",
    "Jump to previous article" : "前の記事へジャンプ",
    "Toggle star article" : "スター付きの記事を切り替え",
    "Star article and jump to next one" : "記事にスターを付けて次へ",
    "Toggle keep current article unread" : "現在の記事の未読を切り替え",
    "Open article in new tab" : "新しいタブで記事を開く",
    "Toggle expand article in compact view" : "コンパクトビューでの記事の拡張の切り替え",
    "Refresh" : "同期",
    "Load next feed" : "次のフィードを読み込む",
    "Load previous feed" : "前のフィードを読み込む",
    "Load previous folder" : "前のフォルダーを読み込む",
    "Load next folder" : "次のフォルダーを読み込む",
    "Scroll to active navigation entry" : "アクティブなナビゲーションエントリーにスクロール",
    "Mark current article's feed/folder read" : "現在の記事のフィード/フォルダーを既読にする",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax か Web cron モードになっています。フィードは自動的に更新されません。",
    "How to set up the operating system cron" : "OSのcronのやり方",
    "Install and set up a faster parallel updater that uses the News app's update API" : "ニュースアプリのアップデートAPIを使用する、高速な並列アップデーターをインストールして、設定します。",
    "Subscribe" : "購読",
    "Web address" : "WEBアドレス",
    "Feed exists already!" : "フィードはすでに存在します！",
    "Folder" : "フォルダー",
    "No folder" : "フォルダーはありません",
    "New folder" : "新しいフォルダー",
    "Folder name" : "フォルダー名",
    "Go back" : "戻る",
    "Folder exists already!" : "フォルダーはすでに存在します！",
    "Credentials" : "資格情報",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP ベーシック認証の認証情報は暗号化せずに保管する必要があります。その為、サーバーやデータベースにアクセスできる人はすべてこの情報を見ることができます。",
    "Password" : "パスワード",
    "Auto discover Feed" : "自動探索フィード",
    "New Folder" : "フォルダーを作成する",
    "Create" : "作成",
    "Explore" : "探索",
    "Update failed more than 50 times" : "フィードの更新に50回以上失敗しました",
    "Deleted feed" : "削除されたフィード",
    "Undo delete feed" : "削除したフィードを元に戻す",
    "Rename" : "名前の変更",
    "Menu" : "メニュー",
    "Mark read" : "既読にする",
    "Unpin from top" : "トップからピンを外す",
    "Pin to top" : "トップにピン",
    "Newest first" : "新しい順",
    "Oldest first" : "古い順",
    "Default order" : "デフォルト順",
    "Enable full text" : "全文検索を有効",
    "Disable full text" : "全文検索を無効",
    "Unread updated" : "更新を未読",
    "Ignore updated" : "更新を無視",
    "Open feed URL" : "フィードURLを開く",
    "Delete" : "削除",
    "Dismiss" : "閉じる",
    "Collapse" : "折りたたむ",
    "Deleted folder" : "削除されたフォルダー",
    "Undo delete folder" : "削除したフォルダーを元に戻す",
    "Starred" : "共有",
    "All articles" : "すべての記事",
    "Settings" : "設定",
    "Disable mark read through scrolling" : "スクロール時の既読マークを無効化",
    "Compact view" : "コンパクト表示",
    "Expand articles on key navigation" : "キーナビゲーションで記事を展開",
    "Show all articles" : "すべての記事を表示",
    "Reverse ordering (oldest on top)" : "逆順",
    "Subscriptions (OPML)" : "RSS購読リスト (OPML)",
    "Import" : "インポート",
    "Export" : "エクスポート",
    "Error when importing: File does not contain valid OPML" : "インポート中のエラー: ファイルは有効なOPMLを含んでいません",
    "Error when importing: OPML is does neither contain feeds nor folders" : "インポートエラー: OPML はフィードもフォルダーも含んでいません",
    "Unread/Starred Articles" : "未読/注目記事",
    "Error when importing: file does not contain valid JSON" : "インポート中のエラー: ファイルは有効なJSONを含んでいません",
    "Help" : "ヘルプ",
    "Keyboard shortcuts" : "キーボードショートカット",
    "Documentation" : "ドキュメント",
    "Report a bug" : "不具合を報告"
},
"nplurals=1; plural=0;");
