OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Pieprasījums neizdevās, nav pieejams tīkla pieslēgums!",
    "Request unauthorized. Are you logged in?" : "Pieprasījums nav pilnvarots. Vai esot pieteicies?",
    "Token expired or app not enabled! Reload the page!" : "Pilnvara beigusies vai lietotne nav iespējota. Pārlādējiet lapu!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Iekšēja servera kļūda! Lūdzu pārbaudiet data/nextcloud.log papildus informācijai!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Pieprasījums neizdevās, Nextcloud pašlaik darbojas uzturēšanas režīmā!",
    "Unread articles" : "Nelasītie raksti",
    "Shared with me" : "Koplietots ar mani",
    "Use system cron for updates" : "Izmantot sistēmas cron atjauninājumiem",
    "Maximum redirects" : "Maksimāli pieļaujamais pārsūtīšanu skaits",
    "Download" : "Lejupielādēt",
    "Close" : "Aizvērt",
    "Open website" : "Atvērt vietni",
    "Share" : "Koplietot",
    "Username" : "Lietotājvārds",
    "by" : "līdz",
    "from" : "no",
    "Play audio" : "Atskaņot audio",
    "Download audio" : "Lejupielādēt audio",
    "Download video" : "Lejupielādēt video",
    "Keyboard shortcut" : "Tastatūras saīsne",
    "Description" : "Apraksts",
    "right" : "pa labi",
    "left" : "pa kreisi",
    "Refresh" : "Atsvaidzināt",
    "Load previous folder" : "Ielādēt iepriekšējo mapi",
    "Load next folder" : "Ielādēt nākamo mapi",
    "Subscribe" : "Abonēt",
    "Web address" : "Tīmekļa adrese",
    "Feed exists already!" : "Plūsma jau eksistē!",
    "Folder" : "Mape",
    "No folder" : "Nav mapes",
    "New folder" : "Jauna mape",
    "Folder name" : "Mapes nosaukums",
    "Go back" : "Atpakaļ",
    "Folder exists already!" : "Mape jau eksistē!",
    "Credentials" : "Akreditācijas dati",
    "Password" : "Parole",
    "New Folder" : "Jauna mape",
    "Create" : "Izveidot",
    "Update failed more than 50 times" : "Atjaunināšana neizdevās vairāk nekā 50 reizes",
    "Rename" : "Pārsaukt",
    "Menu" : "Izvēlne",
    "Newest first" : "Jaunākie pirms",
    "Oldest first" : "Vecākie pirms",
    "Delete" : "Dzēst",
    "Dismiss" : "Atmest",
    "Collapse" : "Sakļaut",
    "Deleted folder" : "Dzēstās mapes",
    "Starred" : "Svarīgs",
    "All articles" : "Visi raksti",
    "Settings" : "Iestatījumi",
    "Compact view" : "Kompakts skats",
    "Show all articles" : "Rādīt visus rakstus",
    "Subscriptions (OPML)" : "Abonementi (OPML)",
    "Import" : "Importēt",
    "Export" : "Eksportēt",
    "Error when importing: file does not contain valid JSON" : "Kļūda, importējot: datne nesatur derīgus JSON",
    "Help" : "Palīdzība",
    "Keyboard shortcuts" : "Tastatūras saīsnes",
    "Documentation" : "Dokumentācija",
    "Report a bug" : "Ziņot par kļūdu"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
