/**
 * Nextcloud - News
 *
 * This file is licensed under the Affero General Public License version 3 or
 * later. See the COPYING file.
 *
 * @author Bernhard Posselt <dev@bernhard-posselt.com>
 * @copyright Bernhard Posselt 2014
 */
#global-loading {
    width: 100%;
}

#undo-container {
    position: fixed;
    top: 0px;
    width: 100%;
    text-align: center;
    z-index: 101;
    line-height: 1.2;
}

#undo {
    z-index: 101;
    background-color: var(--color-warning);
    border: 0;
    padding: 0 .7em .3em;
    display: none;
    position: relative;
    top: 0;
    border-bottom-left-radius: 1em;
    border-bottom-right-radius: 1em;
}

#undo a {
    font-weight: bold;
}

#undo a:hover {
    text-decoration: underline;
}

#searchbox {
    display: block !important;
}

#mark-all-read-button {
    position: fixed;
    z-index: 1;
    bottom: 0.5em;
    right: 0.5em;
}

.dropdown-content {
    position: absolute;
    background-color: #f1f1f1;
    box-shadow: 0px 8px 16px 0px rgba(0,0,0,0.2);
    z-index: 999;
    min-width: 20em;
    left: 100px;
}

.compact .dropdown-content {
    left: auto;
    right: 15px;
}


.dropdown-content a {
    color: black;
    padding: 2px 12px 2px 44px;
    background-position: 14px center;
    text-decoration: none;
    display: block;
}

.dropdown-content a:hover {
    background-color: #ddd;
}

.compact-dropdown{
    z-index: 1;
}

/* Override hidden before angular is loaded */
[ng\:cloak], [ng-cloak], [data-ng-cloak], [x-ng-cloak], .ng-cloak, .x-ng-cloak, .ng-hide:not(.ng-hide-animate) {
    display: none !important;
}

.contact-input {
    display: flex;
    justify-content: space-between;
    margin: 1em 1.5em;
}

.label-group {
    padding-left: 1.5em;
    background-color: rgba(0, 0, 0, 0.1);
    font-weight: bold;
}

.dropdown-search-message {
    margin-left: 2em;
    font-size: 0.85em;
}

.share-status-icon {
    margin-top: 1.1em;
    margin-right: 1em;
    float: right;
}
