OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Anfrage fehlgeschlagen, Netzwerkverbindung nicht verfügbar!",
    "Request unauthorized. Are you logged in?" : "Anfrage nicht autorisiert. Sind Sie angemeldet?",
    "Request forbidden. Are you an administrator?" : "Anfrage verboten. Sind Sie ein Admin?",
    "Token expired or app not enabled! Reload the page!" : "Token abgelaufen oder App nicht aktiviert! Bitte laden Sie die Seite neu!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Interner Serverfehler! Bitte kontrollieren Sie data/nextcloud.log für weitere Informationen!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Anfrage fehlgeschlagen, diese Nextcloud-Instanz befindet sich derzeit im Wartungsmodus.",
    "News feeds" : "Nachrichten-Feeds",
    "Unread articles" : "Ungelesene Artikel",
    "News" : "News",
    "News folders" : "Nachrichtenordner",
    "Shared with me" : "Mit mir geteilt",
    "An RSS/Atom feed reader" : "Ein RSS/Atom-Feed-Reader",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Eine RSS/Atom Feed Reader App für Nextcloud\n\n- 📲 Synchronisieren Sie Ihre Feeds mit mehreren mobilen oder Desktop [Clients] (https://nextcloud.github.io/news/clients/)\n- 🔄 Automatische Aktualisierung Ihrer Newsfeeds\n- 🆓 Kostenlos und quelloffen unter AGPLv3, keine Werbung oder Premiumfunktionen\n\n**System Cron wird derzeit benötigt, damit diese App funktioniert**\n\nDie Anforderungen finden Sie [hier](https://nextcloud.github.io/news/install/#dependencies)\n\nDie Liste der Änderungen (Changelog) finden Sie [hier](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\n\nErstellen Sie einen [Fehlerbericht](https://github.com/nextcloud/news/issues/new/choose)\n\nErstellen Sie eine [Funktionsanforderung](https://github.com/nextcloud/news/discussions/new)\n\nMelden Sie ein [Feed-Problem](https://github.com/nextcloud/news/discussions/new)",
    "Use system cron for updates" : "Verwende System-Cron für Aktualisierungen",
    "Disable this if you use a custom updater." : "Deaktivieren Sie diese Option, wenn Sie einen eigenen Updater verwenden.",
    "Maximum read count per feed" : "Maximale Anzahl an gelesenen Artikeln pro Feed",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Definiert die maximale Anzahl an Artikeln, die pro Feed gelesen und bei einem Säuberungsauftrag nicht aus der Datenbank gelöscht werden; wenn ältere Artikel nach dem Lesen erhalten bleiben sollen, erhöhe diesen Wert; negative Werte wie -1 deaktivieren diese Funktion komplett",
    "Delete unread articles automatically" : "Ungelesene Artikel automatisch löschen",
    "Enable this if you also want to delete unread articles." : "Dies aktivieren, wenn auch ungelesene Artikel gelöscht werden sollen.",
    "Maximum redirects" : "Maximale Anzahl Weiterleitungen",
    "How many redirects the feed fetcher should follow." : "Anzahl Weiterleitungen die der Feed-Sammler folgen soll.",
    "Feed fetcher timeout" : "Zeitüberschreitung Feed-Sammler",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maximale Anzahl an Sekunden zum Laden eines RSS- oder Atom-Feeds. Wenn dies länger dauert, wird die Aktualisierung abgebrochen.",
    "Explore Service URL" : "Service-URL finden",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Falls angegeben, wird die URL dieses Dienstes zur Feed-Anzeige innerhalb des Explore-Feed-Bereichs abgefragt. Lassen Sie dieses Feld unausgefüllt, um auf den eingebauten Explore-Dienst zurückzugreifen.",
    "Update interval" : "Aktualisierungsintervall",
    "Interval in seconds in which the feeds will be updated." : "Intervall in Sekunden, in dem die Feeds aktualisiert werden.",
    "Successfully updated news configuration" : "Die News-Einstellungen wurde erfolgreich aktualisiert",
    "Unable to update news config" : "Die News-Einstellungen konnten nicht aktualisiert werden",
    "Download" : "Herunterladen",
    "Close" : "Schließen",
    "Subscribe to" : "Abonnieren von",
    "No articles available" : "Keine Artikel verfügbar",
    "No unread articles available" : "Keine ungelesenen Artikel verfügbar",
    "Open website" : "Webseite öffnen",
    "Star article" : "Artikel markieren",
    "Unstar article" : "Markierung aufheben",
    "Keep article unread" : "Artikel ungelesenen lassen",
    "Remove keep article unread" : "„Artikel ungelesenen lassen“ entfernen",
    "Share" : "Teilen",
    "Share with users" : "Mit Benutzern teilen",
    "Username" : "Benutzername",
    "No users found" : "Keine Benutzer gefunden",
    "Error while searching for users" : "Fehler beim Suchen nach Benutzern",
    "Share on social media" : "Auf sozialen Medien teilen",
    "I wanted you to see this article" : "Bitte sehen Sie sich diesen Artikel an",
    "Check out this article" : "Sehen Sie sich diesen Artikel an",
    "by" : "von",
    "from" : "von",
    "shared by" : "Geteilt von",
    "Play audio" : "Audio wiedergeben",
    "Download audio" : "Audio herunterladen",
    "Download video" : "Video herunterladen",
    "Keyboard shortcut" : "Tastaturbefehl",
    "Description" : "Beschreibung",
    "right" : "Rechts",
    "Jump to next article" : "Zum nächsten Artikel springen",
    "left" : "Links",
    "Jump to previous article" : "Zum vorherigen Artikel springen",
    "Toggle star article" : "Markierung des Artikels umschalten",
    "Star article and jump to next one" : "Artikel markieren und zum Nächsten springen",
    "Toggle keep current article unread" : "Umschalten lässt den Artikel ungelesen",
    "Open article in new tab" : "Artikel in neuen Tab öffnen",
    "Toggle expand article in compact view" : "Umschalten zeigt den kompletten Artikel in der kompakten Ansicht",
    "Refresh" : "Aktualisieren",
    "Load next feed" : "Nächsten Feed laden",
    "Load previous feed" : "Vorherigen Feed laden",
    "Load previous folder" : "Vorherigen Ordner laden",
    "Load next folder" : "Nächsten Ordner laden",
    "Scroll to active navigation entry" : "Zum aktiven Navigationseintrag scrollen",
    "Mark current article's feed/folder read" : "Feed/Ordner dieses Artikels als gelesen markieren",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax oder ein webbasierter Cron-Modus gefunden! Ihre Feeds werden nicht aktualisiert! ",
    "How to set up the operating system cron" : "Wie der Cron des Betriebssystems eingerichtet wird",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Installieren und richten Sie einen schnellen, parallelen Updater ein, der die Update-API der News-App nutzt",
    "Subscribe" : "Abonnieren",
    "Web address" : "Internetadresse",
    "Feed exists already!" : "Feed existiert bereits!",
    "Folder" : "Ordner",
    "No folder" : "Kein Ordner",
    "New folder" : "Neuer Ordner",
    "Folder name" : "Ordnername",
    "Go back" : "Zurück gehen",
    "Folder exists already!" : "Der Ordner existiert bereits!",
    "Credentials" : "Zugangsdaten",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Die Anmeldeinformationen der HTTP-Standardauthentifizierung müssen unverschlüsselt gespeichert werden! Jeder mit Serverzugriff ist in der Lage diese Daten zu lesen.",
    "Password" : "Passwort",
    "Auto discover Feed" : "Feed automatisch erkennen",
    "New Folder" : "Neuer Ordner",
    "Create" : "Erstellen",
    "Explore" : "Entdecken",
    "Update failed more than 50 times" : "Aktualisierung ist mehr als 50 mal fehlgeschlagen",
    "Deleted feed" : "Feed gelöscht",
    "Undo delete feed" : "Gelöschten Feed wiederherstellen",
    "Rename" : "Umbenennen",
    "Menu" : "Menü",
    "Mark read" : "Als gelesen markieren",
    "Unpin from top" : "Fixierung aufheben",
    "Pin to top" : "Oben fixieren",
    "Newest first" : "Neue zuerst",
    "Oldest first" : "Älteste zuerst",
    "Default order" : "Standard-Sortierung",
    "Enable full text" : "Volltext aktivieren",
    "Disable full text" : "Volltext deaktivieren",
    "Unread updated" : "Ungelesene aktualisiert",
    "Ignore updated" : "Aktualisierte ignorieren",
    "Open feed URL" : "Feed-URL öffnen",
    "Delete" : "Löschen",
    "Dismiss" : "Ausblenden",
    "Collapse" : "Zuklappen",
    "Deleted folder" : "Ordner gelöscht",
    "Undo delete folder" : "Gelöschten Ordner wiederherstellen",
    "Starred" : "Markiert",
    "All articles" : "Alle Artikel",
    "Settings" : "Einstellungen",
    "Disable mark read through scrolling" : "Keine Artikel während des Bildlaufs als gelesen markieren",
    "Compact view" : "Kompakte Ansicht",
    "Expand articles on key navigation" : "Artikel bei der Tasten-Navigation erweitern",
    "Show all articles" : "Alle Artikel anzeigen",
    "Reverse ordering (oldest on top)" : "Sortierung umkehren (älteste zuerst)",
    "Subscriptions (OPML)" : "Abonnements (OPML)",
    "Import" : "Importieren",
    "Export" : "Exportieren",
    "Error when importing: File does not contain valid OPML" : "Fehler beim Importieren: Datei enthält kein gültiges OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Fehler beim Importieren: OPML enthält weder Feeds noch Ordner",
    "Unread/Starred Articles" : "Ungelesene/Markierte Artikel",
    "Error when importing: file does not contain valid JSON" : "Fehler beim Importieren: Datei enthält kein gültiges JSON",
    "Help" : "Hilfe",
    "Keyboard shortcuts" : "Tastaturkürzel",
    "Documentation" : "Dokumentation",
    "Report a bug" : "Melden Sie einen technischen Fehler"
},
"nplurals=2; plural=(n != 1);");
