<?php

// autoload_psr4.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'fivefilters\\Readability\\' => array($vendorDir . '/fivefilters/readability.php/src'),
    'Riimu\\Kit\\PathJoin\\' => array($vendorDir . '/riimu/kit-pathjoin/src'),
    'Psr\\Http\\Message\\' => array($vendorDir . '/psr/http-message/src'),
    'OCA\\News\\' => array($baseDir . '/lib'),
    'Masterminds\\' => array($vendorDir . '/masterminds/html5/src'),
    'League\\Uri\\' => array($vendorDir . '/league/uri-interfaces/src', $vendorDir . '/league/uri/src'),
    'FeedIo\\' => array($vendorDir . '/debril/feed-io/src/FeedIo'),
    'Favicon\\' => array($vendorDir . '/arthurhoaro/favicon/src/Favicon'),
);
