OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Неуспео захтев. Мрежа није доступна!",
    "Request unauthorized. Are you logged in?" : "Неовлашћен захтев. Јесте ли пријављени?",
    "Token expired or app not enabled! Reload the page!" : "Жетон је истекао или апликација није укључена! Учитајте поново страницу!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Интерна грешка на серверу! Проверите data/nextcloud.log фајл за додатне информације!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Неуспео захтев. Некстклауд сервер је тренутно у режиму приступа само једног корисника!",
    "Unread articles" : "Непрочитани чланци",
    "News" : "Вести",
    "Shared with me" : "Дељено са мном",
    "An RSS/Atom feed reader" : "RSS/Atom читач довода",
    "Use system cron for updates" : "Користи системски крон за ажурирања",
    "Maximum read count per feed" : "Максимални број читања по доводу",
    "Maximum redirects" : "Највише преусмеравања",
    "How many redirects the feed fetcher should follow." : "Колико ће се преусмеравања следити.",
    "Feed fetcher timeout" : "Рок добављања довода",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Време у секундама које ће се чекати да се довод учита. Ако траје дуже, ажурирање ће се прекинути.",
    "Explore Service URL" : "Истражите сервисну адресу",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Ако је дато, ова сервисна адреса ће бити упитана за приказивање у секцији за истраживање довода. За повратак на коришћење уграђеног сервиса за истраживање, оставите ово празно.",
    "Update interval" : "Време ажурирања",
    "Interval in seconds in which the feeds will be updated." : "Интервал у секундама у којем се ће доводи да се ажурирају.",
    "Download" : "Преузми",
    "Close" : "Затвори",
    "Subscribe to" : "Претплати се на",
    "No articles available" : "Нема доступних чланака",
    "No unread articles available" : "Нема непрочитаних чланака",
    "Open website" : "Отвори веб сајт",
    "Star article" : "Стави звездицу чланку",
    "Unstar article" : "Скини звездицу чланку",
    "Keep article unread" : "Остави чланак непрочитаним",
    "Remove keep article unread" : "Уклони да остане непрочитан",
    "Share" : "Подели",
    "Username" : "Корисничко име",
    "by" : "од",
    "from" : "од",
    "Play audio" : "Пусти аудио",
    "Download audio" : "Преузми аудио",
    "Download video" : "Преузми видео",
    "Keyboard shortcut" : "Пречица тастатуре",
    "Description" : "Опис",
    "right" : "десно",
    "Jump to next article" : "Пређи на следећи чланак",
    "left" : "лево",
    "Jump to previous article" : "Пређи на претходни чланак",
    "Toggle star article" : "Мења озвезданост чланка",
    "Star article and jump to next one" : "Стави звездицу чланку и пређи на следећи",
    "Toggle keep current article unread" : "Мења „остави тренутни чланак непрочитаним“",
    "Open article in new tab" : "Отвори чланак у новом језичку",
    "Toggle expand article in compact view" : "Мења „рашири чланак у компактном приказу“",
    "Refresh" : "Освежи",
    "Load next feed" : "Учитај следећи довод",
    "Load previous feed" : "Учитај претходни довод",
    "Load previous folder" : "Учитај претходну фасциклу",
    "Load next folder" : "Учитај следећу фасциклу",
    "Scroll to active navigation entry" : "Отклизај до активног уноса",
    "Mark current article's feed/folder read" : "Означи доводе/фасцикле тренутног чланка прочитаним",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Детектован Ajax или webcron начин рада! Доводи неће бити ажурирани!",
    "How to set up the operating system cron" : "Како подестити крон оперативног система",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Инсталирајте и подесите брже паралелно ажурирање које користи API за ажурирање од ове апликације",
    "Subscribe" : "Претплати се",
    "Web address" : "Веб адреса",
    "Feed exists already!" : "Довод већ постоји!",
    "Folder" : "Фасцикла",
    "No folder" : "Нема фасцикле",
    "New folder" : "Нова фасцикла",
    "Folder name" : "Назив фасцикле",
    "Go back" : "Иди назад",
    "Folder exists already!" : "Фасцикла већ постоји!",
    "Credentials" : "Акредитиви",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth акредитиви морају бити сачувани нешифровани! Свак са приступом серверу или бази ће моћи да им приступи!",
    "Password" : "Лозинка",
    "New Folder" : "Нова фасцикла",
    "Create" : "Направи",
    "Explore" : "Истражи",
    "Update failed more than 50 times" : "Ажурирање је било неуспешно више од 50 пута",
    "Deleted feed" : "Обрисани доводи",
    "Undo delete feed" : "Поништи брисање довода",
    "Rename" : "Преименуј",
    "Menu" : "Мени",
    "Mark read" : "Означи као прочитано",
    "Unpin from top" : "Откачи са врха",
    "Pin to top" : "Закачи на врх",
    "Newest first" : "Прво новије",
    "Oldest first" : "Прво старије",
    "Default order" : "Подразумевани редослед",
    "Enable full text" : "Укључи цео текст",
    "Disable full text" : "Искључи цео текст",
    "Unread updated" : "Ажуриране непрочитане",
    "Ignore updated" : "Игнориши непрочитане",
    "Open feed URL" : "Отвори адресу довода",
    "Delete" : "Обриши",
    "Dismiss" : "Одбаци",
    "Collapse" : "Скупи",
    "Deleted folder" : "Обрисана фасцикла",
    "Undo delete folder" : "Поништи брисање фасцикле",
    "Starred" : "Означено звездицом",
    "All articles" : "Сви чланци",
    "Settings" : "Поставке",
    "Disable mark read through scrolling" : "Искључи „означи прочитаним при клизању“",
    "Compact view" : "Компактни приказ",
    "Expand articles on key navigation" : "Рашири чланке при навигацији тастерима",
    "Show all articles" : "Прикажи све чланке",
    "Reverse ordering (oldest on top)" : "Обрнуто ређање (најстарији на врху)",
    "Subscriptions (OPML)" : "Претплате (ОПМЛ)",
    "Import" : "Увези",
    "Export" : "Извези",
    "Error when importing: File does not contain valid OPML" : "Грешка приликом увоза: Фајл не садржи исправан OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Грешка приликом увоза: OPML не садржи ни доводе ни фасцикле",
    "Unread/Starred Articles" : "Непрочитани/Озвездани чланци",
    "Error when importing: file does not contain valid JSON" : "Грешка приликом увоза: фајл не садржи исправан JSON",
    "Help" : "Помоћ",
    "Keyboard shortcuts" : "Пречице тастатуре",
    "Documentation" : "Документација",
    "Report a bug" : "Пријави грешку"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
