OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Eskaerak huts egin du, sareko konexioa ez dago eskuragarri!",
    "Request unauthorized. Are you logged in?" : "Baimendu gabeko eskaera. Saioa hasi duzu?",
    "Request forbidden. Are you an administrator?" : "Debekatutako eskaera. Administratzailea al zara?",
    "Token expired or app not enabled! Reload the page!" : "Tokena iraungi da edo aplikazioa ez dago gaituta! Kargatu berriz orria!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Zerbitzariaren barneko errorea! Begiratu data/nextcloud.log fitxategia informazio gehiagorako!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Eskaerak huts egin du, Nextcloud mantentze moduan dago une honetan!",
    "News feeds" : "Albiste jarioak",
    "Unread articles" : "Irakurri gabeko artikuluak",
    "News" : "Berriak",
    "News folders" : "Albiste karpetak",
    "Shared with me" : "Nirekin partekatuta",
    "An RSS/Atom feed reader" : "RSS/Atom jarioen irakurle bat",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 RSS/Atom Feed irakurgailu aplikazioa Nextcloud-entzat\n\n- 📲Sinkronizatu jarioak mugikorreko edo mahaigaineko [bezero](https://nextcloud.github.io/news/clients/) anitzekin \n- 🔄 Zure albisteen jarioen eguneratze automatikoak\n- 🆓 Kode irekia eta doakoa AGPLv3-pean, iragarkirik edo premium funtziorik gabe\n\n** Une honetan Cron beharrezkoa da aplikazio honek funtziona dezan **\n\nBaldintzak [hemen](https://nextcloud.github.io/news/install/#dependencies) aurki daitezke\n\nAldaketa-erregistroa eskuragarri dago [hemen](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nSortu [akatsen txostena](https://github.com/nextcloud/news/issues/new/choose)\n\nSortu [ezaugarri eskaera](https://github.com/nextcloud/news/discussions/new)\n\nEman [jarioaren arazo](https://github.com/nextcloud/news/discussions/new)-en berri",
    "Use system cron for updates" : "Erabili sistemaren cron-a eguneraketak egiteko",
    "Disable this if you use a custom updater." : "Desgaitu hau eguneratze pertsonalizatua erabiltzen baduzu.",
    "Maximum read count per feed" : "Gehienezko irakurketa kopurua jarioko",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Garbiketa lanak jario bakoitzean ezabatuko ez dituen artikuluen gehienezko kopurua zehazten du; artikulu zaharrak irakurri ondoren berriz agertzen hasten badira, handitu balio hau; -1 bezalako balio negatiboek ezaugarri hau desgaitzen dute.",
    "Maximum redirects" : "Gehienezko birbideratzeak",
    "How many redirects the feed fetcher should follow." : "Jarioak eskuratzean zenbat birbideratze jarraituko diren.",
    "Feed fetcher timeout" : "Jarioak hartzeko denbora-muga",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "RSS edo Atom jario bat kargatzeko gehienez itxarongo den segundo kopurua; gehiago luzatzen bada eguneraketa bertan behera utziko da.",
    "Explore Service URL" : "Arakatu zerbitzuaren URLa",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Emanez gero, zerbitzu honen URLa erabiliko da 'Arakatu jarioak' atalean bistaratutako jarioak eskuratzeko. Berriz ere jario lehenetsiak bistaratzeko, utzi eremu hau hutsik.",
    "Update interval" : "Eguneraketa tartea",
    "Interval in seconds in which the feeds will be updated." : "Jarioak zenbat segundoko tartean eguneratuko diren.",
    "Successfully updated news configuration" : "Berrien konfigurazioa ondo eguneratu da",
    "Unable to update news config" : "Ezin izan da berrien konfigurazioa eguneratu.",
    "Download" : "Deskargatu",
    "Close" : "Itxi",
    "Subscribe to" : "Harpidetu",
    "No articles available" : "Artikulurik ez eskuragarri",
    "No unread articles available" : "Ez dago irakurri gabeko artikulurik eskuragarri",
    "Open website" : "Ireki webgunea",
    "Star article" : "Izarra artikuluari",
    "Unstar article" : "Kendu izarra artikuluari",
    "Keep article unread" : "Mantendu artikulua irakurri gabea",
    "Remove keep article unread" : "Ezabatu mantendu artikulua irakurri gabea",
    "Share" : "Partekatu",
    "Share with users" : "Partekatu erabiltzaileekin",
    "Username" : "Erabiltzaile-izena",
    "No users found" : "Ez da erabiltzailerik aurkitu",
    "Error while searching for users" : "Errorea erabiltzaileak bilatzean",
    "Share on social media" : "Partekatu sare sozialetan",
    "I wanted you to see this article" : "Artikulu hau ikustea nahi nuen",
    "Check out this article" : "Ikusi artikulu hau",
    "by" : " Egilea:",
    "from" : "Jatorria:",
    "shared by" : "honek partekatua",
    "Play audio" : "Erreproduzitu audioa",
    "Download audio" : "Deskargatu audioa",
    "Download video" : "Deskargatu bideoa",
    "Keyboard shortcut" : "Teklatuko lasterbidea",
    "Description" : "Deskribapena",
    "right" : "eskuina",
    "Jump to next article" : "Joan hurrengo artikulura",
    "left" : "ezkerra",
    "Jump to previous article" : "Joan aurreko artikulura",
    "Toggle star article" : "Txandakatu artikuluaren izarra",
    "Star article and jump to next one" : "Izarra artikuluari eta joan hurrengora",
    "Toggle keep current article unread" : "Txandakatu mantendu uneko artikulua irakurri gabea",
    "Open article in new tab" : "Ireki artikulua fitxa berri batean",
    "Toggle expand article in compact view" : "Txandakatu zabaldu artikulua ikuspegi trinkoan",
    "Refresh" : "Freskatu",
    "Load next feed" : "Kargatu hurrengo jarioa",
    "Load previous feed" : "Kargatu aurreko jarioa",
    "Load previous folder" : "Kargatu aurreko karpeta",
    "Load next folder" : "Kargatu hurrengo karpeta",
    "Scroll to active navigation entry" : "Korritu nabigazioko sarrera aktibora",
    "Mark current article's feed/folder read" : "Markatu uneko artikuluaren jarioa/karpeta irakurrita",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax edo webcron modua detektatu da! Zure jarioak ez dira eguneratuko!",
    "How to set up the operating system cron" : "Nola konfiguratu sistema eragilearen cron-a",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instalatu eta konfiguratu Berriak aplikazioaren eguneraketa APIa erabiltzen duen eguneratzaile paralelo azkarrago bat",
    "Subscribe" : "Harpidetu",
    "Web address" : "Web helbidea",
    "Feed exists already!" : "Jarioa dagoeneko existitzen da!",
    "Folder" : "Karpeta",
    "No folder" : "Karpetarik ez",
    "New folder" : "Karpeta berria",
    "Folder name" : "Karpetaren izena",
    "Go back" : "Atzera",
    "Folder exists already!" : "Karpeta dagoeneko existitzen da!",
    "Credentials" : "Kredentzialak",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Oinarrizko Autorizazio kredentzialak enkriptatu gabe gorde behar dira! Zerbitzarira edo datu-basera sarbidea duen edonork ikusi ahal izango ditu!",
    "Password" : "Pasahitza",
    "Auto discover Feed" : "Aurkitu automatikoki jarioa",
    "New Folder" : "Karpeta berria",
    "Create" : "Sortu",
    "Explore" : "Arakatu",
    "Update failed more than 50 times" : "Eguneraketak 50 aldiz baino gehiagotan huts egin du",
    "Deleted feed" : "Ezabatu jarioa",
    "Undo delete feed" : "Desegin jarioa ezabatzea",
    "Rename" : "Berrizendatu",
    "Menu" : "Menua",
    "Mark read" : "Markatu irakurrita",
    "Unpin from top" : "Kendu aingura goitik",
    "Pin to top" : "Ainguratu goian",
    "Newest first" : "Berrienak lehenik",
    "Oldest first" : "Zaharrenak lehenik",
    "Default order" : "Lehenetsitako ordena",
    "Enable full text" : "Gaitu testu osoa",
    "Disable full text" : "Desgaitu testu osoa",
    "Unread updated" : "Markatu eguneratuak irakurri gabe",
    "Ignore updated" : "Ez ikusi eguneratuak",
    "Open feed URL" : "Ireki jarioaren URLa",
    "Delete" : "Ezabatu",
    "Dismiss" : "Baztertu",
    "Collapse" : "Tolestu",
    "Deleted folder" : "Karpeta ezabatuta",
    "Undo delete folder" : "Desegin karpeta ezabatzea",
    "Starred" : "Izardunak",
    "All articles" : "Artikulu guztiak",
    "Settings" : "Ezarpenak",
    "Disable mark read through scrolling" : "Desgaitu korritzean irakurrita markatzea",
    "Compact view" : "Ikuspegi trinkoa",
    "Expand articles on key navigation" : "Zabaldu artikuluak teklatu bidezko nabigazioan",
    "Show all articles" : "Erakutsi artikulu guztiak",
    "Reverse ordering (oldest on top)" : "Alderantzizko ordena (zaharrenak goian)",
    "Subscriptions (OPML)" : "Harpidetzak (OPML)",
    "Import" : "Inportatu",
    "Export" : "Esportatu",
    "Error when importing: File does not contain valid OPML" : "Errorea inportatzean: Fitxategiak ez dauka baliozko OPMLrik",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Errorea inportatzean: OPMLak ez dauka jario edo karpetarik",
    "Unread/Starred Articles" : "Irakurri gabeko/izarra duten artikuluak",
    "Error when importing: file does not contain valid JSON" : "Errorea inportatzean: fitxategiak ez du baliozko JSONa",
    "Help" : "Laguntza",
    "Keyboard shortcuts" : "Teklatuaren lasterbideak",
    "Documentation" : "Dokumentazioa",
    "Report a bug" : "Jakinarazi errore bat"
},
"nplurals=2; plural=(n != 1);");
